@@ -4,12 +4,13 @@ namespace PhpParser\Node\Expr;
 
 use PhpParser\Node\Expr;
 
-/**
- * @property Expr $var  Variable
- * @property Expr $expr Expression
- */
 class Assign extends Expr
 {
+    /** @var Expr Variable */
+    public $var;
+    /** @var Expr Expression */
+    public $expr;
+
     /**
      * Constructs an assignment node.
      *
@@ -18,12 +19,12 @@ class Assign extends Expr
      * @param array $attributes Additional attributes
      */
     public function __construct(Expr $var, Expr $expr, array $attributes = array()) {
-        parent::__construct(
-            array(
-                'var'  => $var,
-                'expr' => $expr
-            ),
-            $attributes
-        );
+        parent::__construct(null, $attributes);
+        $this->var = $var;
+        $this->expr = $expr;
     }
-}
\ No newline at end of file
+
+    public function getSubNodeNames() {
+        return array('var', 'expr');
+    }
+}
