@@ -10,22 +10,20 @@ OC.L10N.register(
     "Activities" : "فعالیت‌ها",
     "Error loading activities" : "خطا در بارگزاری فعالیت‌ها",
     "No activities" : "هیچ فعالیتی",
+    ", " : "رشته های ترجمه نشده",
     "There are no events for this filter" : "هیچ رخدادی برای این فیلتر وجود ندارد",
+    "Today" : "امروز",
+    "Yesterday" : "دیروز",
+    "\"remote user\"" : "\"کاربران از راه‌ دور\"",
     "Activity notification" : "هشدارهای فعالیت",
     "All Activities" : "تمام فعالیت ها",
     "Activities by you" : "فعالیت های مربوط به شما",
     "Activities by others" : "فعالیت های انجام شده توسط دیگران",
-    "\"remote user\"" : "\"کاربران از راه‌ دور\"",
-    "in %s" : "در %s",
     "%s and %s" : "%s و %s",
-    ", " : "رشته های ترجمه نشده",
-    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s و <strong %s>%n بیشتر </strong>"],
-    "_%s and %n more_::_%s and %n more_" : ["%s و %s بیشتر"],
     "Hello %s," : "سلام %s",
     "You are receiving this email because the following things happened at %s" : "شما به علت رویداد موارد زیر این ایمیل را دریافت کرده‌اید %s",
     "* %1$s - %2$s" : "* %1$s - %2$s",
     "_* and %n more _::_* and %n more _" : ["* و %n بیشتر"],
-    "Notifications" : "هشدارها",
     "List your own actions in the stream" : "اعمال شخصی تان در پخش را لیست کنید",
     "Notify about your own actions via email" : "اطلاع رسانی درباره اعمال شخصی تان با ایمیل",
     "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل های هشدار می بایست ادرس ایمیل خود را تنظیم کنید",
@@ -37,7 +35,6 @@ OC.L10N.register(
     "Enable RSS feed" : "فعالسازی فید RSS",
     "No activity yet" : "هنوز فعالیتی انجام نشده",
     "No more events to load" : "رویداد دیگری برای بارگزاری وجود ندارد",
-    "Files" : "فایل ها",
-    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s و  <strong class=\"has-tooltip\" title=\"%s\">%n بیشتر </strong>"]
+    "Files" : "فایل ها"
 },
 "nplurals=1; plural=0;");
