@@ -10,23 +10,24 @@ OC.L10N.register(
     "Activities" : "Etkinlikler",
     "Error loading activities" : "Etkinlikler yüklenirken hata oluştu",
     "No activities" : "Etkinlik yok",
+    ", " : ", ",
+    "{parameterList} and {lastParameter}" : "{parameterList} ve {lastParameter}",
+    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} ve {linkStart}%n daha fazla{linkEnd}","{parameterList} ve {linkStart}%n daha fazla{linkEnd}"],
+    "in {directory}" : "{directory} içinde",
     "This stream will show events like additions, changes & shares" : "Bu akış ekleme, değişiklikler ve paylaşımlar gibi etkinlikleri gösterecektir",
     "There are no events for this filter" : "Bu filtre için herhangi bir etkinlik bulunmuyor",
+    "Today" : "Bugün",
+    "Yesterday" : "Dün",
+    "\"remote user\"" : "\"uzak kullanıcı\"",
     "Activity notification" : "Etkinlik bildirimi",
     "All Activities" : "Tüm Etkinlikler",
     "Activities by you" : "Sizin etkinlikleriniz",
     "Activities by others" : "Başkalarının etkinlikleri",
-    "\"remote user\"" : "\"uzak kullanıcı\"",
-    "in %s" : "%s içinde",
     "%s and %s" : "%s ve %s",
-    ", " : ", ",
-    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s ve <strong %s>%n daha</strong>","%s ve <strong %s>%n daha</strong>"],
-    "_%s and %n more_::_%s and %n more_" : ["%s ve %n daha fazla","%s ve %n daha fazla"],
     "Hello %s," : "Merhaba %s,",
     "You are receiving this email because the following things happened at %s" : "Bu e-postayı alma sebebiniz %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
     "* %1$s - %2$s" : "* %1$s - %2$s",
     "_* and %n more _::_* and %n more _" : ["* ve %n daha fazla","* ve %n daha fazla"],
-    "Notifications" : "Bildirimler",
     "List your own actions in the stream" : "Akışta kendi eylemlerinizi listeleyin",
     "Notify about your own actions via email" : "Kendi eylemlerinizi e-posta ile alın",
     "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını almadan önce e-posta adresinizi ayarlamanız gerekiyor.",
@@ -38,7 +39,6 @@ OC.L10N.register(
     "Enable RSS feed" : "RSS beslemesini etkinleştir",
     "No activity yet" : "Henüz bir etkinlik yok",
     "No more events to load" : "Yüklenecek başka olay yok",
-    "Files" : "Dosyalar",
-    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s ve <strong class=\"has-tooltip\" title=\"%s\">%n daha</strong>","%s ve <strong class=\"has-tooltip\" title=\"%s\">%n daha</strong>"]
+    "Files" : "Dosyalar"
 },
 "nplurals=2; plural=(n > 1);");
