@@ -4,13 +4,6 @@ OC.L10N.register(
     "Storage not available" : "Speicher nicht verfügbar",
     "Storage invalid" : "Speicher ungültig",
     "Unknown error" : "Unbekannter Fehler",
-    "Could not move %s - File with this name already exists" : "%s konnte nicht verschoben werden. Eine Datei mit diesem Namen existiert bereits.",
-    "Could not move %s" : "Konnte %s nicht verschieben",
-    "Permission denied" : "Zugriff verweigert",
-    "The target folder has been moved or deleted." : "Der Zielordner wurde verschoben oder gelöscht.",
-    "The name %s is already used in the folder %s. Please choose a different name." : "Der Name %s wird bereits im Ordner %s benutzt. Bitte wählen Sie einen anderen Namen.",
-    "Error when creating the file" : "Fehler beim Erstellen der Datei",
-    "Error when creating the folder" : "Fehler beim Erstellen des Ordners",
     "Unable to set upload directory." : "Das Upload-Verzeichnis konnte nicht gesetzt werden.",
     "Invalid Token" : "Ungültiger Token",
     "No file was uploaded. Unknown error" : "Keine Datei hochgeladen. Unbekannter Fehler",
@@ -22,6 +15,7 @@ OC.L10N.register(
     "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
     "Failed to write to disk" : "Fehler beim Schreiben auf die Festplatte",
     "Not enough storage available" : "Nicht genug Speicher vorhanden.",
+    "The target folder has been moved or deleted." : "Der Zielordner wurde verschoben oder gelöscht.",
     "Upload failed. Could not find uploaded file" : "Hochladen fehlgeschlagen. Die hochgeladene Datei konnte nicht gefunden werden.",
     "Upload failed. Could not get file info." : "Hochladen fehlgeschlagen. Die Dateiinformationen konnten nicht abgerufen werden.",
     "Invalid directory." : "Ungültiges Verzeichnis.",
@@ -30,30 +24,36 @@ OC.L10N.register(
     "Favorites" : "Favoriten",
     "Home" : "Zuhause",
     "Close" : "Schließen",
+    "Upload cancelled." : "Upload abgebrochen.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
     "Total file size {size1} exceeds upload limit {size2}" : "Die Gesamt-Größe {size1} überschreitet die Upload-Begrenzung {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, Sie möchten {size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
-    "Upload cancelled." : "Upload abgebrochen.",
+    "Error uploading file \"{fileName}\": {message}" : "Fehler beim Hochladen der Datei \"{fileName}\": {message}",
     "Could not get result from server." : "Ergebnis konnte nicht vom Server abgerufen werden.",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Dateiupload läuft. Wenn Sie die Seite jetzt verlassen, wird der Upload abgebrochen.",
     "Actions" : "Aktionen",
     "Download" : "Herunterladen",
     "Rename" : "Umbenennen",
     "Delete" : "Löschen",
+    "Disconnect storage" : "Speicher trennen",
+    "Unshare" : "Freigabe aufheben",
     "Details" : "Details",
     "Select" : "Auswählen",
     "Pending" : "Ausstehend",
     "Unable to determine date" : "Datum konnte nicht ermittelt werden",
     "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
     "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Logdateien oder kontaktieren Sie den Administrator",
-    "Error moving file." : "Fehler beim Verschieben der Datei.",
-    "Error moving file" : "Fehler beim Verschieben der Datei",
-    "Error" : "Fehler",
-    "{new_name} already exists" : "{new_name} existiert bereits",
-    "Could not rename file" : "Die Datei konnte nicht umbenannt werden",
-    "Could not create file" : "Die Datei konnte nicht erstellt werden",
-    "Could not create folder" : "Der Ordner konnte nicht erstellt werden",
-    "Error deleting file." : "Fehler beim Löschen der Datei.",
+    "Could not move \"{file}\", target exists" : "Die Datei konnte nicht verschoben werden \"{file}\", da die Datei im Zielordner bereits existiert",
+    "Could not move \"{file}\"" : "Die Datei konnte nicht verschoben werden \"{file}\"",
+    "{newName} already exists" : "{newName} existiert bereits",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei konnte nicht umbennant werden \"{fileName}\", da die Datei nicht mehr existiert",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte wählen Sie einen anderen Namen.",
+    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
+    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Die Datei konnte nicht erstellt werden \"{file}\", da diese bereits existiert",
+    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
+    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner konnte nicht erstellt werden \"{dir}\", da dieser bereits existiert",
+    "Error deleting file \"{fileName}\"." : "Fehler beim löschen der Datei \"{fileName}\".",
     "No entries in this folder match '{filter}'" : "Keine Einträge in diesem Ordner stimmen mit '{filter}' überein",
     "Name" : "Name",
     "Size" : "Größe",
@@ -71,12 +71,14 @@ OC.L10N.register(
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)" : "Ihr Speicher ist fast voll ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["stimmt mit '{filter}' überein","stimmen mit '{filter}' überein"],
+    "Path" : "Pfad",
+    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Favorisiert",
     "Favorite" : "Favorit",
-    "Upload" : "Hochladen",
-    "Text file" : "Textdatei",
     "Folder" : "Ordner",
     "New folder" : "Neuer Ordner",
+    "{newname} already exists" : "{newname} existiert bereits",
+    "Upload" : "Hochladen",
     "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
     "A new file or folder has been <strong>created</strong>" : "Eine neue Datei oder ein neuer Ordner wurde <strong>erstellt</strong>",
     "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
@@ -92,14 +94,16 @@ OC.L10N.register(
     "%2$s deleted %1$s" : "%2$s hat %1$s gelöscht",
     "You restored %1$s" : "Sie haben %1$s wiederhergestellt",
     "%2$s restored %1$s" : "%2$s wiederhergestellt %1$s",
-    "%s could not be renamed as it has been deleted" : "%s konnte nicht umbenannt werden, da es gelöscht wurde",
-    "%s could not be renamed" : "%s konnte nicht umbenannt werden",
+    "Changed by %2$s" : "Geändert von %2$s",
+    "Deleted by %2$s" : "Gelöscht durch %2$s",
+    "Restored by %2$s" : "Wiederhergestellt durch %2$s",
     "Upload (max. %s)" : "Hochladen (max. %s)",
     "File handling" : "Dateibehandlung",
     "Maximum upload size" : "Maximale Upload-Größe",
     "max. possible: " : "maximal möglich:",
     "Save" : "Speichern",
-    "Can not be edited from here due to insufficient permissions." : "Aufgrund unzureichender Berechtigungen kann dies nicht von hier bearbeitet werden.",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Bei PHP-FPM kann es 5 Minuten dauern, bis Änderungen angewendet sind.",
+    "Missing permissions to edit from here." : "Fehlende Berechtigungen um von hier aus zu bearbeiten.",
     "Settings" : "Einstellungen",
     "WebDAV" : "WebDAV",
     "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Benutzen Sie diese Adresse, um <a href=\"%s\" target=\"_blank\">über WebDAV auf Ihre Dateien zuzugreifen</a>",
@@ -110,10 +114,17 @@ OC.L10N.register(
     "Select all" : "Alle auswählen",
     "Upload too large" : "Der Upload ist zu groß",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
-    "Files are being scanned, please wait." : "Dateien werden gescannt, bitte warten.",
-    "Currently scanning" : "Durchsuchen läuft",
     "No favorites" : "Keine Favoriten",
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
-    "Unable to set upload directory." : "Das Upload-Verzeichnis konnte nicht gesetzt werden."
+    "Text file" : "Textdatei",
+    "New text file.txt" : "Neue Textdatei file.txt",
+    "Changed by %2$s" : "Geändert von %2$s",
+    "Deleted by %2$s" : "Gelöscht durch %2$s",
+    "Restored by %2$s" : "Wiederhergestellt durch %2$s",
+    "Unable to set upload directory." : "Das Upload-Verzeichnis konnte nicht gesetzt werden.",
+    "You changed %1$s" : "Sie haben %1$s geändert",
+    "You created %1$s" : "Sie haben %1$s erstellt",
+    "You deleted %1$s" : "Sie haben %1$s gelöscht",
+    "You restored %1$s" : "Sie haben %1$s wiederhergestellt"
 },
 "nplurals=2; plural=(n != 1);");
