@@ -4,13 +4,6 @@ OC.L10N.register(
     "Storage not available" : "Spațiu de stocare indisponibil",
     "Storage invalid" : "Spațiu de stocare invalid",
     "Unknown error" : "Eroare necunoscută",
-    "Could not move %s - File with this name already exists" : "%s nu se poate muta - Fișierul cu acest nume există deja ",
-    "Could not move %s" : "Nu se poate muta %s",
-    "Permission denied" : "Accesul interzis",
-    "The target folder has been moved or deleted." : "Dosarul țintă a fost mutat sau șters.",
-    "The name %s is already used in the folder %s. Please choose a different name." : "Numele %s este deja este folosit în dosarul %s. Te rog alege alt nume.",
-    "Error when creating the file" : "Eroare la crearea fișierului",
-    "Error when creating the folder" : "Eroare la crearea dosarului",
     "Unable to set upload directory." : "Imposibil de a seta directorul pentru încărcare.",
     "Invalid Token" : "Jeton Invalid",
     "No file was uploaded. Unknown error" : "Niciun fișier nu a fost încărcat. Eroare necunoscută",
@@ -22,6 +15,7 @@ OC.L10N.register(
     "Missing a temporary folder" : "Lipsește un dosar temporar",
     "Failed to write to disk" : "Eroare la scrierea pe disc",
     "Not enough storage available" : "Nu este disponibil suficient spațiu",
+    "The target folder has been moved or deleted." : "Dosarul țintă a fost mutat sau șters.",
     "Upload failed. Could not find uploaded file" : "Încărcare eșuată. Nu se poate găsi fișierul încărcat",
     "Upload failed. Could not get file info." : "Încărcare eșuată. Nu se pot obține informații despre fișier.",
     "Invalid directory." : "Dosar nevalid.",
@@ -30,27 +24,21 @@ OC.L10N.register(
     "Favorites" : "Favorite",
     "Home" : "Acasă",
     "Close" : "Închide",
+    "Upload cancelled." : "Încărcare anulată.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nu se poate încărca {filename} deoarece este un director sau are mărimea de 0 octeți",
     "Total file size {size1} exceeds upload limit {size2}" : "Mărimea fișierului este {size1} ce depășește limita de încărcare de {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spațiu liber insuficient, încărcați {size1} însă doar {size2} disponibil rămas",
-    "Upload cancelled." : "Încărcare anulată.",
     "Could not get result from server." : "Nu se poate obține rezultatul de la server.",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Fișierul este în curs de încărcare. Părăsirea paginii va întrerupe încărcarea.",
     "Actions" : "Acțiuni",
     "Download" : "Descarcă",
     "Rename" : "Redenumește",
     "Delete" : "Șterge",
+    "Disconnect storage" : "Deconectează stocarea",
+    "Unshare" : "Nu mai partaja",
     "Details" : "Detalii",
     "Select" : "Alege",
     "Pending" : "În așteptare",
-    "Error moving file." : "Eroare la mutarea fișierului.",
-    "Error moving file" : "Eroare la mutarea fișierului",
-    "Error" : "Eroare",
-    "{new_name} already exists" : "{new_name} există deja",
-    "Could not rename file" : "Nu s-a putut redenumi fișierul",
-    "Could not create file" : "Nu s-a putut crea fisierul",
-    "Could not create folder" : "Nu s-a putut crea folderul",
-    "Error deleting file." : "Eroare la ștergerea fișierului.",
     "Name" : "Nume",
     "Size" : "Mărime",
     "Modified" : "Modificat",
@@ -65,10 +53,9 @@ OC.L10N.register(
     "Your storage is full, files can not be updated or synced anymore!" : "Spațiul de stocare este plin, fișierele nu mai pot fi actualizate sau sincronizate!",
     "Your storage is almost full ({usedSpacePercent}%)" : "Spațiul de stocare este aproape plin ({usedSpacePercent}%)",
     "Favorite" : "Favorit",
-    "Upload" : "Încărcă",
-    "Text file" : "Fișier text",
     "Folder" : "Dosar",
     "New folder" : "Un nou dosar",
+    "Upload" : "Încărcă",
     "A new file or folder has been <strong>created</strong>" : "Un nou fișier sau dosar a fost <strong>creat</strong>",
     "A file or folder has been <strong>changed</strong>" : "Un nou fișier sau dosar a fost <strong>modificat</strong>",
     "A file or folder has been <strong>deleted</strong>" : "Un nou fișier sau dosar a fost <strong>șters</strong>",
@@ -82,8 +69,6 @@ OC.L10N.register(
     "%2$s deleted %1$s" : "%2$s a șters %1$s",
     "You restored %1$s" : "Ai restaurat %1$s",
     "%2$s restored %1$s" : "%2$s a restaurat %1$s",
-    "%s could not be renamed as it has been deleted" : "%s nu a putut fi redenumit deoarece a fost sters",
-    "%s could not be renamed" : "%s nu a putut fi redenumit",
     "Upload (max. %s)" : "Încarcă (max. %s)",
     "File handling" : "Manipulare fișiere",
     "Maximum upload size" : "Dimensiune maximă admisă la încărcare",
@@ -96,7 +81,10 @@ OC.L10N.register(
     "Select all" : "Selectează tot",
     "Upload too large" : "Fișierul încărcat este prea mare",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fișierele pe care încerci să le încarci depășesc limita de încărcare maximă admisă pe acest server.",
-    "Files are being scanned, please wait." : "Fișierele sunt scanate, te rog așteaptă.",
-    "Currently scanning" : "Acum scanează"
+    "Text file" : "Fișier text",
+    "You changed %1$s" : "Ai schimbat %1$s",
+    "You created %1$s" : "Ai creat %1$s",
+    "You deleted %1$s" : "Ai şters %1$s",
+    "You restored %1$s" : "Ai restaurat %1$s"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
