@@ -4,13 +4,6 @@ OC.L10N.register(
     "Storage not available" : "ไม่สามารถใช้พื้นที่จัดเก็บข้อมูลได้",
     "Storage invalid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
     "Unknown error" : "ข้อผิดพลาดที่ไม่ทราบสาเหตุ",
-    "Could not move %s - File with this name already exists" : "ไม่สามารถย้าย %s ได้ - ไฟล์ที่ใช้ชื่อนี้มีอยู่แล้ว",
-    "Could not move %s" : "ไม่สามารถย้าย %s ได้",
-    "Permission denied" : "ไม่อนุญาต",
-    "The target folder has been moved or deleted." : "โฟลเดอร์ปลายทางถูกย้ายหรือลบ",
-    "The name %s is already used in the folder %s. Please choose a different name." : "ชื่อ %s ถูกใช้ไปแล้วในโฟลเดอร์ %s โปรดเลือกชื่ออื่นที่แตกต่างกัน",
-    "Error when creating the file" : "เกิดข้อผิดพลาดเมื่อมีการสร้างไฟล์",
-    "Error when creating the folder" : "เกิดข้อผิดพลาดเมื่อมีการสร้างโฟลเดอร์",
     "Unable to set upload directory." : "ไม่สามารถตั้งค่าอัพโหลดไดเรกทอรี",
     "Invalid Token" : "โทเค็นไม่ถูกต้อง",
     "No file was uploaded. Unknown error" : "ยังไม่มีไฟล์ใดที่ถูกอัพโหลด เกิดข้อผิดพลาดที่ไม่ทราบสาเหตุ",
@@ -22,6 +15,7 @@ OC.L10N.register(
     "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวเกิดการสูญหาย",
     "Failed to write to disk" : "เขียนข้อมูลลงแผ่นดิสก์ล้มเหลว",
     "Not enough storage available" : "เหลือพื้นที่ไม่เพียงสำหรับใช้งาน",
+    "The target folder has been moved or deleted." : "โฟลเดอร์ปลายทางถูกย้ายหรือลบ",
     "Upload failed. Could not find uploaded file" : "อัพโหลดล้มเหลว ไม่สามารถหาไฟล์ที่จะอัพโหลด",
     "Upload failed. Could not get file info." : "อัพโหลดล้มเหลว ไม่สามารถรับข้อมูลไฟล์",
     "Invalid directory." : "ไดเร็กทอรี่ไม่ถูกต้อง",
@@ -30,30 +24,35 @@ OC.L10N.register(
     "Favorites" : "รายการโปรด",
     "Home" : "บ้าน",
     "Close" : "ปิด",
+    "Upload cancelled." : "การอัพโหลดถูกยกเลิก",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "ไม่สามารถอัพโหลด {filename} มันเป็นไดเรกทอรีหรือมี 0 ไบต์",
     "Total file size {size1} exceeds upload limit {size2}" : "ขนาดไฟล์ {size1} ทั้งหมดเกินขีดจำกัด ของการอัพโหลด {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "พื้นที่ว่างไม่เพียงพอคุณจะอัพโหลด {size1} แต่มีพืนที่แค่ {size2}",
-    "Upload cancelled." : "การอัพโหลดถูกยกเลิก",
     "Could not get result from server." : "ไม่สามารถรับผลลัพธ์จากเซิร์ฟเวอร์",
     "File upload is in progress. Leaving the page now will cancel the upload." : "การอัพโหลดไฟล์กำลังอยู่ในระหว่างดำเนินการ การออกจากหน้าเว็บนี้จะทำให้การอัพโหลดถูกยกเลิก",
     "Actions" : "การกระทำ",
     "Download" : "ดาวน์โหลด",
     "Rename" : "เปลี่ยนชื่อ",
     "Delete" : "ลบ",
+    "Disconnect storage" : "ยกเลิกการเชื่อมต่อการจัดเก็บข้อมูล",
+    "Unshare" : "ยกเลิกการแชร์",
     "Details" : "รายละเอียด",
     "Select" : "เลือก",
     "Pending" : "อยู่ระหว่างดำเนินการ",
     "Unable to determine date" : "ไม่สามารถกำหนดวัน",
     "This operation is forbidden" : "การดำเนินการนี้ถูกห้าม",
     "This directory is unavailable, please check the logs or contact the administrator" : "ไม่สามารถใช้งานไดเรกทอรีนี้โปรดตรวจสอบบันทึกหรือติดต่อผู้ดูแลระบบ",
-    "Error moving file." : "ข้อผิดพลาดในการเคลื่อนย้ายไฟล์",
-    "Error moving file" : "ข้อผิดพลาดในการเคลื่อนย้ายไฟล์",
-    "Error" : "ข้อผิดพลาด",
-    "{new_name} already exists" : "{new_name} มีอยู่แล้วในระบบ",
-    "Could not rename file" : "ไม่สามารถเปลี่ยนชื่อไฟล์",
-    "Could not create file" : "ไม่สามารถสร้างไฟล์",
-    "Could not create folder" : "ไม่สามารถสร้างโฟลเดอร์",
-    "Error deleting file." : "เกิดข้อผิดพลาดในการลบไฟล์",
+    "Could not move \"{file}\", target exists" : "ไม่สามารถย้ายไฟล์ \"{file}\" ไม่มีไฟล์นั้นอยู่",
+    "Could not move \"{file}\"" : "ไม่สามารถย้ายไฟล์ \"{file}\"",
+    "{newName} already exists" : "{newName} มีอยู่แล้ว",
+    "Could not rename \"{fileName}\", it does not exist any more" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\" ไฟล์นั้นไม่มีอยู่",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "ชื่อโฟลเดอร์ \"{targetName}\" มีอยู่แล้วใน \"{dir}\" กรุณาใช้ชื่อที่แตกต่างกัน",
+    "Could not rename \"{fileName}\"" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\"",
+    "Could not create file \"{file}\"" : "ไม่สามารถสร้างไฟล์ \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "ไม่สามารถสร้างไฟล์ \"{file}\" เพราะมันมีอยู่แล้ว",
+    "Could not create folder \"{dir}\"" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\"",
+    "Could not create folder \"{dir}\" because it already exists" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\" เพราะมันมีอยู่แล้ว",
+    "Error deleting file \"{fileName}\"." : "เกิดข้อผิดพลาดขณะลบไฟล์ \"{fileName}\"",
     "No entries in this folder match '{filter}'" : "ไม่มีรายการในโฟลเดอร์นี้ที่ตรงกับ '{filter}'",
     "Name" : "ชื่อ",
     "Size" : "ขนาด",
@@ -75,12 +74,10 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n ไบต์"],
     "Favorited" : "รายการโปรด",
     "Favorite" : "รายการโปรด",
-    "{newname} already exists" : "{newname} ถูกใช้ไปแล้ว",
-    "Upload" : "อัพโหลด",
-    "Text file" : "ไฟล์ข้อความ",
-    "New text file.txt" : "ไฟล์ข้อความใหม่ .txt",
     "Folder" : "แฟ้มเอกสาร",
     "New folder" : "โฟลเดอร์ใหม่",
+    "{newname} already exists" : "{newname} ถูกใช้ไปแล้ว",
+    "Upload" : "อัพโหลด",
     "An error occurred while trying to update the tags" : "เกิดข้อผิดพลาดขณะที่พยายามจะปรับปรุงแท็ก",
     "A new file or folder has been <strong>created</strong>" : "มีไฟล์ใหม่หรือโฟลเดอร์ได้ถูก <strong>สร้างขึ้น!</strong>",
     "A file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ได้ถูก <strong>เปลี่ยน!</strong>",
@@ -99,15 +96,13 @@ OC.L10N.register(
     "Changed by %2$s" : "เปลี่ยนแปลงโดย %2$s",
     "Deleted by %2$s" : "ลบโดย %2$s",
     "Restored by %2$s" : "กู้คืนโดย %2$s",
-    "%s could not be renamed as it has been deleted" : "%s ไม่สามารถเปลี่ยนชื่อเนื่องจากถูกลบไปแล้ว",
-    "%s could not be renamed" : "%s ไม่สามารถเปลี่ยนชื่อ",
     "Upload (max. %s)" : "อัพโหลด (สูงสุด %s)",
     "File handling" : "การจัดการไฟล์",
     "Maximum upload size" : "ขนาดไฟล์สูงสุดที่อัพโหลดได้",
     "max. possible: " : "จำนวนสูงสุดที่สามารถทำได้: ",
-    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "ด้วยค่า PHP-FPM นี้อาจใช้เวลาถึง 5 นาที จะมีผลหลังจากการบันทึก",
     "Save" : "บันทึก",
-    "Can not be edited from here due to insufficient permissions." : "ไม่สามารถแก้ไขได้จากที่นี่เนื่องจากสิทธิ์ไม่เพียงพอ",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "กับ PHP-FPM อาจใช้เวลา 5 นาทีสำหรับการเปลี่ยนแปลงที่ถูกนำมาใช้",
+    "Missing permissions to edit from here." : "สิทธิ์ในการแก้ไขส่วนนี้หายไป",
     "Settings" : "ตั้งค่า",
     "WebDAV" : "WebDAV",
     "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "ใช้ที่อยู่นี้เพื่อ <a href=\"%s\" target=\"_blank\">เข้าถึงไฟล์ของคุณผ่าน WebDAV</a>",
@@ -118,9 +113,16 @@ OC.L10N.register(
     "Select all" : "เลือกทั้งหมด",
     "Upload too large" : "ไฟล์ที่อัพโหลดมีขนาดใหญ่เกินไป",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ไฟล์ที่คุณพยายามที่จะอัพโหลดมีขนาดเกินกว่าขนาดสูงสุดที่กำหนดไว้ให้อัพโหลดได้สำหรับเซิร์ฟเวอร์นี้",
-    "Files are being scanned, please wait." : "ไฟล์กำลังอยู่ระหว่างการสแกน, กรุณารอสักครู่.",
-    "Currently scanning" : "ปัจจุบันกำลังสแกน",
     "No favorites" : "ไม่มีรายการโปรด",
-    "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณทำเครื่องหมายเป็นรายการโปรดจะปรากฏขึ้นที่นี่"
+    "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณทำเครื่องหมายเป็นรายการโปรดจะปรากฏขึ้นที่นี่",
+    "Text file" : "ไฟล์ข้อความ",
+    "New text file.txt" : "ไฟล์ข้อความใหม่ .txt",
+    "Changed by %2$s" : "เปลี่ยนแปลงโดย %2$s",
+    "Deleted by %2$s" : "ลบโดย %2$s",
+    "Restored by %2$s" : "กู้คืนโดย %2$s",
+    "You changed %1$s" : "คุณทำการเปลี่ยนแปลง %1$s",
+    "You created %1$s" : "คุณสร้าง %1$s",
+    "You deleted %1$s" : "คุณลบ %1$s ออก",
+    "You restored %1$s" : "คุณกู้คืน %1$s"
 },
 "nplurals=1; plural=0;");
