@@ -16,6 +16,9 @@ OC.L10N.register(
     "Not permitted to use authentication mechanism \"%s\"" : "Utilizzo del meccanismo di autenticazione \"%s\" non permesso",
     "Unsatisfied backend parameters" : "Parametri del motore non soddisfatti",
     "Unsatisfied authentication mechanism parameters" : "Parametri del meccanismo di autenticazione non soddisfatti",
+    "Insufficient data: %s" : "Dati insufficienti: %s",
+    "%s" : "%s",
+    "Storage with id \"%i\" is not user editable" : "L'archiviazione con ID \"%i\" non è modificabile dall'utente",
     "Personal" : "Personale",
     "System" : "Sistema",
     "Grant access" : "Concedi l'accesso",
@@ -26,13 +29,30 @@ OC.L10N.register(
     "Error generating key pair" : "Errore durante la generazione della coppia di chiavi",
     "Enable encryption" : "Abilita cifratura",
     "Enable previews" : "Abilita le anteprime",
+    "Enable sharing" : "Abilita condivisione",
     "Check for changes" : "Controlla le modifiche",
     "Never" : "Mai",
     "Once every direct access" : "Una volta per ogni accesso diretto",
-    "Every time the filesystem is used" : "Ogni volta che il filesystem viene utilizzato",
     "All users. Type to select user or group." : "Tutti gli utenti. Digita per selezionare utente o gruppo.",
     "(group)" : "(gruppo)",
+    "Admin defined" : "Definito dall'amministratore",
     "Saved" : "Salvato",
+    "Empty response from the server" : "Risposta vuota dal server",
+    "Couldn't access. Please logout and login to activate this mount point" : "Impossibile accedere. Chiudi la sessione e accedi nuovamente per attivare questo punto di mount",
+    "Couldn't get the information from the ownCloud server: {code} {type}" : "Impossibile ottenere le informazioni dal server ownCloud: {code} {type}",
+    "Couldn't get the list of external mount points: {type}" : "Impossibile ottenere l'elenco dei punti di mount esterni: {type}",
+    "There was an error with message: " : "Si è verificato un errore con il messaggio:",
+    "External mount error" : "Errore di mount esterno",
+    "external-storage" : "archiviazione-esterna",
+    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Impossibile ottenere l'elenco dei punti di mount delle unità di rete Windows: risposta vuota dal server",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alcuni dei punti di mount esterni configurati non sono connessi. Fai clic sulle righe rosse per ulteriori informazioni",
+    "Please enter the credentials for the {mount} mount" : "Digita le credenziali per montare {mount}",
+    "Username" : "Nome utente",
+    "Password" : "Password",
+    "Credentials saved" : "Credenziali salvate",
+    "Credentials saving failed" : "Salvataggio delle credenziali non riuscito",
+    "Credentials required" : "Credenziali richieste",
+    "Save" : "Salva",
     "Access key" : "Chiave di accesso",
     "Secret key" : "Chiave segreta",
     "Builtin" : "Integrata",
@@ -44,14 +64,12 @@ OC.L10N.register(
     "Client ID" : "ID client",
     "Client secret" : "Segreto del client",
     "OpenStack" : "OpenStack",
-    "Username" : "Nome utente",
-    "Password" : "Password",
     "Tenant name" : "Nome tenant",
     "Identity endpoint URL" : "URL endpoint delle identità",
     "Rackspace" : "Rackspace",
     "API key" : "Chiave API",
     "Username and password" : "Nome utente e password",
-    "Session credentials" : "Credenziali di sessione",
+    "Log-in credentials, save in session" : "Credenziali di accesso, salva nella sessione",
     "RSA public key" : "Chiave pubblica RSA",
     "Public key" : "Chiave pubblica",
     "Amazon S3" : "Amazon S3",
@@ -98,10 +116,12 @@ OC.L10N.register(
     "Authentication" : "Autenticazione",
     "Configuration" : "Configurazione",
     "Available for" : "Disponibile per",
+    "Add storage" : "Aggiungi archiviazione",
     "Advanced settings" : "Impostazioni avanzate",
     "Delete" : "Elimina",
-    "Add storage" : "Aggiungi archiviazione",
-    "Enable User External Storage" : "Abilita la memoria esterna dell'utente",
-    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente memoria esterna"
+    "Allow users to mount external storage" : "Consenti agli utenti di montare archiviazioni esterne",
+    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente archiviazione esterna",
+    "SMB / CIFS" : "SMB / CIFS",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alcuni dei punti di mount esterni configurati non sono connessi. Fai clic sulle righe rosse per ulteriori informazioni"
 },
 "nplurals=2; plural=(n != 1);");
