@@ -1,14 +1,18 @@
 OC.L10N.register(
     "files_external",
     {
+    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Nepavyko atsiųsti užklausos žymės. Patikrinkite savo programos raktą ir paslaptį.",
+    "Step 1 failed. Exception: %s" : "1 žingsnio klaida: %s",
+    "Step 2 failed. Exception: %s" : "2 žingsnio klaida: %s",
     "External storage" : "Išorinė saugykla",
     "Personal" : "Asmeniniai",
     "Grant access" : "Suteikti priėjimą",
     "Access granted" : "Priėjimas suteiktas",
     "Saved" : "Išsaugoti",
-    "None" : "Nieko",
     "Username" : "Prisijungimo vardas",
     "Password" : "Slaptažodis",
+    "Save" : "Išsaugoti",
+    "None" : "Nieko",
     "API key" : "API raktas",
     "Port" : "Prievadas",
     "Region" : "Regionas",
@@ -22,8 +26,7 @@ OC.L10N.register(
     "External Storage" : "Išorinės saugyklos",
     "Folder name" : "Katalogo pavadinimas",
     "Configuration" : "Konfigūracija",
-    "Delete" : "Ištrinti",
     "Add storage" : "Pridėti saugyklą",
-    "Enable User External Storage" : "Įjungti vartotojų išorines saugyklas"
+    "Delete" : "Ištrinti"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
