@@ -1,33 +1,50 @@
 <?php
 /**
- * ownCloud
+ * @author Adam Williamson <awilliam@redhat.com>
+ * @author Arthur Schiwon <blizzz@owncloud.com>
+ * @author Bart Visscher <bartv@thisnet.nl>
+ * @author Christopher Schäpers <kondou@ts.unde.re>
+ * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Lukas Reschke <lukas@owncloud.com>
+ * @author Michael Gapczynski <GapczynskiM@gmail.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Philipp Kapfer <philipp.kapfer@gmx.at>
+ * @author Robin Appelman <icewind@owncloud.com>
+ * @author Robin McCorkell <robin@mccorkell.me.uk>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @author Michael Gapczynski
- * @copyright 2012 Michael Gapczynski mtgap@owncloud.com
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @license AGPL-3.0
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3,
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License, version 3,
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 namespace OC\Files\Storage;
 
+use GuzzleHttp\Exception\RequestException;
+use Icewind\Streams\IteratorDirectory;
+use Icewind\Streams\RetryWrapper;
+
 set_include_path(get_include_path().PATH_SEPARATOR.
 	\OC_App::getAppPath('files_external').'/3rdparty/google-api-php-client/src');
-require_once 'Google_Client.php';
-require_once 'contrib/Google_DriveService.php';
+require_once 'Google/Client.php';
+require_once 'Google/Service/Drive.php';
 
 class Google extends \OC\Files\Storage\Common {
 
+	private $client;
 	private $id;
 	private $service;
 	private $driveFiles;
@@ -46,14 +63,19 @@ class Google extends \OC\Files\Storage\Common {
 			&& isset($params['client_id']) && isset($params['client_secret'])
 			&& isset($params['token'])
 		) {
-			$client = new \Google_Client();
-			$client->setClientId($params['client_id']);
-			$client->setClientSecret($params['client_secret']);
-			$client->setScopes(array('https://www.googleapis.com/auth/drive'));
-			$client->setUseObjects(true);
-			$client->setAccessToken($params['token']);
+			$this->client = new \Google_Client();
+			$this->client->setClientId($params['client_id']);
+			$this->client->setClientSecret($params['client_secret']);
+			$this->client->setScopes(array('https://www.googleapis.com/auth/drive'));
+			$this->client->setAccessToken($params['token']);
+			// if curl isn't available we're likely to run into
+			// https://github.com/google/google-api-php-client/issues/59
+			// - disable gzip to avoid it.
+			if (!function_exists('curl_version') || !function_exists('curl_exec')) {
+				$this->client->setClassConfig("Google_Http_Request", "disable_gzip", true);
+			}
 			// note: API connection is lazy
-			$this->service = new \Google_DriveService($client);
+			$this->service = new \Google_Service_Drive($this->client);
 			$token = json_decode($params['token'], true);
 			$this->id = 'google::'.substr($params['client_id'], 0, 30).$token['created'];
 		} else {
@@ -66,9 +88,10 @@ class Google extends \OC\Files\Storage\Common {
 	}
 
 	/**
-	 * Get the Google_DriveFile object for the specified path
+	 * Get the Google_Service_Drive_DriveFile object for the specified path.
+	 * Returns false on failure.
 	 * @param string $path
-	 * @return string
+	 * @return \Google_Service_Drive_DriveFile|false
 	 */
 	private function getDriveFile($path) {
 		// Remove leading and trailing slashes
@@ -96,7 +119,7 @@ class Google extends \OC\Files\Storage\Common {
 				if (isset($this->driveFiles[$path])) {
 					$parentId = $this->driveFiles[$path]->getId();
 				} else {
-					$q = "title='".$name."' and '".$parentId."' in parents and trashed = false";
+					$q = "title='" . str_replace("'","\\'", $name) . "' and '" . str_replace("'","\\'", $parentId) . "' in parents and trashed = false";
 					$result = $this->service->files->listFiles(array('q' => $q))->getItems();
 					if (!empty($result)) {
 						// Google Drive allows files with the same name, ownCloud doesn't
@@ -115,7 +138,7 @@ class Google extends \OC\Files\Storage\Common {
 							$pathWithoutExt = substr($path, 0, $pos);
 							$file = $this->getDriveFile($pathWithoutExt);
 							if ($file) {
-								// Switch cached Google_DriveFile to the correct index
+								// Switch cached Google_Service_Drive_DriveFile to the correct index
 								unset($this->driveFiles[$pathWithoutExt]);
 								$this->driveFiles[$path] = $file;
 								$parentId = $file->getId();
@@ -133,9 +156,9 @@ class Google extends \OC\Files\Storage\Common {
 	}
 
 	/**
-	 * Set the Google_DriveFile object in the cache
+	 * Set the Google_Service_Drive_DriveFile object in the cache
 	 * @param string $path
-	 * @param Google_DriveFile|false $file
+	 * @param Google_Service_Drive_DriveFile|false $file
 	 */
 	private function setDriveFile($path, $file) {
 		$path = trim($path, '/');
@@ -188,10 +211,10 @@ class Google extends \OC\Files\Storage\Common {
 		if (!$this->is_dir($path)) {
 			$parentFolder = $this->getDriveFile(dirname($path));
 			if ($parentFolder) {
-				$folder = new \Google_DriveFile();
+				$folder = new \Google_Service_Drive_DriveFile();
 				$folder->setTitle(basename($path));
 				$folder->setMimeType(self::FOLDER);
-				$parent = new \Google_ParentReference();
+				$parent = new \Google_Service_Drive_ParentReference();
 				$parent->setId($parentFolder->getId());
 				$folder->setParents(array($parent));
 				$result = $this->service->files->insert($folder);
@@ -205,6 +228,9 @@ class Google extends \OC\Files\Storage\Common {
 	}
 
 	public function rmdir($path) {
+		if (!$this->isDeletable($path)) {
+			return false;
+		}
 		if (trim($path, '/') === '') {
 			$dir = $this->opendir($path);
 			if(is_resource($dir)) {
@@ -225,8 +251,6 @@ class Google extends \OC\Files\Storage\Common {
 	}
 
 	public function opendir($path) {
-		// Remove leading and trailing slashes
-		$path = trim($path, '/');
 		$folder = $this->getDriveFile($path);
 		if ($folder) {
 			$files = array();
@@ -237,12 +261,13 @@ class Google extends \OC\Files\Storage\Common {
 				if ($pageToken !== true) {
 					$params['pageToken'] = $pageToken;
 				}
-				$params['q'] = "'".$folder->getId()."' in parents and trashed = false";
+				$params['q'] = "'" . str_replace("'","\\'", $folder->getId()) . "' in parents and trashed = false";
 				$children = $this->service->files->listFiles($params);
 				foreach ($children->getItems() as $child) {
 					$name = $child->getTitle();
 					// Check if this is a Google Doc i.e. no extension in name
-					if ($child->getFileExtension() === ''
+					$extension = $child->getFileExtension();
+					if (empty($extension)
 						&& $child->getMimeType() !== self::FOLDER
 					) {
 						$name .= '.'.$this->getGoogleDocExtension($child->getMimeType());
@@ -263,15 +288,14 @@ class Google extends \OC\Files\Storage\Common {
 							$this->onDuplicateFileDetected($filepath);
 						}
 					} else {
-						// Cache the Google_DriveFile for future use
+						// Cache the Google_Service_Drive_DriveFile for future use
 						$this->setDriveFile($filepath, $child);
 						$files[] = $name;
 					}
 				}
 				$pageToken = $children->getNextPageToken();
 			}
-			\OC\Files\Stream\Dir::register('google'.$path, $files);
-			return opendir('fakedir://google'.$path);
+			return IteratorDirectory::wrap($files);
 		} else {
 			return false;
 		}
@@ -287,7 +311,7 @@ class Google extends \OC\Files\Storage\Common {
 				// Check if this is a Google Doc
 				if ($this->getMimeType($path) !== $file->getMimeType()) {
 					// Return unknown file size
-					$stat['size'] = \OC\Files\SPACE_UNKNOWN;
+					$stat['size'] = \OCP\Files\FileInfo::SPACE_UNKNOWN;
 				} else {
 					$stat['size'] = $file->getFileSize();
 				}
@@ -347,23 +371,44 @@ class Google extends \OC\Files\Storage\Common {
 	public function rename($path1, $path2) {
 		$file = $this->getDriveFile($path1);
 		if ($file) {
+			$newFile = $this->getDriveFile($path2);
 			if (dirname($path1) === dirname($path2)) {
-				$file->setTitle(basename(($path2)));
+				if ($newFile) {
+					// rename to the name of the target file, could be an office file without extension
+					$file->setTitle($newFile->getTitle());
+				} else {
+					$file->setTitle(basename(($path2)));
+				}
 			} else {
 				// Change file parent
 				$parentFolder2 = $this->getDriveFile(dirname($path2));
 				if ($parentFolder2) {
-					$parent = new \Google_ParentReference();
+					$parent = new \Google_Service_Drive_ParentReference();
 					$parent->setId($parentFolder2->getId());
 					$file->setParents(array($parent));
 				} else {
 					return false;
 				}
 			}
+			// We need to get the object for the existing file with the same
+			// name (if there is one) before we do the patch. If oldfile
+			// exists and is a directory we have to delete it before we
+			// do the rename too.
+			$oldfile = $this->getDriveFile($path2);
+			if ($oldfile && $this->is_dir($path2)) {
+				$this->rmdir($path2);
+				$oldfile = false;
+			}
 			$result = $this->service->files->patch($file->getId(), $file);
 			if ($result) {
 				$this->setDriveFile($path1, false);
 				$this->setDriveFile($path2, $result);
+				if ($oldfile && $newFile) {
+					// only delete if they have a different id (same id can happen for part files)
+					if ($newFile->getId() !== $oldfile->getId()) {
+						$this->service->files->delete($oldfile->getId());
+					}
+				}
 			}
 			return (bool)$result;
 		} else {
@@ -392,14 +437,30 @@ class Google extends \OC\Files\Storage\Common {
 						$downloadUrl = $file->getDownloadUrl();
 					}
 					if (isset($downloadUrl)) {
-						$request = new \Google_HttpRequest($downloadUrl, 'GET', null, null);
-						$httpRequest = \Google_Client::$io->authenticatedRequest($request);
-						if ($httpRequest->getResponseHttpCode() == 200) {
-							$tmpFile = \OC_Helper::tmpFile($ext);
-							$data = $httpRequest->getResponseBody();
-							file_put_contents($tmpFile, $data);
-							return fopen($tmpFile, $mode);
+						$request = new \Google_Http_Request($downloadUrl, 'GET', null, null);
+						$httpRequest = $this->client->getAuth()->sign($request);
+						// the library's service doesn't support streaming, so we use Guzzle instead
+						$client = \OC::$server->getHTTPClientService()->newClient();
+						try {
+							$response = $client->get($downloadUrl, [
+								'headers' => $httpRequest->getRequestHeaders(),
+								'stream' => true,
+								'verify' => __DIR__ . '/../3rdparty/google-api-php-client/src/Google/IO/cacerts.pem',
+							]);
+						} catch (RequestException $e) {
+							if(!is_null($e->getResponse())) {
+								if ($e->getResponse()->getStatusCode() === 404) {
+									return false;
+								} else {
+									throw $e;
+								}
+							} else {
+								throw $e;
+							}
 						}
+
+						$handle = $response->getBody();
+						return RetryWrapper::wrap($handle);
 					}
 				}
 				return false;
@@ -415,7 +476,7 @@ class Google extends \OC\Files\Storage\Common {
 			case 'x+':
 			case 'c':
 			case 'c+':
-				$tmpFile = \OC_Helper::tmpFile($ext);
+				$tmpFile = \OCP\Files::tmpFile($ext);
 				\OC\Files\Stream\Close::registerCallback($tmpFile, array($this, 'writeBack'));
 				if ($this->file_exists($path)) {
 					$source = $this->fopen($path, 'rb');
@@ -431,26 +492,74 @@ class Google extends \OC\Files\Storage\Common {
 			$path = self::$tempFiles[$tmpFile];
 			$parentFolder = $this->getDriveFile(dirname($path));
 			if ($parentFolder) {
-				// TODO Research resumable upload
-				$mimetype = \OC_Helper::getMimeType($tmpFile);
-				$data = file_get_contents($tmpFile);
+				$mimetype = \OC::$server->getMimeTypeDetector()->detect($tmpFile);
 				$params = array(
-					'data' => $data,
 					'mimeType' => $mimetype,
+					'uploadType' => 'media'
 				);
 				$result = false;
+
+				$chunkSizeBytes = 10 * 1024 * 1024;
+
+				$useChunking = false;
+				$size = filesize($tmpFile);
+				if ($size > $chunkSizeBytes) {
+					$useChunking = true;
+				} else {
+					$params['data'] = file_get_contents($tmpFile);
+				}
+
 				if ($this->file_exists($path)) {
 					$file = $this->getDriveFile($path);
-					$result = $this->service->files->update($file->getId(), $file, $params);
+					$this->client->setDefer($useChunking);
+					$request = $this->service->files->update($file->getId(), $file, $params);
 				} else {
-					$file = new \Google_DriveFile();
+					$file = new \Google_Service_Drive_DriveFile();
 					$file->setTitle(basename($path));
 					$file->setMimeType($mimetype);
-					$parent = new \Google_ParentReference();
+					$parent = new \Google_Service_Drive_ParentReference();
 					$parent->setId($parentFolder->getId());
 					$file->setParents(array($parent));
-					$result = $this->service->files->insert($file, $params);
+					$this->client->setDefer($useChunking);
+					$request = $this->service->files->insert($file, $params);
 				}
+
+				if ($useChunking) {
+					// Create a media file upload to represent our upload process.
+					$media = new \Google_Http_MediaFileUpload(
+						$this->client,
+						$request,
+						'text/plain',
+						null,
+						true,
+						$chunkSizeBytes
+					);
+					$media->setFileSize($size);
+
+					// Upload the various chunks. $status will be false until the process is
+					// complete.
+					$status = false;
+					$handle = fopen($tmpFile, 'rb');
+					while (!$status && !feof($handle)) {
+						$chunk = fread($handle, $chunkSizeBytes);
+						$status = $media->nextChunk($chunk);
+					}
+
+					// The final value of $status will be the data from the API for the object
+					// that has been uploaded.
+					$result = false;
+					if ($status !== false) {
+						$result = $status;
+					}
+
+					fclose($handle);
+				} else {
+					$result = $request;
+				}
+
+				// Reset to the client to execute requests immediately in the future.
+				$this->client->setDefer(false);
+
 				if ($result) {
 					$this->setDriveFile($path, $result);
 				}
@@ -476,7 +585,8 @@ class Google extends \OC\Files\Storage\Common {
 				// Download as .odp is not available
 				return 'application/pdf';
 			} else {
-				return $mimetype;
+				// use extension-based detection, could be an encrypted file
+				return parent::getMimeType($path);
 			}
 		} else {
 			return false;
@@ -493,7 +603,10 @@ class Google extends \OC\Files\Storage\Common {
 		$result = false;
 		if ($file) {
 			if (isset($mtime)) {
-				$file->setModifiedDate($mtime);
+				// This is just RFC3339, but frustratingly, GDrive's API *requires*
+				// the fractions portion be present, while no handy PHP constant
+				// for RFC3339 or ISO8601 includes it. So we do it ourselves.
+				$file->setModifiedDate(date('Y-m-d\TH:i:s.uP', $mtime));
 				$result = $this->service->files->patch($file->getId(), $file, array(
 					'setModifiedDate' => true,
 				));
@@ -503,9 +616,9 @@ class Google extends \OC\Files\Storage\Common {
 		} else {
 			$parentFolder = $this->getDriveFile(dirname($path));
 			if ($parentFolder) {
-				$file = new \Google_DriveFile();
+				$file = new \Google_Service_Drive_DriveFile();
 				$file->setTitle(basename($path));
-				$parent = new \Google_ParentReference();
+				$parent = new \Google_Service_Drive_ParentReference();
 				$parent->setId($parentFolder->getId());
 				$file->setParents(array($parent));
 				$result = $this->service->files->insert($file);
@@ -591,11 +704,7 @@ class Google extends \OC\Files\Storage\Common {
 	 * check if curl is installed
 	 */
 	public static function checkDependencies() {
-		if (function_exists('curl_init')) {
-			return true;
-		} else {
-			return array('curl');
-		}
+		return true;
 	}
 
 }
