@@ -1,16 +1,17 @@
 <?php
 /**
  * @author Arthur Schiwon <blizzz@owncloud.com>
+ * @author Jesús Macias <jmacias@solidgear.es>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Philipp Kapfer <philipp.kapfer@gmx.at>
  * @author Robin Appelman <icewind@owncloud.com>
- * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
+ * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,13 +30,17 @@
 
 namespace OC\Files\Storage;
 
+use Icewind\SMB\Exception\ConnectException;
 use Icewind\SMB\Exception\Exception;
+use Icewind\SMB\Exception\ForbiddenException;
 use Icewind\SMB\Exception\NotFoundException;
 use Icewind\SMB\NativeServer;
 use Icewind\SMB\Server;
 use Icewind\Streams\CallbackWrapper;
 use Icewind\Streams\IteratorDirectory;
+use OC\Cache\CappedMemoryCache;
 use OC\Files\Filesystem;
+use OCP\Files\StorageNotAvailableException;
 
 class SMB extends Common {
 	/**
@@ -48,10 +53,15 @@ class SMB extends Common {
 	 */
 	protected $share;
 
+	/**
+	 * @var string
+	 */
+	protected $root;
+
 	/**
 	 * @var \Icewind\SMB\FileInfo[]
 	 */
-	protected $statCache = array();
+	protected $statCache;
 
 	public function __construct($params) {
 		if (isset($params['host']) && isset($params['user']) && isset($params['password']) && isset($params['share'])) {
@@ -72,6 +82,7 @@ class SMB extends Common {
 		} else {
 			throw new \Exception('Invalid configuration');
 		}
+		$this->statCache = new CappedMemoryCache();
 	}
 
 	/**
@@ -95,26 +106,36 @@ class SMB extends Common {
 	/**
 	 * @param string $path
 	 * @return \Icewind\SMB\IFileInfo
+	 * @throws StorageNotAvailableException
 	 */
 	protected function getFileInfo($path) {
-		$path = $this->buildPath($path);
-		if (!isset($this->statCache[$path])) {
-			$this->statCache[$path] = $this->share->stat($path);
+		try {
+			$path = $this->buildPath($path);
+			if (!isset($this->statCache[$path])) {
+				$this->statCache[$path] = $this->share->stat($path);
+			}
+			return $this->statCache[$path];
+		} catch (ConnectException $e) {
+			throw new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 		}
-		return $this->statCache[$path];
 	}
 
 	/**
 	 * @param string $path
 	 * @return \Icewind\SMB\IFileInfo[]
+	 * @throws StorageNotAvailableException
 	 */
 	protected function getFolderContents($path) {
-		$path = $this->buildPath($path);
-		$files = $this->share->dir($path);
-		foreach ($files as $file) {
-			$this->statCache[$path . '/' . $file->getName()] = $file;
+		try {
+			$path = $this->buildPath($path);
+			$files = $this->share->dir($path);
+			foreach ($files as $file) {
+				$this->statCache[$path . '/' . $file->getName()] = $file;
+			}
+			return $files;
+		} catch (ConnectException $e) {
+			throw new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 		}
-		return $files;
 	}
 
 	/**
@@ -152,6 +173,10 @@ class SMB extends Common {
 			}
 		} catch (NotFoundException $e) {
 			return false;
+		} catch (ForbiddenException $e) {
+			return false;
+		} catch (ConnectException $e) {
+			throw new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 		}
 	}
 
@@ -190,7 +215,10 @@ class SMB extends Common {
 					return $this->share->read($fullPath);
 				case 'w':
 				case 'wb':
-					return $this->share->write($fullPath);
+					$source = $this->share->write($fullPath);
+					return CallBackWrapper::wrap($source, null, null, function () use ($fullPath) {
+						unset($this->statCache[$fullPath]);
+					});
 				case 'a':
 				case 'ab':
 				case 'r+':
@@ -220,7 +248,8 @@ class SMB extends Common {
 					}
 					$source = fopen($tmpFile, $mode);
 					$share = $this->share;
-					return CallBackWrapper::wrap($source, null, null, function () use ($tmpFile, $fullPath, $share) {
+					return CallbackWrapper::wrap($source, null, null, function () use ($tmpFile, $fullPath, $share) {
+						unset($this->statCache[$fullPath]);
 						$share->put($tmpFile, $fullPath);
 						unlink($tmpFile);
 					});
@@ -228,6 +257,10 @@ class SMB extends Common {
 			return false;
 		} catch (NotFoundException $e) {
 			return false;
+		} catch (ForbiddenException $e) {
+			return false;
+		} catch (ConnectException $e) {
+			throw new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 		}
 	}
 
@@ -246,20 +279,34 @@ class SMB extends Common {
 			return true;
 		} catch (NotFoundException $e) {
 			return false;
+		} catch (ForbiddenException $e) {
+			return false;
+		} catch (ConnectException $e) {
+			throw new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 		}
 	}
 
 	public function touch($path, $time = null) {
-		if (!$this->file_exists($path)) {
-			$fh = $this->share->write($this->buildPath($path));
-			fclose($fh);
-			return true;
+		try {
+			if (!$this->file_exists($path)) {
+				$fh = $this->share->write($this->buildPath($path));
+				fclose($fh);
+				return true;
+			}
+			return false;
+		} catch (ConnectException $e) {
+			throw new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 		}
-		return false;
 	}
 
 	public function opendir($path) {
-		$files = $this->getFolderContents($path);
+		try {
+			$files = $this->getFolderContents($path);
+		} catch (NotFoundException $e) {
+			return false;
+		} catch (ForbiddenException $e) {
+			return false;
+		}
 		$names = array_map(function ($info) {
 			/** @var \Icewind\SMB\IFileInfo $info */
 			return $info->getName();
@@ -272,6 +319,8 @@ class SMB extends Common {
 			return $this->getFileInfo($path)->isDirectory() ? 'dir' : 'file';
 		} catch (NotFoundException $e) {
 			return false;
+		} catch (ForbiddenException $e) {
+			return false;
 		}
 	}
 
@@ -280,6 +329,8 @@ class SMB extends Common {
 		try {
 			$this->share->mkdir($path);
 			return true;
+		} catch (ConnectException $e) {
+			throw new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
 		} catch (Exception $e) {
 			return false;
 		}
@@ -291,6 +342,32 @@ class SMB extends Common {
 			return true;
 		} catch (NotFoundException $e) {
 			return false;
+		} catch (ForbiddenException $e) {
+			return false;
+		} catch (ConnectException $e) {
+			throw new StorageNotAvailableException($e->getMessage(), $e->getCode(), $e);
+		}
+	}
+
+	public function isReadable($path) {
+		try {
+			$info = $this->getFileInfo($path);
+			return !$info->isHidden();
+		} catch (NotFoundException $e) {
+			return false;
+		} catch (ForbiddenException $e) {
+			return false;
+		}
+	}
+
+	public function isUpdatable($path) {
+		try {
+			$info = $this->getFileInfo($path);
+			return !$info->isHidden() && !$info->isReadOnly();
+		} catch (NotFoundException $e) {
+			return false;
+		} catch (ForbiddenException $e) {
+			return false;
 		}
 	}
 
@@ -298,7 +375,22 @@ class SMB extends Common {
 	 * check if smbclient is installed
 	 */
 	public static function checkDependencies() {
-		$smbClientExists = (bool)\OC_Helper::findBinaryPath('smbclient');
-		return $smbClientExists ? true : array('smbclient');
+		return (
+			(bool)\OC_Helper::findBinaryPath('smbclient')
+			|| Server::NativeAvailable()
+		) ? true : ['smbclient'];
+	}
+
+	/**
+	 * Test a storage for availability
+	 *
+	 * @return bool
+	 */
+	public function test() {
+		try {
+			return parent::test();
+		} catch (Exception $e) {
+			return false;
+		}
 	}
 }
