@@ -7,10 +7,10 @@
  * @author Lukas Reschke <lukas@owncloud.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <icewind@owncloud.com>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Roeland Jago Douma <rullzer@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -28,6 +28,11 @@
  */
 namespace OCA\Files_Sharing;
 
+use OC\Files\Filesystem;
+use OC\Files\View;
+use OCP\Files\NotFoundException;
+use OCP\User;
+
 class Helper {
 
 	public static function registerHooks() {
@@ -48,6 +53,7 @@ class Helper {
 	 * @param string $token string share token
 	 * @param string $relativePath optional path relative to the share
 	 * @param string $password optional password
+	 * @return array
 	 */
 	public static function setupFromToken($token, $relativePath = null, $password = null) {
 		\OC_User::setIncognitoMode(true);
@@ -71,10 +77,11 @@ class Helper {
 			\OCP\JSON::checkUserExists($rootLinkItem['uid_owner']);
 			\OC_Util::tearDownFS();
 			\OC_Util::setupFS($rootLinkItem['uid_owner']);
-			$path = \OC\Files\Filesystem::getPath($linkItem['file_source']);
 		}
 
-		if ($path === null) {
+		try {
+			$path = Filesystem::getPath($linkItem['file_source']);
+		} catch (NotFoundException $e) {
 			\OCP\Util::writeLog('share', 'could not resolve linkItem', \OCP\Util::DEBUG);
 			\OC_Response::setStatus(404);
 			\OCP\JSON::error(array('success' => false));
@@ -98,8 +105,8 @@ class Helper {
 
 		$basePath = $path;
 
-		if ($relativePath !== null && \OC\Files\Filesystem::isReadable($basePath . $relativePath)) {
-			$path .= \OC\Files\Filesystem::normalizePath($relativePath);
+		if ($relativePath !== null && Filesystem::isReadable($basePath . $relativePath)) {
+			$path .= Filesystem::normalizePath($relativePath);
 		}
 
 		return array(
@@ -124,7 +131,7 @@ class Helper {
 				$newHash = '';
 				if(\OC::$server->getHasher()->verify($password, $linkItem['share_with'], $newHash)) {
 					// Save item id in session for future requests
-					\OC::$server->getSession()->set('public_link_authenticated', $linkItem['id']);
+					\OC::$server->getSession()->set('public_link_authenticated', (string) $linkItem['id']);
 
 					/**
 					 * FIXME: Migrate old hashes to new hash format
@@ -154,7 +161,7 @@ class Helper {
 		else {
 			// not authenticated ?
 			if ( ! \OC::$server->getSession()->exists('public_link_authenticated')
-				|| \OC::$server->getSession()->get('public_link_authenticated') !== $linkItem['id']) {
+				|| \OC::$server->getSession()->get('public_link_authenticated') !== (string)$linkItem['id']) {
 				return false;
 			}
 		}
@@ -163,11 +170,11 @@ class Helper {
 
 	public static function getSharesFromItem($target) {
 		$result = array();
-		$owner = \OC\Files\Filesystem::getOwner($target);
-		\OC\Files\Filesystem::initMountPoints($owner);
-		$info = \OC\Files\Filesystem::getFileInfo($target);
-		$ownerView = new \OC\Files\View('/'.$owner.'/files');
-		if ( $owner != \OCP\User::getUser() ) {
+		$owner = Filesystem::getOwner($target);
+		Filesystem::initMountPoints($owner);
+		$info = Filesystem::getFileInfo($target);
+		$ownerView = new View('/'.$owner.'/files');
+		if ( $owner != User::getUser() ) {
 			$path = $ownerView->getPath($info['fileid']);
 		} else {
 			$path = $target;
@@ -200,15 +207,34 @@ class Helper {
 		return $result;
 	}
 
+	/**
+	 * get the UID of the owner of the file and the path to the file relative to
+	 * owners files folder
+	 *
+	 * @param $filename
+	 * @return array
+	 * @throws \OC\User\NoUserException
+	 */
 	public static function getUidAndFilename($filename) {
-		$uid = \OC\Files\Filesystem::getOwner($filename);
-		\OC\Files\Filesystem::initMountPoints($uid);
-		if ( $uid != \OCP\User::getUser() ) {
-			$info = \OC\Files\Filesystem::getFileInfo($filename);
-			$ownerView = new \OC\Files\View('/'.$uid.'/files');
-			$filename = $ownerView->getPath($info['fileid']);
+		$uid = Filesystem::getOwner($filename);
+		$userManager = \OC::$server->getUserManager();
+		// if the user with the UID doesn't exists, e.g. because the UID points
+		// to a remote user with a federated cloud ID we use the current logged-in
+		// user. We need a valid local user to create the share
+		if (!$userManager->userExists($uid)) {
+			$uid = User::getUser();
 		}
-		return array($uid, $filename);
+		Filesystem::initMountPoints($uid);
+		if ( $uid != User::getUser() ) {
+			$info = Filesystem::getFileInfo($filename);
+			$ownerView = new View('/'.$uid.'/files');
+			try {
+				$filename = $ownerView->getPath($info['fileid']);
+			} catch (NotFoundException $e) {
+				$filename = null;
+			}
+		}
+		return [$uid, $filename];
 	}
 
 	/**
@@ -236,7 +262,7 @@ class Helper {
 	 *
 	 * @param string $path
 	 * @param array $excludeList
-	 * @param \OC\Files\View $view
+	 * @param View $view
 	 * @return string $path
 	 */
 	public static function generateUniqueTarget($path, $excludeList, $view) {
@@ -246,7 +272,7 @@ class Helper {
 		$dir = $pathinfo['dirname'];
 		$i = 2;
 		while ($view->file_exists($path) || in_array($path, $excludeList)) {
-			$path = \OC\Files\Filesystem::normalizePath($dir . '/' . $name . ' ('.$i.')' . $ext);
+			$path = Filesystem::normalizePath($dir . '/' . $name . ' ('.$i.')' . $ext);
 			$i++;
 		}
 
@@ -276,19 +302,23 @@ class Helper {
 	/**
 	 * get default share folder
 	 *
+	 * @param \OC\Files\View
 	 * @return string
 	 */
-	public static function getShareFolder() {
+	public static function getShareFolder($view = null) {
+		if ($view === null) {
+			$view = Filesystem::getView();
+		}
 		$shareFolder = \OC::$server->getConfig()->getSystemValue('share_folder', '/');
-		$shareFolder = \OC\Files\Filesystem::normalizePath($shareFolder);
+		$shareFolder = Filesystem::normalizePath($shareFolder);
 
-		if (!\OC\Files\Filesystem::file_exists($shareFolder)) {
+		if (!$view->file_exists($shareFolder)) {
 			$dir = '';
 			$subdirs = explode('/', $shareFolder);
 			foreach ($subdirs as $subdir) {
 				$dir = $dir . '/' . $subdir;
-				if (!\OC\Files\Filesystem::is_dir($dir)) {
-					\OC\Files\Filesystem::mkdir($dir);
+				if (!$view->is_dir($dir)) {
+					$view->mkdir($dir);
 				}
 			}
 		}
@@ -306,20 +336,4 @@ class Helper {
 		\OC::$server->getConfig()->setSystemValue('share_folder', $shareFolder);
 	}
 
-	/**
-	 * remove protocol from URL
-	 *
-	 * @param string $url
-	 * @return string
-	 */
-	public static function removeProtocolFromUrl($url) {
-		if (strpos($url, 'https://') === 0) {
-			return substr($url, strlen('https://'));
-		} else if (strpos($url, 'http://') === 0) {
-			return substr($url, strlen('http://'));
-		}
-
-		return $url;
-	}
-
 }
