@@ -12,6 +12,8 @@ OC.L10N.register(
     "failed!" : "neúspešné!",
     "Saved" : "Uložené",
     "There was a problem saving your changes. Click to resume editing." : "Vyskytol sa problém s ukladaním zmien. Kliknite pre pokračovanie v úpravách.",
-    "An error occurred!" : "Vyskytla sa chyba!"
+    "An error occurred!" : "Vyskytla sa chyba!",
+    "Text file" : "Textový súbor",
+    "New text file.txt" : "Nový text file.txt"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
