@@ -4,8 +4,8 @@ OC.L10N.register(
     "Could not revert: %s" : "Kunne ikke genskabe: %s",
     "Versions" : "Versioner",
     "Failed to revert {file} to revision {timestamp}." : "Kunne ikke tilbagerulle {file} til den tidligere udgave: {timestamp}.",
-    "More versions..." : "Flere versioner...",
+    "Restore" : "Gendan",
     "No other versions available" : "Ingen andre versioner tilgængelig",
-    "Restore" : "Gendan"
+    "More versions..." : "Flere versioner..."
 },
 "nplurals=2; plural=(n != 1);");
