@@ -1,13 +1,14 @@
 <?php
 $TRANSLATIONS = array(
-"Welcome to %s" => "Bienllegáu a %s",
-"Your personal web services. All your files, contacts, calendar and more, in one place." => "La to web de servicios personal. Tolos tos ficheros, contautos, calendariu y más, nun llugar.",
 "Get the apps to sync your files" => "Obtener les aplicaciones pa sincronizar ficheros",
+"Desktop client" => "Cliente d'escritoriu",
+"Android app" => "Aplicación d'Android",
+"iOS app" => "Aplicación d'iOS",
 "Connect your desktop apps to %s" => "Coneuta les tos aplicaciones d'escritoriu a %s",
 "Connect your Calendar" => "Coneuta'l to Calendariu",
 "Connect your Contacts" => "Coneuta los tos Contautos",
-"Access files via WebDAV" => "Ficheru d'accesu vía WebDAV",
 "Documentation" => "Documentación",
+"Access files via WebDAV" => "Ficheru d'accesu vía WebDAV",
 "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Hai más información na <a target=\"_blank\" href=\"%s\">documentación y nel nuesu <a target=\"_blank\" href=\"http://owncloud.org\">sitiu web</a>."
 );
 $PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
