@@ -3,6 +3,9 @@ $TRANSLATIONS = array(
 "Could not load template" => "Não foi possível carregar o modelo",
 "Saved" => "Salvo",
 "Reset" => "Reiniciar",
+"An error occurred" => "Ocorreu um erro",
+"Sharing email - public link shares (HTML)" => "Compartilhando email - link de compartilhamento público (HTML)",
+"Sharing email - public link shares (plain text fallback)" => "Compartilhando email - link de compartilhamento público (alternativa em texto simples)",
 "Sharing email (HTML)" => "Compartilhando email (HTML)",
 "Sharing email (plain text fallback)" => "Compartilhando email (recurso texto simples)",
 "Lost password mail" => "Perdeu senha do email",
