@@ -11,7 +11,6 @@ OC.L10N.register(
     "Updated \"%s\" to %s" : "Actualizado «%s» a %s",
     "Repair warning: " : "Aviso de arranxo:",
     "Repair error: " : "Arranxar o erro:",
-    "Following incompatible apps have been disabled: %s" : "As seguintes aplicacións incompatíbeis foron desactivadas: %s",
     "Following apps have been disabled: %s" : "As seguintes aplicacións foron desactivadas: %s",
     "File is too big" : "O ficheiro é grande de máis",
     "Invalid file provided" : "O ficheiro fornecido non é válido",
@@ -22,6 +21,10 @@ OC.L10N.register(
     "No crop data provided" : "Non indicou como recortar",
     "No valid crop data provided" : "Os datos cortados fornecidos non son válidos",
     "Crop is not square" : "O corte non é cadrado",
+    "Couldn't reset password because the token is invalid" : "No, foi posíbel restabelecer o contrasinal, a marca non é correcta",
+    "Couldn't send reset email. Please make sure your username is correct." : "Non foi posíbel enviar o correo do restabelecemento. Asegúrese de que o nome de usuario é o correcto.",
+    "%s password reset" : "Restabelecer o contrasinal %s",
+    "Couldn't send reset email. Please contact your administrator." : "Non foi posíbel enviar o correo do restabelecemento. Póñase en contacto co administrador.",
     "Sunday" : "domingo",
     "Monday" : "luns",
     "Tuesday" : "martes",
@@ -69,8 +72,8 @@ OC.L10N.register(
     "Dec." : "dec.",
     "Settings" : "Axustes",
     "Saving..." : "Gardando...",
+    "Dismiss" : "Desbotar",
     "seconds ago" : "segundos atrás",
-    "Couldn't send reset email. Please contact your administrator." : "Non foi posíbel enviar o correo do restabelecemento. Póñase en contacto co administrador.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "A ligazón para restabelecer o seu contrasinal foi enviada ao seu correo. Se non a recibe nun prazo razoábel de tempo, vexa o seu cartafol de correo lixo. <br> Se non está ali pregúntelle ao administrador local.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Os seus ficheiros están cifrados. Se non activou a chave de recuperación, non haberá maneira de recuperar os datos após o restabelecemento do contrasinal. <br />Se non está seguro de que facer, póñase en contacto co administrador antes de continuar. <br /> Confirma que quere continuar?",
     "I know what I'm doing" : "Sei o estou a facer",
@@ -100,24 +103,21 @@ OC.L10N.register(
     "Strong password" : "Contrasinal forte",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "O servidor aínda non está configurado correctamente para permitir a sincronización de ficheiros, semella que a interface WebDAV non está a funcionar.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor non ten conexión activa a Internet. Isto significa que algunhas características como a montaxe do almacenamento externo, as notificacións sobre actualizacións ou a instalación de engadidos de terceiros non funcionarán. Así mesmo,  o acceso remoto a ficheiros e enviar correos de notificación poderían non funcionar. Suxerímoslle que active a conexión a Internet para este servidor se quere ter todos estes servizos.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "O directorio de datos e os seus ficheiros probabelmente son accesíbeis desde a Internet. O ficheiro .htaccess non funciona. Recomendámoslle que configure o seu servidor web de xeito que o directorio de datos non sexa accesíbel ou que mova o directorio de datos fora do directorio root do servidor web.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Non foi configurada a memoria cache. Para mellorar o rendemento configure unha «memcache», se está dispoñíbel. Pode atopar máis información na nosa <a href=\"{docLink}\">documentación</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom non é lexíbel por PHP xa que esta absolutamente desaconsellado por razóns de seguridade. Pode atopar máis información na nosa <a href=\"{docLink}\">documentación</a>.",
     "Error occurred while checking server setup" : "Aconteceu un erro mentras se comprobaba a configuración do servidor",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "O directorio de datos e os seus ficheiros probabelmente son accesíbeis desde a Internet. O ficheiro .htaccess non funciona. Recomendámoslle que configure o seu servidor web de xeito que o directorio de datos non sexa accesíbel ou que mova o directorio de datos fora do directorio root do servidor web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "A cabeceira HTTP «{header}» non está configurada como igual a «{expected}». Isto é un posíbel risco para a seguridade ou a intimidade, recomendámoslle que axuste esta opción.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "A cabeceira HTTP «Strict-Transport-Security» non está configurada para menos de «{seconds}» segundos . Para mellorar a seguridade, recomendámoslle que active o uso de HTTPS, tal e como se describe nos <a href=\"{docUrl}\">consellos de seguridade</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Está accedendo a este sitio a través de HTTP. Suxerímoslle que configure o seu servidor para requirir, no seu canto, o uso de HTTPS, tal e como se descrine nos<a href=\"{docUrl}\">consellos de seguridade</a>.",
     "Shared" : "Compartido",
     "Shared with {recipients}" : "Compartido con {recipients}",
     "Error" : "Erro",
     "Error while sharing" : "Produciuse un erro ao compartir",
     "Error while unsharing" : "Produciuse un erro ao deixar de compartir",
-    "Error while changing permissions" : "Produciuse un erro ao cambiar os permisos",
     "Error setting expiration date" : "Produciuse un erro ao definir a data de caducidade",
     "The public link will expire no later than {days} days after it is created" : "A ligazón pública caducará, a máis tardar, {days} días após a súa creación",
     "Set expiration date" : "Definir a data de caducidade",
     "Expiration" : "Caducidade",
     "Expiration date" : "Data de caducidade",
+    "Choose a password for the public link" : "Escolla un contrasinal para a ligazón pública",
     "Sending ..." : "Enviando...",
     "Email sent" : "Correo enviado",
     "Resharing is not allowed" : "Non se permite volver compartir",
@@ -125,13 +125,11 @@ OC.L10N.register(
     "Link" : "Ligazón",
     "Password protect" : "Protexido con contrasinal",
     "Password" : "Contrasinal",
-    "Choose a password for the public link" : "Escolla un contrasinal para a ligazón pública",
     "Allow editing" : "Permitir a edición",
     "Email link to person" : "Enviar ligazón por correo",
     "Send" : "Enviar",
     "Shared with you and the group {group} by {owner}" : "Compartido con vostede e co grupo {group} por {owner}",
     "Shared with you by {owner}" : "Compartido con vostede por {owner}",
-    "Shared in {item} with {user}" : "Compartido en {item} con {user}",
     "group" : "grupo",
     "remote" : "remoto",
     "notify by email" : "notificar por correo",
@@ -148,9 +146,10 @@ OC.L10N.register(
     "Share with users or groups …" : "Compartir con usuarios ou grupos ...",
     "Share with users, groups or remote users …" : "Compartir con usuarios, grupos ou usuarios remotos ...",
     "Warning" : "Aviso",
+    "Delete" : "Eliminar",
+    "Rename" : "Renomear",
     "The object type is not specified." : "Non se especificou o tipo de obxecto.",
     "Enter new" : "Introduza o novo",
-    "Delete" : "Eliminar",
     "Add" : "Engadir",
     "Edit tags" : "Editar etiquetas",
     "Error loading dialog template: {error}" : "Produciuse un erro ao cargar o modelo do dialogo: {error}",
@@ -161,20 +160,11 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Ola {name}, o tempo é {weather}",
     "Hello {name}" : "Ola {name}",
     "_download %n file_::_download %n files_" : ["descargar %n ficheiro","descargar %n ficheiros"],
-    "{version} is available. Get more information on how to update." : "{version} está dispoñíbel. Obteña máis información sobre como actualizar.",
     "Updating {productName} to version {version}, this may take a while." : "Actualizando {productName} a versión {version}, isto pode levar un anaco.",
     "Please reload the page." : "Volva cargar a páxina.",
     "The update was unsuccessful. " : "Fracasou a actualización.",
     "The update was successful. There were warnings." : "A actualización realizouse correctamente. Houbo algún aviso.",
     "The update was successful. Redirecting you to ownCloud now." : "A actualización realizouse correctamente. Redirixíndoo agora á ownCloud.",
-    "Couldn't reset password because the token is invalid" : "No, foi posíbel restabelecer o contrasinal, a marca non é correcta",
-    "Couldn't send reset email. Please make sure your username is correct." : "Non foi posíbel enviar o correo do restabelecemento. Asegúrese de que o nome de usuario é o correcto.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Non foi posíbel enviar o correo do restabelecemento. Semella que este correo non corresponde con este nome de usuario. Póñase en contacto co administrador.",
-    "%s password reset" : "Restabelecer o contrasinal %s",
-    "Use the following link to reset your password: {link}" : "Usa a seguinte ligazón para restabelecer o contrasinal: {link}",
-    "New password" : "Novo contrasinal",
-    "New Password" : "Novo contrasinal",
-    "Reset password" : "Restabelecer o contrasinal",
     "Searching other places" : "Buscando noutros lugares",
     "Personal" : "Persoal",
     "Users" : "Usuarios",
@@ -232,6 +222,7 @@ OC.L10N.register(
     "Finishing …" : "Rematando ...",
     "Need help?" : "Precisa axuda?",
     "See the documentation" : "Vexa a documentación",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ola,<br><br>só facerlle saber que %s compartiu <strong>%s</strong> con vostede.<br><a href=\"%s\">Véxao!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación require JavaScript para un correcto funcionamento. {linkstart}Active  JavaScript{linkend} e volva cargar a páxina.",
     "Log out" : "Desconectar",
     "Search" : "Buscar",
@@ -240,15 +231,16 @@ OC.L10N.register(
     "An internal error occured." : "Produciuse un erro interno.",
     "Please try again or contact your administrator." : "Ténteo de novo ou póñase en contacto co administrador.",
     "Log in" : "Acceder",
-    "remember" : "lembrar",
     "Alternative Logins" : "Accesos alternativos",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ola,<br><br>só facerlle saber que %s compartiu <strong>%s</strong> con vostede.<br><a href=\"%s\">Véxao!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Usa a seguinte ligazón para restabelecer o contrasinal: {link}",
+    "New password" : "Novo contrasinal",
+    "New Password" : "Novo contrasinal",
+    "Reset password" : "Restabelecer o contrasinal",
     "This ownCloud instance is currently in single user mode." : "Esta instancia do ownCloud está actualmente en modo de usuario único.",
     "This means only administrators can use the instance." : "Isto significa que só os administradores poden utilizar a instancia.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Póñase en contacto co administrador do sistema se persiste esta mensaxe ou se aparece de forma inesperada.",
     "Thank you for your patience." : "Grazas pola súa paciencia.",
     "You are accessing the server from an untrusted domain." : "Esta accedendo desde un dominio non fiábel.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Póñase en contacto co administrador. Se vostede é administrador desta instancia, configure o parámetro «trusted_domain» en config/config.php. Dispón dun exemplo de configuración en config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependendo da súa configuración, como administrador vostede podería utilizar o botón de embaixo para confiar neste dominio.",
     "Add \"%s\" as trusted domain" : "Engadir «%s» como dominio de confianza",
     "App update required" : "É necesario actualizar a aplicación",
@@ -260,6 +252,8 @@ OC.L10N.register(
     "Start update" : "Iniciar a actualización",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos de espera nas instalacións grandes, no seu lugar pode executar a seguinte orde desde o directorio de instalación:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s atopase en modo de mantemento, isto pode levar un anaco.",
-    "This page will refresh itself when the %s instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia de %s estea dispoñíbel de novo."
+    "This page will refresh itself when the %s instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia de %s estea dispoñíbel de novo.",
+    "Error loading file picker template: {error}" : "Produciuse un erro ao cargar o modelo do selector: {error}",
+    "Password can not be changed. Please contact your administrator." : "Non é posíbel cambiar o contrasinal. Póñase en contacto co administrador."
 },
 "nplurals=2; plural=(n != 1);");
