@@ -36,7 +36,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "L'aplicació no es pot instal·lar perquè hi ha codi no autoritzat en l'aplicació",
     "App can't be installed because it is not compatible with this version of ownCloud" : "L'aplicació no es pot instal·lar perquè no és compatible amb aquesta versió d'ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicació no es pot instal·lar perquè conté l'etiqueta <shipped>vertader</shipped> que no es permet per aplicacions no enviades",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "L'aplicació no es pot instal·lar perquè la versió a info.xml/version no és la mateixa que la versió indicada des de la botiga d'aplicacions",
     "Application is not enabled" : "L'aplicació no està habilitada",
     "Authentication error" : "Error d'autenticació",
     "Token expired. Please reload page." : "El testimoni ha expirat. Torneu a carregar la pàgina.",
@@ -58,7 +57,6 @@ OC.L10N.register(
     "%s shared »%s« with you" : "%s ha compartit »%s« amb tu",
     "Sharing %s failed, because the file does not exist" : "Ha fallat en compartir %s, perquè el fitxer no existeix",
     "You are not allowed to share %s" : "No se us permet compartir %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Ha fallat en compartir %s, perquè l'usuari %s és el propietari de l'element",
     "Sharing %s failed, because the user %s does not exist" : "Ha fallat en compartir %s, perquè l'usuari %s no existeix",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Ha fallat en compartir %s, perquè l'usuari %s no és membre de cap grup dels que %s és membre",
     "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
@@ -74,14 +72,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El rerefons de compartició %s ha d'implementar la interfície OCP\\Share_Backend",
     "Sharing backend %s not found" : "El rerefons de compartició %s no s'ha trobat",
     "Sharing backend for %s not found" : "El rerefons de compartició per a %s no s'ha trobat",
-    "Sharing %s failed, because the user %s is the original sharer" : "Ha fallat en compartir %s perquè l'usuari %s és qui comparteix inicialment",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Ha fallat en compartir %s perquè els permisos excedeixen els permesos per a %s",
     "Sharing %s failed, because resharing is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir de nou",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ha fallat en compartir %s, perquè el rerefons de compartir per %s no pot trobar la seva font",
     "Sharing %s failed, because the file could not be found in the file cache" : "Ha fallat en compartir %s, perquè el fitxer no s'ha trobat en el fitxer cau",
     "Could not find category \"%s\"" : "No s'ha trobat la categoria \"%s\"",
     "Apps" : "Aplicacions",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Només els caràcters següents estan permesos en el nom d'usuari: \"a-z\", \"A-Z\", \"0-9\" i \"_.@-\"",
     "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
     "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
     "The username is already being used" : "El nom d'usuari ja està en ús",
@@ -101,12 +97,11 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Demaneu a l'administrador que reinici el servidor web.",
     "PostgreSQL >= 9 required" : "Es requereix PostgreSQL >= 9",
     "Please upgrade your database version" : "Actualitzeu la versió de la base de dades",
-    "Error occurred while checking PostgreSQL version" : "Hi ha hagut un error en comprovar la versió de PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Assegureu-vos que teniu PostgreSQL >= 9 o comproveu els registres per més informació quant a l'error",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Canvieu els permisos a 0770 per tal que la carpeta no es pugui llistar per altres usuaris.",
     "Data directory (%s) is readable by other users" : "La carpeta de dades (%s) és llegible per altres usuaris",
     "Data directory (%s) is invalid" : "La carpeta de dades (%s) no és vàlida",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Comproveu que la carpeta de dades contingui un fitxer \".ocdata\" a la seva arrel.",
-    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir un bloqueig tipus %d a \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir un bloqueig tipus %d a \"%s\".",
+    "Storage not available" : "Emmagatzemament no disponible"
 },
 "nplurals=2; plural=(n != 1);");
