@@ -16,7 +16,7 @@ OC.L10N.register(
     "Library %s with a version lower than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih rendah dari %s - versi yang tersedia %s.",
     "Following platforms are supported: %s" : "Berikut adalah platform yang didukung: %s",
     "ownCloud %s or higher is required." : "Diperlukan ownCloud %s atau yang lebih tinggi.",
-    "ownCloud with a version lower than %s is required." : "Diperlukan ownCloud dengan versi yang lebih rendah dari %s.",
+    "ownCloud %s or lower is required." : "ownCloud %s atau yang lebih rendah diperlukan.",
     "Help" : "Bantuan",
     "Personal" : "Pribadi",
     "Users" : "Pengguna",
@@ -38,15 +38,18 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n menit yang lalu"],
     "seconds ago" : "beberapa detik yang lalu",
     "web services under your control" : "layanan web dalam kendali anda",
+    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul dengan id: %s tidak ada. Mohon aktifkan modul tersebut di pengaturan aplikasi Anda atau hubungi administrator.",
     "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
     "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
     "4-byte characters are not supported in file names" : "Karakter 4 byte tidak didukung dalam nama berkas",
     "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
     "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
     "File name is too long" : "Nama berkas terlalu panjang",
+    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
     "Can't read file" : "Tidak dapat membaca berkas",
     "App directory already exists" : "Direktori Apl sudah ada",
     "Can't create app folder. Please fix permissions. %s" : "Tidak dapat membuat folder apl. Silakan perbaiki perizinan. %s",
+    "Archive does not contain a directory named %s" : "Arsip tidak berisi direktori yang bernama %s",
     "No source specified when installing app" : "Tidak ada sumber yang ditentukan saat menginstal apl",
     "No href specified when installing app from http" : "Href tidak ditentukan saat menginstal apl dari http",
     "No path specified when installing app from local file" : "Lokasi tidak ditentukan saat menginstal apl dari berkas lokal",
@@ -56,7 +59,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Apl tidak dapat diinstal karena terdapat kode yang tidak diizinkan didalam Apl",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Apl tidak dapat diinstal karena tidak kompatibel dengan versi ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Apl tidak dapat diinstal karena mengandung tag <shipped>true</shipped> yang tidak diizinkan untuk apl yang bukan bawaan.",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Apl tidak dapat diinstal karena versi di info.xml/versi tidak sama dengan versi yang dilansir dari toko apl",
     "Application is not enabled" : "Aplikasi tidak diaktifkan",
     "Authentication error" : "Galat saat otentikasi",
     "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
@@ -64,17 +66,11 @@ OC.L10N.register(
     "%s enter the database username." : "%s masukkan nama pengguna basis data.",
     "%s enter the database name." : "%s masukkan nama basis data.",
     "%s you may not use dots in the database name" : "%s anda tidak boleh menggunakan karakter titik pada nama basis data",
-    "MS SQL username and/or password not valid: %s" : "Nama pengguna dan/atau sandi MySQL tidak sah: %s",
-    "You need to enter either an existing account or the administrator." : "Anda harus memasukkan akun yang sudah ada atau administrator.",
-    "MySQL/MariaDB username and/or password not valid" : "Nama pengguna dan/atau sandi MySQL/MariaDB tidak sah",
-    "DB Error: \"%s\"" : "Kesalahan Basis Data: \"%s\"",
-    "Offending command was: \"%s\"" : "Perintah yang bermasalah: \"%s\"",
-    "MySQL/MariaDB user '%s'@'localhost' exists already." : "'%s'@'localhost' pengguna MySQL/MariaDB sudah ada.",
-    "Drop this user from MySQL/MariaDB" : "Drop pengguna ini dari MySQL/MariaDB",
-    "MySQL/MariaDB user '%s'@'%%' already exists" : "'%s'@'%%' pengguna MySQL/MariaDB sudah ada.",
-    "Drop this user from MySQL/MariaDB." : "Drop pengguna ini dari MySQL/MariaDB.",
     "Oracle connection could not be established" : "Koneksi Oracle tidak dapat dibuat",
     "Oracle username and/or password not valid" : "Nama pengguna dan/atau sandi Oracle tidak sah",
+    "DB Error: \"%s\"" : "Kesalahan Basis Data: \"%s\"",
+    "Offending command was: \"%s\"" : "Perintah yang bermasalah: \"%s\"",
+    "You need to enter either an existing account or the administrator." : "Anda harus memasukkan akun yang sudah ada atau administrator.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Perintah yang bermasalah: \"%s\", nama pengguna: %s, sandi: %s",
     "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau sandi PostgreSQL tidak valid",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X tidak didukung dan %s tidak akan bekerja dengan baik pada platform ini. Gunakan dengan resiko Anda sendiri!",
@@ -84,15 +80,17 @@ OC.L10N.register(
     "Set an admin username." : "Tetapkan nama pengguna admin.",
     "Set an admin password." : "Tetapkan sandi admin.",
     "Can't create or write into the data directory %s" : "Tidak dapat membuat atau menulis kedalam direktori data %s",
+    "Invalid Federated Cloud ID" : "Federated Cloud ID tidak sah",
     "%s shared »%s« with you" : "%s membagikan »%s« dengan anda",
     "%s via %s" : "%s melalui %s",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Gagal berbagi %s, karena backend tidak mengizinkan berbagi dengan tipe %i",
     "Sharing %s failed, because the file does not exist" : "Gagal membagikan %s, karena berkas tidak ada",
     "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Gagal membagikan %s, karena pengguna %s adalah pemilik item",
+    "Sharing %s failed, because you can not share with yourself" : "Berbagi %s gagal, karena Anda tidak dapat berbagi dengan diri sendiri",
     "Sharing %s failed, because the user %s does not exist" : "Gagal membagikan %s, karena pengguna %s tidak ada",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Gagal membagikan %s, karena pengguna %s bukan merupakan anggota dari grup yang %s ikuti",
     "Sharing %s failed, because this item is already shared with %s" : "Gagal membagkan %s, karena item ini sudah dibagikan dengan %s",
+    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
     "Sharing %s failed, because the group %s does not exist" : "Gagal membagikan %s, karena grup %s tidak ada",
     "Sharing %s failed, because %s is not a member of the group %s" : "Gagal membagikan %s, karena %s bukan anggota dari grup %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Anda perlu memberikan sandi untuk membuat tautan publik, hanya tautan yang terlindungi yang diizinkan",
@@ -107,13 +105,13 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
     "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
-    "Sharing %s failed, because the user %s is the original sharer" : "Gagal berbagi %s. karena pengguna %s adalah yang membagikan pertama",
+    "Sharing failed, because the user %s is the original sharer" : "Berbagi gagal, karena pengguna %s adalah pembagi awal",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Gagal membagikan %s, karena izin melebihi izin yang diberikan untuk %s",
     "Sharing %s failed, because resharing is not allowed" : "Gagal berbagi %s, karena membagikan ulang tidak diizinkan",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Berbagi %s gagal, karena backend berbagi untuk %s tidak menemukan sumbernya",
     "Sharing %s failed, because the file could not be found in the file cache" : "Gagal berbagi %s, karena berkas tidak ditemukan di berkas cache",
     "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Hanya karakter berikut yang diizinkan dalam nama pengguna: \"a-z\", \"A-Z\", \"0-9\", dan \"_.@-\"",
+    "Apps" : "Aplikasi",
     "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
     "A valid password must be provided" : "Tuliskan sandi yang valid",
     "The username is already being used" : "Nama pengguna ini telah digunakan",
@@ -140,14 +138,13 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
     "PostgreSQL >= 9 required" : "Diperlukan PostgreSQL >= 9",
     "Please upgrade your database version" : "Mohon perbarui versi basis data Anda",
-    "Error occurred while checking PostgreSQL version" : "Terjadi kesalahan saat memeriksa versi PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Pastikan bahwa Anda memiliki PostgreSQL >= 9 atau periksa log untuk informasi lebih lanjut tentang kesalahan",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
     "Data directory (%s) is readable by other users" : "Direktori data (%s) dapat dibaca oleh pengguna lain",
     "Data directory (%s) must be an absolute path" : "Direktori Data (%s) harus berupa lokasi lengkap",
     "Check the value of \"datadirectory\" in your configuration" : "Periksa nilai \"datadirectory\" di konfigurasi Anda",
     "Data directory (%s) is invalid" : "Direktori data (%s) tidak sah",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Mohon periksa apakah direktori data berisi sebuah berkas \".ocdata\" di direktori induknya.",
-    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
+    "Storage not available" : "Penyimpanan tidak tersedia"
 },
 "nplurals=1; plural=0;");
