@@ -4,6 +4,7 @@ OC.L10N.register(
     "Help" : "یارمەتی",
     "Users" : "به‌كارهێنه‌ر",
     "Admin" : "به‌ڕێوه‌به‌ری سه‌ره‌كی",
-    "web services under your control" : "ڕاژه‌ی وێب له‌ژێر چاودێریت دایه"
+    "web services under your control" : "ڕاژه‌ی وێب له‌ژێر چاودێریت دایه",
+    "Apps" : "به‌رنامه‌كان"
 },
 "nplurals=2; plural=(n != 1);");
