@@ -56,10 +56,11 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Arkiver av type %s støttes ikke",
     "Failed to open archive when installing app" : "Klarte ikke å åpne arkiv ved installering av app",
     "App does not provide an info.xml file" : "App-en inneholder ikke filen info.xml",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Signatur kunne ikke sjekkes. Kontakt app-utvikleren og sjekk admin-bildet.",
     "App can't be installed because of not allowed code in the App" : "App kan ikke installeres på grunn av ulovlig kode i appen.",
     "App can't be installed because it is not compatible with this version of ownCloud" : "App kan ikke installeres fordi den ikke er kompatibel med denne versjonen av ownCloud",
-    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App kan ikke installeres fordi den inneholder tag <shipped>true</shipped> som ikke er tillatt for apper som ikke leveres med systemet",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "App kan ikke installeres fordi versjonen i info.xml/version ikke er den samme som versjonen som rapporteres fra app-butikken",
+    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App kan ikke installeres fordi den er merket med <shipped>true</shipped> som ikke er tillatt for apper som ikke leveres med systemet",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "App kan ikke installeres fordi versjonen i info.xml ikke er den samme som versjonen som rapporteres fra app-butikken",
     "Application is not enabled" : "Applikasjon er ikke påslått",
     "Authentication error" : "Autentikasjonsfeil",
     "Token expired. Please reload page." : "Symbol utløpt. Vennligst last inn siden på nytt.",
@@ -87,7 +88,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling av %s feilet, fordi serveren ikke tillater delinger fra type %i",
     "Sharing %s failed, because the file does not exist" : "Deling av %s feilet, fordi filen ikke eksisterer",
     "You are not allowed to share %s" : "Du har ikke lov til å dele %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Deling av %s feilet, fordi brukeren %s er eier av elementet",
+    "Sharing %s failed, because you can not share with yourself" : "Deling av %s feilet fordi du ikke kan dele med deg selv",
     "Sharing %s failed, because the user %s does not exist" : "Deling av %s feilet, fordi brukeren %s ikke finnes",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Deling av %s feilet, fordi brukeren %s ikke er medlem av noen grupper som %s er medlem av",
     "Sharing %s failed, because this item is already shared with %s" : "Deling av %s feilet, fordi dette elementet allerede er delt med %s",
@@ -96,6 +97,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Deling av %s feilet, fordi %s ikke er medlem av gruppen %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Du må oppgi et passord for å lage en offentlig lenke. Bare beskyttede lenker er tillatt",
     "Sharing %s failed, because sharing with links is not allowed" : "Deling av %s feilet, fordi deling med lenker ikke er tillatt",
+    "Not allowed to create a federated share with the same user" : "Ikke tillatt å opprette en Sammenknyttet sky-deling med den samme brukeren",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling %s feilet, fant ikke %s, kanskje servern er utilgjengelig for øyeblikket.",
     "Share type %s is not valid for %s" : "Delingstype %s er ikke gyldig for %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Setting av tillatelser for %s feilet, fordi tillatelsene gikk ut over tillatelsene som er gitt til %s",
@@ -106,15 +108,19 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delings-server %s må implementere grensesnittet OCP\\Share_Backend",
     "Sharing backend %s not found" : "Delings-server %s ikke funnet",
     "Sharing backend for %s not found" : "Delings-server for %s ikke funnet",
-    "Sharing %s failed, because the user %s is the original sharer" : "Deling av %s feilet, fordi brukeren %s er den opprinnelige eieren",
+    "Sharing failed, because the user %s is the original sharer" : "Deling feilet fordi brukeren %s er den som delte opprinnelig",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deling av %s feilet, fordi tillatelsene går utover tillatelsene som er gitt til %s",
     "Sharing %s failed, because resharing is not allowed" : "Deling av %s feilet, fordi videre-deling ikke er tillatt",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling av %s feilet, fordi delings-serveren for %s ikke kunne finne kilden",
     "Sharing %s failed, because the file could not be found in the file cache" : "Deling av %s feilet, fordi filen ikke ble funnet i fil-mellomlageret",
+    "Cannot increase permissions of %s" : "Kan ikke øke tillatelser for %s",
+    "Expiration date is in the past" : "Utløpsdato er tilbake i tid",
+    "Cannot set expiration date more than %s days in the future" : "Kan ikke sette utløpsdato mer enn  %s dager fram i tid",
     "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
     "Apps" : "Apper",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-'\"",
     "A valid username must be provided" : "Oppgi et gyldig brukernavn",
+    "Username contains whitespace at the beginning or at the end" : "Brukernavn inneholder blanke på begynnelsen eller slutten",
     "A valid password must be provided" : "Oppgi et gyldig passord",
     "The username is already being used" : "Brukernavnet er allerede i bruk",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen databasedrivere (sqlite, mysql, or postgresql) installert.",
@@ -140,14 +146,17 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Be server-administratoren om å starte web-serveren på nytt.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kreves",
     "Please upgrade your database version" : "Vennligst oppgrader versjonen av databasen din",
-    "Error occurred while checking PostgreSQL version" : "Det oppstod en feil ved sjekking av PostgreSQL-versjon",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Sjekk at du har PostgreSQL >= 9 eller sjekk loggene for mer informasjon om feilen",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endre tillatelsene til 0770 slik at mappen ikke kan listes av andre brukere.",
     "Data directory (%s) is readable by other users" : "Data-mappen (%s) kan leses av andre brukere",
     "Data directory (%s) must be an absolute path" : "Datamappen (%s) må være en absolutt sti",
     "Check the value of \"datadirectory\" in your configuration" : "Sjekk verdien for \"datadirectory\" i konfigurasjonen din",
     "Data directory (%s) is invalid" : "Data-mappe (%s) er ugyldig",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Sjekk at det ligger en fil \".ocdata\" i roten av data-mappen.",
-    "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\".",
+    "Storage unauthorized. %s" : "Lager uautorisert: %s",
+    "Storage incomplete configuration. %s" : "Ikke komplett oppsett for lager. %s",
+    "Storage connection error. %s" : "Tilkoblingsfeil for lager. %s",
+    "Storage not available" : "Lagringsplass ikke tilgjengelig",
+    "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s"
 },
 "nplurals=2; plural=(n != 1);");
