@@ -58,7 +58,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "L'aplicacion pòt pas èsser installada perque conten de còde pas autorizat",
     "App can't be installed because it is not compatible with this version of ownCloud" : "L'aplicacion pòt pas èsser installada perque es pas compatibla amb aquesta version d'ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicacion pòt pas èsser installada perque conten la balisa <shipped>true</shipped> qu'es pas autorizada per las aplicacions non inclusas per defaut",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "L'aplicacion pòt pas èsser installada perque la version dins info.xml/version es pas identica a la qu'es indicada sus l'app store",
     "Application is not enabled" : "L'aplicacion es pas activada",
     "Authentication error" : "Error d'autentificacion",
     "Token expired. Please reload page." : "La session a expirat. Recargatz la pagina.",
@@ -86,7 +85,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Lo partiment de %s a fracassat perque l’infrastructura autoriza pas los partiments de tipe %i",
     "Sharing %s failed, because the file does not exist" : "Lo partiment de %s a fracassat perque lo fichièr existís pas",
     "You are not allowed to share %s" : "Sètz pas autorizat a partejar %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Lo partiment de %s a fracassat perque l'utilizaire %s es lo proprietari de l'objècte",
+    "Sharing %s failed, because you can not share with yourself" : "Lo partiment de %s a fracassat perque podètz pas partejar amb vos-meteis",
     "Sharing %s failed, because the user %s does not exist" : "Lo partiment de %s a fracassat perque l'utilizaire %s existís pas",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Lo partiment de %s a fracassat perque l'utilizaire %s es pas membre de cap de grop al qual %s aparten",
     "Sharing %s failed, because this item is already shared with %s" : "Lo partiment de %s a fracassat perque aqueste objècte es ja partejat amb %s",
@@ -105,14 +104,13 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Lo servici de partiment %s deu implementar l'interfàcia OCP\\Share_Backend",
     "Sharing backend %s not found" : "Servici de partiment %s pas trobat",
     "Sharing backend for %s not found" : "Lo servici de partiment per %s es introbable",
-    "Sharing %s failed, because the user %s is the original sharer" : "Lo partiment de %s a fracassat perque l'utilizaire %s es l'utilizaire a l'origina del partiment.",
+    "Sharing failed, because the user %s is the original sharer" : "Lo partiment a fracassat perque l'utilizaire %s es lo proprietari original",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Lo partiment de %s a fracassat perque las permissions depassan las que son acordadas a %s",
     "Sharing %s failed, because resharing is not allowed" : "Lo partiment de %s a fracassat perque lo repartatge es pas autorizat",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Lo partiment de %s a fracassat perque la font es pas estada trobada pel partiment %s.",
     "Sharing %s failed, because the file could not be found in the file cache" : "Lo partiment de %s a fracassat perque lo fichièr es pas estat trobat dins los fichièrs meses en escondedor.",
     "Could not find category \"%s\"" : "Impossible de trobar la categoria \"%s\"",
     "Apps" : "Aplicacions",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Sols los caractèrs seguents son autorizats dins un nom d'utilizaire : \"a-z\", \"A-Z\", \"0-9\", e \"_.@-\"",
     "A valid username must be provided" : "Un nom d'utilizaire valid deu èsser sasit",
     "A valid password must be provided" : "Un senhal valid deu èsser sasit",
     "The username is already being used" : "Aqueste nom d'utilizaire es ja utilizat",
@@ -139,14 +137,13 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Demandatz a vòstre administrator servidor que reavie lo servidor web.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requesit",
     "Please upgrade your database version" : "Metètz a jorn vòstre gestionari de banca de donadas",
-    "Error occurred while checking PostgreSQL version" : "Una error s’es produsida pendent la recuperacion del numèro de version de PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Verificatz qu'utilizatz PostgreSQL >= 9 , o agachatz dins lo jornal d’error per mai d’informacions sus aqueste problèma",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambiatz las permissions del repertòri en mòde 0770 per fin que son contengut pòsca èsser listat pels autres utilizaires.",
     "Data directory (%s) is readable by other users" : "Lo repertòri de donadas (%s) es legible pels autres utilizaires",
     "Data directory (%s) must be an absolute path" : "Lo camin del dorsièr de donadas (%s) deu èsser absolut",
     "Check the value of \"datadirectory\" in your configuration" : "Verificatz la valor de \"datadirectory\" dins vòstra configuracion",
     "Data directory (%s) is invalid" : "Lo repertòri (%s) es pas valid",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Verificatz que lo repertòri de donadas conten un fichièr \".ocdata\" a sa raiç.",
-    "Could not obtain lock type %d on \"%s\"." : "Impossible d'obténer lo varrolhatge de tipe %d sus \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Impossible d'obténer lo varrolhatge de tipe %d sus \"%s\".",
+    "Storage not available" : "Supòrt d'emmagazinatge pas disponible"
 },
 "nplurals=2; plural=(n > 1);");
