@@ -35,6 +35,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n minut sedan","%n minuter sedan"],
     "seconds ago" : "sekunder sedan",
     "web services under your control" : "webbtjänster under din kontroll",
+    "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
     "App directory already exists" : "Appens mapp finns redan",
     "Can't create app folder. Please fix permissions. %s" : "Kan inte skapa appens mapp. Var god åtgärda rättigheterna. %s",
     "No source specified when installing app" : "Ingen källa angiven vid installation av app ",
@@ -46,7 +47,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Appen kan inte installeras eftersom att den innehåller otillåten kod",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Appen kan inte installeras eftersom att den inte är kompatibel med denna version av ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Appen kan inte installeras eftersom att den innehåller etiketten <shipped>true</shipped> vilket inte är tillåtet för icke inkluderade appar",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Appen kan inte installeras eftersom versionen i info.xml inte är samma som rapporteras från app store",
     "Application is not enabled" : "Applikationen är inte aktiverad",
     "Authentication error" : "Fel vid autentisering",
     "Token expired. Please reload page." : "Ogiltig token. Ladda om sidan.",
@@ -66,11 +66,11 @@ OC.L10N.register(
     "Set an admin username." : "Ange ett användarnamn för administratören.",
     "Set an admin password." : "Ange ett administratörslösenord.",
     "Can't create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
+    "Invalid Federated Cloud ID" : "Ogiltigt \"Federated Cloud\"-ID",
     "%s shared »%s« with you" : "%s delade »%s« med dig",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Misslyckades dela ut %s då backend inte tillåter delningar från typ %i",
     "Sharing %s failed, because the file does not exist" : "Delning av %s misslyckades på grund av att filen inte existerar",
     "You are not allowed to share %s" : "Du har inte rätt att dela %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Delning %s misslyckades därför att användaren %s är den som äger objektet",
     "Sharing %s failed, because the user %s does not exist" : "Delning %s misslyckades därför att användaren %s inte existerar",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Delning %s misslyckades därför att användaren %s inte är medlem i någon utav de grupper som %s är medlem i",
     "Sharing %s failed, because this item is already shared with %s" : "Delning %s misslyckades därför att objektet redan är delat med %s",
@@ -78,6 +78,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Delning %s misslyckades därför att %s inte ingår i gruppen %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Du måste ange ett lösenord för att skapa en offentlig länk, endast skyddade länkar är tillåtna",
     "Sharing %s failed, because sharing with links is not allowed" : "Delning %s misslyckades därför att delning utav länkar inte är tillåtet",
+    "Not allowed to create a federated share with the same user" : "Ej tillåtet att skapa en förbundsdelning med samma användare",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Misslyckades dela ut %s, kan inte hitta %s, kanske är servern inte åtkomlig för närvarande.",
     "Share type %s is not valid for %s" : "Delningstyp %s är inte giltig för %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Misslyckades att sätta rättigheter för %s därför att rättigheterna överskrider de som är tillåtna för %s",
@@ -87,14 +88,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delningsgränssnittet %s måste implementera gränssnittet OCP\\Share_Backend",
     "Sharing backend %s not found" : "Delningsgränssnittet %s hittades inte",
     "Sharing backend for %s not found" : "Delningsgränssnittet för %s hittades inte",
-    "Sharing %s failed, because the user %s is the original sharer" : "Delning %s misslyckades därför att användaren %s är den som delade objektet först",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Delning %s misslyckades därför att rättigheterna överskrider de rättigheter som är tillåtna för %s",
     "Sharing %s failed, because resharing is not allowed" : "Delning %s misslyckades därför att vidaredelning inte är tillåten",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Delning %s misslyckades därför att delningsgränsnittet för %s inte kunde hitta sin källa",
     "Sharing %s failed, because the file could not be found in the file cache" : "Delning %s misslyckades därför att filen inte kunde hittas i filcachen",
     "Could not find category \"%s\"" : "Kunde inte hitta kategorin \"%s\"",
     "Apps" : "Program",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Endast följande tecken är tillåtna i ett användarnamn: \"az\", \"AZ\", \"0-9\", och \"_ @ -.\"",
     "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
     "A valid password must be provided" : "Ett giltigt lösenord måste anges",
     "The username is already being used" : "Användarnamnet används redan",
@@ -114,12 +113,11 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Vänligen be din serveradministratör att starta om webservern.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 krävs",
     "Please upgrade your database version" : "Vänligen uppgradera din databas-version",
-    "Error occurred while checking PostgreSQL version" : "Ett fel inträffade vid kontroll utav PostgreSQL-version",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Vänligen säkerställ att du har PostgreSQL >= 9 eller kolla loggarna för mer information om felet",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Vänligen ändra rättigheterna till 0770 så att katalogen inte kan listas utav andra användare.",
     "Data directory (%s) is readable by other users" : "Datakatalogen (%s) kan läsas av andra användare",
     "Data directory (%s) is invalid" : "Datakatlogen (%s) är ogiltig",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Vänligen kontrollera att datakatalogen innehåller filen \".ocdata\" i rooten.",
-    "Could not obtain lock type %d on \"%s\"." : "Kan inte hämta låstyp %d på \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Kan inte hämta låstyp %d på \"%s\".",
+    "Storage not available" : "Lagring inte tillgänglig"
 },
 "nplurals=2; plural=(n != 1);");
