@@ -16,7 +16,7 @@ OC.L10N.register(
     "Library %s with a version lower than %s is required - available version %s." : "Потрібна бібліотека %s версії менш ніж %s, встановлена версія %s.",
     "Following platforms are supported: %s" : "Підтримуються наступні платформи: %s",
     "ownCloud %s or higher is required." : "Потрібен ownCloud %s або вище.",
-    "ownCloud with a version lower than %s is required." : "Потрібна версія ownCloud нижче %s.",
+    "ownCloud %s or lower is required." : "Потрібна версія %s ownCloud або нижча.",
     "Help" : "Допомога",
     "Personal" : "Особисте",
     "Users" : "Користувачі",
@@ -53,7 +53,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Неможливо встановити додаток. Він містить заборонений код",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Неможливо встановити додаток, він є несумісним з даною версією ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Неможливо встановити додаток, оскільки він містить параметр <shipped>true</shipped> заборонений додаткам, що не входять в поставку ",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Неможливо встановити додаток. Версія в файлі info.xml/version не співпадає з заявленою в магазині додатків",
     "Application is not enabled" : "Додаток не увімкнений",
     "Authentication error" : "Помилка автентифікації",
     "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
@@ -61,17 +60,11 @@ OC.L10N.register(
     "%s enter the database username." : "%s введіть ім'я користувача бази даних.",
     "%s enter the database name." : "%s введіть назву бази даних.",
     "%s you may not use dots in the database name" : "%s не можна використовувати крапки в назві бази даних",
-    "MS SQL username and/or password not valid: %s" : "MS SQL ім'я користувача та/або пароль не дійсні: %s",
-    "You need to enter either an existing account or the administrator." : "Вам потрібно ввести або існуючий обліковий запис або administrator.",
-    "MySQL/MariaDB username and/or password not valid" : "MySQL/MariaDB ім'я користувача та/або пароль не дійсні",
-    "DB Error: \"%s\"" : "Помилка БД: \"%s\"",
-    "Offending command was: \"%s\"" : "Команда, що викликала проблему: \"%s\"",
-    "MySQL/MariaDB user '%s'@'localhost' exists already." : "Користувач MySQL/MariaDB '%s'@'localhost' вже існує.",
-    "Drop this user from MySQL/MariaDB" : "Видалити цього користувача з MySQL/MariaDB",
-    "MySQL/MariaDB user '%s'@'%%' already exists" : "Користувач MySQL/MariaDB '%s'@'%%' вже існує",
-    "Drop this user from MySQL/MariaDB." : "Видалити цього користувача з MySQL/MariaDB.",
     "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
     "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
+    "DB Error: \"%s\"" : "Помилка БД: \"%s\"",
+    "Offending command was: \"%s\"" : "Команда, що викликала проблему: \"%s\"",
+    "You need to enter either an existing account or the administrator." : "Вам потрібно ввести або існуючий обліковий запис або administrator.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Команда, що викликала проблему: \"%s\", ім'я: %s, пароль: %s",
     "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
@@ -86,7 +79,6 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Не вдалося поділитися %s, загальний доступ не допускає публікації з елементів типу %i",
     "Sharing %s failed, because the file does not exist" : "Не вдалося поділитися %s, оскільки файл не існує",
     "You are not allowed to share %s" : "Вам заборонено поширювати %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Не вдалося поділитися з %s, оскільки %s вже є володарем",
     "Sharing %s failed, because the user %s does not exist" : "Не вдалося поділитися з %s, оскільки користувач %s не існує",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Не вдалося поділитися %s, оскільки користувач %s не є членом будь-якої групи в яку входить %s",
     "Sharing %s failed, because this item is already shared with %s" : "Не вдалося поділитися %s, оскільки файл вже в загальному доступі з %s",
@@ -104,13 +96,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend загального доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend загального доступу %s не знайдено",
     "Sharing backend for %s not found" : "Бекенд загального доступу для %s не знайдено",
-    "Sharing %s failed, because the user %s is the original sharer" : "Не вдалося поділитися %s, спочатку елементом поділився %s",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Не вдалося поділитися %s, права перевищують надані права доступу %s",
     "Sharing %s failed, because resharing is not allowed" : "Не вдалося поділитися %s, перевідкриття доступу заборонено",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Не вдалося поділитися %s, backend загального доступу не знайшов шлях до %s",
     "Sharing %s failed, because the file could not be found in the file cache" : "Не вдалося поділитися %s, елемент не знайдено у файловому кеші.",
     "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Тільки такі символи допускаються в імені користувача: \"az\", \"AZ\", \"0-9\", і \"_.@ -\"",
+    "Apps" : "Додатки",
     "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
     "A valid password must be provided" : "Потрібно задати вірний пароль",
     "The username is already being used" : "Ім'я користувача вже використовується",
@@ -137,14 +128,13 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
     "PostgreSQL >= 9 required" : "Потрібно PostgreSQL> = 9",
     "Please upgrade your database version" : "Оновіть версію бази даних",
-    "Error occurred while checking PostgreSQL version" : "Сталася помилка при перевірці версії PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Переконайтеся що версія PostgreSQL> = 9 або перевірте журнали для отримання додаткової інформацією про помилку",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
     "Data directory (%s) is readable by other users" : "Каталог даних (%s) доступний для читання іншим користувачам",
     "Data directory (%s) must be an absolute path" : "Тека з даними (%s) має бути задана абсолютним шляхом",
     "Check the value of \"datadirectory\" in your configuration" : "Перевірте значення \"datadirectory\" у своїй конфігурації",
     "Data directory (%s) is invalid" : "Каталог даних (%s) невірний",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Переконайтеся, що файл \".ocdata\" присутній у корені каталогу даних.",
-    "Could not obtain lock type %d on \"%s\"." : "Не вдалося отримати блокування типу %d для \"%s\""
+    "Could not obtain lock type %d on \"%s\"." : "Не вдалося отримати блокування типу %d для \"%s\"",
+    "Storage not available" : "Сховище не доступне"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
