@@ -13,6 +13,7 @@ OC.L10N.register(
     "last year" : "上年",
     "_%n hour ago_::_%n hours ago_" : ["%n 小時前"],
     "_%n minute ago_::_%n minutes ago_" : ["%n 分鐘前"],
-    "seconds ago" : "秒前"
+    "seconds ago" : "秒前",
+    "Apps" : "軟件"
 },
 "nplurals=1; plural=0;");
