@@ -3,8 +3,8 @@
  * @author Arthur Schiwon <blizzz@owncloud.com>
  * @author Bart Visscher <bartv@thisnet.nl>
  * @author Brice Maron <brice@bmaron.net>
+ * @author Christian Weiske <cweiske@cweiske.de>
  * @author Christopher Schäpers <kondou@ts.unde.re>
- * @author Felix Moeller <mail@felixmoeller.de>
  * @author Frank Karlitschek <frank@owncloud.org>
  * @author Georg Ehrke <georg@owncloud.com>
  * @author Jakob Sack <mail@jakobsack.de>
@@ -12,15 +12,15 @@
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Kamil Domanski <kdomanski@kdemail.net>
  * @author Lukas Reschke <lukas@owncloud.com>
+ * @author michag86 <micha_g@arcor.de>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <icewind@owncloud.com>
- * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
+ * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author root <root@oc.(none)>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Thomas Tanghus <thomas@tanghus.net>
- * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -37,6 +37,9 @@
  *
  */
 
+use OC\App\CodeChecker\CodeChecker;
+use OC\App\CodeChecker\EmptyCheck;
+use OC\App\CodeChecker\PrivateCheck;
 use OC\OCSClient;
 
 /**
@@ -81,9 +84,10 @@ class OC_Installer{
 		$l = \OC::$server->getL10N('lib');
 
 		list($extractDir, $path) = self::downloadApp($data);
-		$info = self::checkAppsIntegrity($data, $extractDir, $path);
 
-		$basedir=OC_App::getInstallPath().'/'.$info['id'];
+		$info = self::checkAppsIntegrity($data, $extractDir, $path);
+		$appId = OC_App::cleanAppId($info['id']);
+		$basedir = OC_App::getInstallPath().'/'.$appId;
 		//check if the destination directory already exists
 		if(is_dir($basedir)) {
 			OC_Helper::rmdirr($extractDir);
@@ -107,6 +111,10 @@ class OC_Installer{
 		}
 
 		$extractDir .= '/' . $info['id'];
+		if(!file_exists($extractDir)) {
+			OC_Helper::rmdirr($basedir);
+			throw new \Exception($l->t("Archive does not contain a directory named %s", $info['id']));
+		}
 		OC_Helper::copyr($extractDir, $basedir);
 
 		//remove temporary files
@@ -114,7 +122,7 @@ class OC_Installer{
 
 		//install the database
 		if(is_file($basedir.'/appinfo/database.xml')) {
-			if (OC_Appconfig::getValue($info['id'], 'installed_version') === null) {
+			if (\OC::$server->getAppConfig()->getValue($info['id'], 'installed_version') === null) {
 				OC_DB::createDbFromStructure($basedir.'/appinfo/database.xml');
 			} else {
 				OC_DB::updateDbFromStructure($basedir.'/appinfo/database.xml');
@@ -122,13 +130,13 @@ class OC_Installer{
 		}
 
 		//run appinfo/install.php
-		if((!isset($data['noinstall']) or $data['noinstall']==false) and file_exists($basedir.'/appinfo/install.php')) {
-			include $basedir.'/appinfo/install.php';
+		if((!isset($data['noinstall']) or $data['noinstall']==false)) {
+			self::includeAppScript($basedir . '/appinfo/install.php');
 		}
 
 		//set the installed version
-		OC_Appconfig::setValue($info['id'], 'installed_version', OC_App::getAppVersion($info['id']));
-		OC_Appconfig::setValue($info['id'], 'enabled', 'no');
+		\OC::$server->getAppConfig()->setValue($info['id'], 'installed_version', OC_App::getAppVersion($info['id']));
+		\OC::$server->getAppConfig()->setValue($info['id'], 'enabled', 'no');
 
 		//set remote/public handelers
 		foreach($info['remote'] as $name=>$path) {
@@ -151,13 +159,15 @@ class OC_Installer{
 	 * Checks whether or not an app is installed, i.e. registered in apps table.
 	 */
 	public static function isInstalled( $app ) {
-		return (OC_Appconfig::getValue($app, "installed_version") !== null);
+		return (\OC::$server->getAppConfig()->getValue($app, "installed_version") !== null);
 	}
 
 	/**
 	 * @brief Update an application
 	 * @param array $info
 	 * @param bool $isShipped
+	 * @throws Exception
+	 * @return bool
 	 *
 	 * This function could work like described below, but currently it disables and then
 	 * enables the app again. This does result in an updated app.
@@ -184,9 +194,9 @@ class OC_Installer{
 	 *   -# setting the installed version
 	 *
 	 * upgrade.php can determine the current installed version of the app using
-	 * "OC_Appconfig::getValue($appid, 'installed_version')"
+	 * "\OC::$server->getAppConfig()->getValue($appid, 'installed_version')"
 	 */
-	public static function updateApp( $info=array(), $isShipped=false) {
+	public static function updateApp($info=array(), $isShipped=false) {
 		list($extractDir, $path) = self::downloadApp($info);
 		$info = self::checkAppsIntegrity($info, $extractDir, $path, $isShipped);
 
@@ -227,8 +237,8 @@ class OC_Installer{
 			\OC::$server->getConfig(),
 			\OC::$server->getLogger()
 		);
-		$appData = $ocsClient->getApplication($ocsId, \OC_Util::getVersion());
-		$download = $ocsClient->getApplicationDownload($ocsId, \OC_Util::getVersion());
+		$appData = $ocsClient->getApplication($ocsId, \OCP\Util::getVersion());
+		$download = $ocsClient->getApplicationDownload($ocsId, \OCP\Util::getVersion());
 
 		if (isset($download['downloadlink']) && trim($download['downloadlink']) !== '') {
 			$download['downloadlink'] = str_replace(' ', '%20', $download['downloadlink']);
@@ -259,7 +269,8 @@ class OC_Installer{
 		//download the file if necessary
 		if($data['source']=='http') {
 			$pathInfo = pathinfo($data['href']);
-			$path=OC_Helper::tmpFile('.' . $pathInfo['extension']);
+			$extension = isset($pathInfo['extension']) ? '.' . $pathInfo['extension'] : '';
+			$path = \OC::$server->getTempManager()->getTemporaryFile($extension);
 			if(!isset($data['href'])) {
 				throw new \Exception($l->t("No href specified when installing app from http"));
 			}
@@ -273,13 +284,13 @@ class OC_Installer{
 		}
 
 		//detect the archive type
-		$mime=OC_Helper::getMimeType($path);
-		if ($mime !=='application/zip' && $mime !== 'application/x-gzip') {
+		$mime = \OC::$server->getMimeTypeDetector()->detect($path);
+		if ($mime !=='application/zip' && $mime !== 'application/x-gzip' && $mime !== 'application/x-bzip2') {
 			throw new \Exception($l->t("Archives of type %s are not supported", array($mime)));
 		}
 
 		//extract the archive in a temporary folder
-		$extractDir=OC_Helper::tmpFolder();
+		$extractDir = \OC::$server->getTempManager()->getTemporaryFolder();
 		OC_Helper::rmdirr($extractDir);
 		mkdir($extractDir);
 		if($archive=OC_Archive::open($path)) {
@@ -302,11 +313,12 @@ class OC_Installer{
 	 * check an app's integrity
 	 * @param array $data
 	 * @param string $extractDir
+	 * @param string $path
 	 * @param bool $isShipped
 	 * @return array
 	 * @throws \Exception
 	 */
-	public static function checkAppsIntegrity($data, $extractDir, $path, $isShipped=false) {
+	public static function checkAppsIntegrity($data, $extractDir, $path, $isShipped = false) {
 		$l = \OC::$server->getL10N('lib');
 		//load the info.xml file of the app
 		if(!is_file($extractDir.'/appinfo/info.xml')) {
@@ -324,12 +336,44 @@ class OC_Installer{
 		}
 		if(!is_file($extractDir.'/appinfo/info.xml')) {
 			OC_Helper::rmdirr($extractDir);
-			if($data['source']=='http') {
+			if($data['source'] === 'http') {
 				unlink($path);
 			}
 			throw new \Exception($l->t("App does not provide an info.xml file"));
 		}
-		$info=OC_App::getAppInfo($extractDir.'/appinfo/info.xml', true);
+
+		$info = OC_App::getAppInfo($extractDir.'/appinfo/info.xml', true);
+		if(!is_array($info)) {
+			throw new \Exception($l->t('App cannot be installed because appinfo file cannot be read.'));
+		}
+
+		// We can't trust the parsed info.xml file as it may have been tampered
+		// with by an attacker and thus we need to use the local data to check
+		// whether the application needs to be signed.
+		$appId = OC_App::cleanAppId($data['appdata']['id']);
+		$appBelongingToId = OC_App::getInternalAppIdByOcs($appId);
+		if(is_string($appBelongingToId)) {
+			$previouslySigned = \OC::$server->getConfig()->getAppValue($appBelongingToId, 'signed', 'false');
+		} else {
+			$appBelongingToId = $info['id'];
+			$previouslySigned = 'false';
+		}
+		if($data['appdata']['level'] === OC_App::officialApp || $previouslySigned === 'true') {
+			\OC::$server->getConfig()->setAppValue($appBelongingToId, 'signed', 'true');
+			$integrityResult = \OC::$server->getIntegrityCodeChecker()->verifyAppSignature(
+					$appBelongingToId,
+					$extractDir
+			);
+			if($integrityResult !== []) {
+				$e = new \Exception(
+						$l->t(
+								'Signature could not get checked. Please contact the app developer and check your admin screen.'
+						)
+				);
+				throw $e;
+			}
+		}
+
 		// check the code for not allowed calls
 		if(!$isShipped && !OC_Installer::checkCode($extractDir)) {
 			OC_Helper::rmdirr($extractDir);
@@ -337,7 +381,7 @@ class OC_Installer{
 		}
 
 		// check if the app is compatible with this version of ownCloud
-		if(!OC_App::isAppCompatible(OC_Util::getVersion(), $info)) {
+		if(!OC_App::isAppCompatible(\OCP\Util::getVersion(), $info)) {
 			OC_Helper::rmdirr($extractDir);
 			throw new \Exception($l->t("App can't be installed because it is not compatible with this version of ownCloud"));
 		}
@@ -387,7 +431,7 @@ class OC_Installer{
 			return false;
 		}
 
-		$ocsid=OC_Appconfig::getValue( $app, 'ocsid', '');
+		$ocsid=\OC::$server->getAppConfig()->getValue( $app, 'ocsid', '');
 
 		if($ocsid<>'') {
 			$ocsClient = new OCSClient(
@@ -395,7 +439,7 @@ class OC_Installer{
 				\OC::$server->getConfig(),
 				\OC::$server->getLogger()
 			);
-			$ocsdata = $ocsClient->getApplication($ocsid, \OC_Util::getVersion());
+			$ocsdata = $ocsClient->getApplication($ocsid, \OCP\Util::getVersion());
 			$ocsversion= (string) $ocsdata['version'];
 			$currentversion=OC_App::getAppVersion($app);
 			if (version_compare($ocsversion, $currentversion, '>')) {
@@ -480,7 +524,7 @@ class OC_Installer{
 
 			return true;
 		}else{
-			OC_Log::write('core', 'can\'t remove app '.$name.'. It is not installed.', OC_Log::ERROR);
+			\OCP\Util::writeLog('core', 'can\'t remove app '.$name.'. It is not installed.', \OCP\Util::ERROR);
 
 			return false;
 		}
@@ -491,19 +535,33 @@ class OC_Installer{
 	 * Installs shipped apps
 	 *
 	 * This function installs all apps found in the 'apps' directory that should be enabled by default;
+	 * @param bool $softErrors When updating we ignore errors and simply log them, better to have a
+	 *                         working ownCloud at the end instead of an aborted update.
+	 * @return array Array of error messages (appid => Exception)
 	 */
-	public static function installShippedApps() {
+	public static function installShippedApps($softErrors = false) {
+		$errors = [];
 		foreach(OC::$APPSROOTS as $app_dir) {
 			if($dir = opendir( $app_dir['path'] )) {
 				while( false !== ( $filename = readdir( $dir ))) {
 					if( substr( $filename, 0, 1 ) != '.' and is_dir($app_dir['path']."/$filename") ) {
-						if( file_exists( $app_dir['path']."/$filename/appinfo/app.php" )) {
+						if( file_exists( $app_dir['path']."/$filename/appinfo/info.xml" )) {
 							if(!OC_Installer::isInstalled($filename)) {
 								$info=OC_App::getAppInfo($filename);
 								$enabled = isset($info['default_enable']);
-								if( $enabled ) {
-									OC_Installer::installShippedApp($filename);
-									OC_Appconfig::setValue($filename, 'enabled', 'yes');
+								if (($enabled || in_array($filename, \OC::$server->getAppManager()->getAlwaysEnabledApps()))
+									  && \OC::$server->getConfig()->getAppValue($filename, 'enabled') !== 'no') {
+									if ($softErrors) {
+										try {
+											OC_Installer::installShippedApp($filename);
+										} catch (\Doctrine\DBAL\Exception\TableExistsException $e) {
+											$errors[$filename] = $e;
+											continue;
+										}
+									} else {
+										OC_Installer::installShippedApp($filename);
+									}
+									\OC::$server->getConfig()->setAppValue($filename, 'enabled', 'yes');
 								}
 							}
 						}
@@ -512,6 +570,8 @@ class OC_Installer{
 				closedir( $dir );
 			}
 		}
+
+		return $errors;
 	}
 
 	/**
@@ -521,29 +581,33 @@ class OC_Installer{
 	 */
 	public static function installShippedApp($app) {
 		//install the database
-		if(is_file(OC_App::getAppPath($app)."/appinfo/database.xml")) {
-			OC_DB::createDbFromStructure(OC_App::getAppPath($app)."/appinfo/database.xml");
+		$appPath = OC_App::getAppPath($app);
+		if(is_file("$appPath/appinfo/database.xml")) {
+			OC_DB::createDbFromStructure("$appPath/appinfo/database.xml");
 		}
 
 		//run appinfo/install.php
-		if(is_file(OC_App::getAppPath($app)."/appinfo/install.php")) {
-			include OC_App::getAppPath($app)."/appinfo/install.php";
-		}
-		$info=OC_App::getAppInfo($app);
+		\OC::$loader->addValidRoot($appPath);
+		self::includeAppScript("$appPath/appinfo/install.php");
+
+		$info = OC_App::getAppInfo($app);
 		if (is_null($info)) {
 			return false;
 		}
-		OC_Appconfig::setValue($app, 'installed_version', OC_App::getAppVersion($app));
+
+		$config = \OC::$server->getConfig();
+
+		$config->setAppValue($app, 'installed_version', OC_App::getAppVersion($app));
 		if (array_key_exists('ocsid', $info)) {
-			OC_Appconfig::setValue($app, 'ocsid', $info['ocsid']);
+			$config->setAppValue($app, 'ocsid', $info['ocsid']);
 		}
 
 		//set remote/public handlers
 		foreach($info['remote'] as $name=>$path) {
-			OCP\CONFIG::setAppValue('core', 'remote_'.$name, $app.'/'.$path);
+			$config->setAppValue('core', 'remote_'.$name, $app.'/'.$path);
 		}
 		foreach($info['public'] as $name=>$path) {
-			OCP\CONFIG::setAppValue('core', 'public_'.$name, $app.'/'.$path);
+			$config->setAppValue('core', 'public_'.$name, $app.'/'.$path);
 		}
 
 		OC_App::setAppTypes($info['id']);
@@ -558,13 +622,22 @@ class OC_Installer{
 	 */
 	public static function checkCode($folder) {
 		// is the code checker enabled?
-		if(!OC_Config::getValue('appcodechecker', false)) {
+		if(!\OC::$server->getConfig()->getSystemValue('appcodechecker', false)) {
 			return true;
 		}
 
-		$codeChecker = new \OC\App\CodeChecker();
+		$codeChecker = new CodeChecker(new PrivateCheck(new EmptyCheck()));
 		$errors = $codeChecker->analyseFolder($folder);
 
 		return empty($errors);
 	}
+
+	/**
+	 * @param $basedir
+	 */
+	private static function includeAppScript($script) {
+		if ( file_exists($script) ){
+			include $script;
+		}
+	}
 }
