@@ -4,11 +4,11 @@
  * @author Christopher Schäpers <kondou@ts.unde.re>
  * @author Joas Schilling <nickvergessen@owncloud.com>
  * @author Morris Jobke <hey@morrisjobke.de>
- * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
+ * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Tom Needham <tom@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -89,13 +89,6 @@ API::register(
 	'core',
 	API::USER_AUTH
 	);
-API::register(
-	'get',
-	'/cloud/users/{userid}',
-	array('OC_OCS_Cloud', 'getUser'),
-	'core',
-	API::USER_AUTH
-);
 API::register(
 	'get',
 	'/cloud/user',
