@@ -12,12 +12,10 @@ OC.L10N.register(
     "Log" : "Log",
     "Tips & tricks" : "Tipps & Tricks",
     "Updates" : "Updates",
-    "Authentication error" : "Authentifizierungsfehler",
-    "Your full name has been changed." : "Dein vollständiger Name ist geändert worden.",
-    "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
     "Couldn't remove app." : "Die App konnte nicht entfernt werden.",
     "Language changed" : "Sprache geändert",
     "Invalid request" : "Fehlerhafte Anfrage",
+    "Authentication error" : "Authentifizierungsfehler",
     "Admins can't remove themself from the admin group" : "Administratoren können sich nicht selbst aus der Admin-Gruppe löschen.",
     "Unable to add user to group %s" : "Der Benutzer konnte nicht zur Gruppe %s hinzugefügt werden",
     "Unable to remove user from group %s" : "Der Benutzer konnte nicht aus der Gruppe %s entfernt werden",
@@ -45,7 +43,7 @@ OC.L10N.register(
     "Email sent" : "E-Mail wurde verschickt",
     "You need to set your user email before being able to send test emails." : "Du musst zunächst Deine Benutzer-E-Mail-Adresse angeben, bevor Du Test-E-Mail verschicken kannst.",
     "Invalid mail address" : "Ungültige E-Mail-Adresse",
-    "A user with that name already exists." : "Es existiert bereits ein Benutzer dieses Namens.",
+    "A user with that name already exists." : "Ein Benutzer mit diesem Namen existiert bereits.",
     "Unable to create user." : "Benutzer konnte nicht erstellt werden.",
     "Your %s account was created" : "Dein %s-Konto wurde erstellt",
     "Unable to delete user." : "Benutzer konnte nicht gelöscht werden.",
@@ -53,6 +51,8 @@ OC.L10N.register(
     "Invalid user" : "Ungültiger Benutzer",
     "Unable to change mail address" : "E-Mail-Adresse konnte nicht geändert werden",
     "Email saved" : "E-Mail-Adresse gespeichert",
+    "Your full name has been changed." : "Dein vollständiger Name ist geändert worden.",
+    "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Bist Du wirklich sicher, dass Du „{domain}“ als vertrauenswürdige Domain hinzufügen möchtest?",
     "Add trusted domain" : "Vertrauenswürdige Domain hinzufügen",
     "Migration in progress. Please wait until the migration is finished" : "Migration in Arbeit. Bitte warte, bis die Migration beendet ist",
@@ -62,10 +62,12 @@ OC.L10N.register(
     "Approved" : "Geprüft",
     "Experimental" : "Experimentell",
     "All" : "Alle",
+    "No apps found for your version" : "Es wurden keine Apps für Deine Version gefunden",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Offizielle Apps werden von und innerhalb der ownCloud-Community entwickelt. Sie stellen zentrale Funktionen von ownCloud bereit und sind auf den Produktiveinsatz vorbereitet.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Geprüfte Apps werden von vertrauenswürdigen Entwicklern entwickelt und haben eine oberflächliche Sicherheitsprüfung durchlaufen. Sie werden innerhalb eines offenen Code-Repositorys aktiv gepflegt und ihre Betreuer erachten sie als stabil genug für für den gelegentlichen bis normalen Einsatz.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Diese App ist nicht auf Sicherheitsprobleme hin überprüft und ist neu oder bekanntermaßen instabil. Die Installation erfolgt auf eigenes Risiko.",
     "Update to %s" : "Aktualisierung auf %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["Sie haben %n Aktualisierung verfügbar","Sie haben %n Aktualisierungen verfügbar"],
     "Please wait...." : "Bitte warten…",
     "Error while disabling app" : "Beim Deaktivieren der App ist ein Fehler aufgetreten",
     "Disable" : "Deaktivieren",
@@ -77,7 +79,12 @@ OC.L10N.register(
     "Uninstalling ...." : "Deinstallieren…",
     "Error while uninstalling app" : "Fehler beim Deinstallieren der App",
     "Uninstall" : "Deinstallieren",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Die App wurde aktiviert, muss aber aktualisiert werden. Du wirst in 5 Sekunden zu Aktualisierungsseite weitergeleitet",
     "App update" : "App aktualisiert",
+    "No apps found for \"{query}\"" : "Es wurden keine Apps für \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Es ist ein Fehler aufgetreten. Bitte lade ein ASCII-kodiertes PEM-Zertifikat hoch.",
+    "Valid until {date}" : "Gültig bis {date}",
+    "Delete" : "Löschen",
     "An error occurred: {message}" : "Ein Fehler ist aufgetreten: {message}",
     "Select a profile picture" : "Wähle ein Profilbild",
     "Very weak password" : "Sehr schwaches Passwort",
@@ -85,12 +92,9 @@ OC.L10N.register(
     "So-so password" : "Durchschnittliches Passwort",
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Es ist ein Fehler aufgetreten. Bitte lade ein ASCII-kodiertes PEM-Zertifikat hoch.",
-    "Valid until {date}" : "Gültig bis {date}",
-    "Delete" : "Löschen",
     "Groups" : "Gruppen",
     "Unable to delete {objName}" : "Löschen von {objName} nicht möglich",
-    "Error creating group" : "Fehler beim Erstellen der Gruppe",
+    "Error creating group: {message}" : "Fehler beim Erstellen der Gruppe: {message}",
     "A valid group name must be provided" : "Ein gültiger Gruppenname muss angegeben werden",
     "deleted {groupName}" : "{groupName} gelöscht",
     "undo" : "rückgängig machen",
@@ -100,13 +104,12 @@ OC.L10N.register(
     "add group" : "Gruppe hinzufügen",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Die Änderung des Passworts führt zu Datenverlust, weil die Datenwiederherstellung für diesen Benutzer nicht verfügbar ist",
     "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
-    "Error creating user" : "Beim Anlegen des Benutzers ist ein Fehler aufgetreten",
+    "Error creating user: {message}" : "Fehler beim Anlegen des Benutzers: {message}",
     "A valid password must be provided" : "Es muss ein gültiges Passwort angegeben werden",
     "A valid email must be provided" : "Es muss eine gültige E-Mail-Adresse angegeben werden",
     "__language_name__" : "Deutsch (Persönlich)",
-    "Sync clients" : "Sync-Clients",
     "Personal info" : "Persönliche Informationen",
-    "SSL root certificates" : "SSL-Root-Zertifikate",
+    "Sync clients" : "Sync-Clients",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Alles (fatale Probleme, Fehler, Warnungen, Infos, Debug-Meldungen)",
     "Info, warnings, errors and fatal issues" : "Infos, Warnungen, Fehler und fatale Probleme",
     "Warnings, errors and fatal issues" : "Warnungen, Fehler und fatale Probleme",
@@ -124,29 +127,32 @@ OC.L10N.register(
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Dein Server wird mit Microsoft Windows betrieben. Für ein optimales Nutzungserlebnis empfehlen wir dringend Linux.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "%1$s ist in einer älteren Version als %2$s installiert, aus Stabilitäts- und Geschwindigkeitsgründen wird ein Update auf eine neuere %1$s-Version empfohlen.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s ist in einer älteren Version als %2$s installiert. Aus Stabilitäts- und Performancegründen empfehlen wir eine Aktualisierung auf eine neuere %1$s-Version",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Das PHP-Modul 'fileinfo' fehlt. Wir empfehlen dieses Modul zu aktivieren um die besten Resultate bei der Erkennung der Dateitypen zu erreichen.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transaktionales Sperren ist deaktiviert, was zu Problemen mit Laufzeitbedingungen führen kann. Aktiviere 'filelocking.enabled' in der config.php  diese Probleme zu vermeiden. Weitere Informationen findest du in unserer <a target=\"_blank\" href=\"%s\">Dokumentation ↗</a>.",
     "System locale can not be set to a one which supports UTF-8." : "Es kann kein Systemgebietsschema gesetzt werden, das UTF-8 unterstützt.",
     "This means that there might be problems with certain characters in file names." : "Dies bedeutet, dass es zu Problemen mit bestimmten Zeichen in Dateinamen kommen kann.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Wir empfehlen dringend, die erforderlichen Pakete auf Ihrem System zu installieren, damit eines der folgenden Gebietsschemata unterstützt wird: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Wenn sich Deine Installation nicht im Wurzelverzeichnis der Domain befindet und Cron aus dem System genutzt wird, kann es zu Fehlern bei der URL-Generierung kommen. Um dies zu verhindern, setze bitte die „overwrite.cli.url“-Option in Deiner config.php auf das Web-Wurzelverzeichnis Deiner Installation (Vorschlag: „%s“).",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Die Ausführung des Cron-Jobs über die Kommandozeile war nicht möglich. Die folgenden technischen Fehler sind dabei aufgetreten:",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Bitte überprüfe noch einmal die <a target=\"_blank\" href=\"%s\">Installationsanleitungen ↗</a> und kontrolliere das <a href=\"#log-section\">Log</a> auf mögliche Fehler oder Warnungen.",
+    "All checks passed." : "Alle Überprüfungen bestanden.",
     "Open documentation" : "Dokumentation öffnen",
-    "Allow apps to use the Share API" : "Erlaubt Apps die Nutzung der Share-API",
+    "Allow apps to use the Share API" : "Apps die Benutzung der Share-API erlauben",
     "Allow users to share via link" : "Benutzern erlauben, Inhalte über Links zu teilen",
     "Enforce password protection" : "Passwortschutz erzwingen",
     "Allow public uploads" : "Öffentliches Hochladen erlauben",
     "Allow users to send mail notification for shared files" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien zu senden",
-    "Set default expiration date" : "Setze  Ablaufdatum",
+    "Set default expiration date" : "Standardmäßiges Ablaufdatum setzen",
     "Expire after " : "Ablauf nach ",
     "days" : "Tagen",
     "Enforce expiration date" : "Ablaufdatum erzwingen",
-    "Allow resharing" : "Erlaubt erneutes Teilen",
+    "Allow resharing" : "Weiterverteilen erlauben",
     "Restrict users to only share with users in their groups" : "Benutzer auf das Teilen innerhalb ihrer Gruppen beschränken",
-    "Allow users to send mail notification for shared files to other users" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien an andere Benutzer zu senden",
+    "Allow users to send mail notification for shared files to other users" : "Benutzern erlauben, E-Mail-Benachrichtigungen für geteilte Dateien an andere Benutzer zu senden",
     "Exclude groups from sharing" : "Gruppen von Freigaben ausschließen",
     "These groups will still be able to receive shares, but not to initiate them." : "Diese Gruppen können weiterhin Freigaben empfangen, aber selbst keine mehr initiieren.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Die Auto-Vervollständigung von Benutzernamen im Teilen-Dialog erlauben. Wenn dies deaktiviert ist, muss der vollständige Benutzername eingegeben werden.",
     "Last cron job execution: %s." : "Letzte Cron-Job-Ausführung: %s.",
     "Last cron job execution: %s. Something seems wrong." : "Letzte Cron-Job-Ausführung: %s. Möglicherweise liegt ein Fehler vor.",
     "Cron was not executed yet!" : "Cron wurde bis jetzt noch nicht ausgeführt!",
@@ -155,7 +161,10 @@ OC.L10N.register(
     "Use system's cron service to call the cron.php file every 15 minutes." : "Benutze den systemeigenen Cron-Dienst, um die cron.php alle 15 Minuten aufzurufen.",
     "Enable server-side encryption" : "Serverseitige Verschlüsselung aktivieren",
     "Please read carefully before activating server-side encryption: " : "Bitte sorgfältig lesen, bevor die serverseitige Verschlüsselung aktiviert wird:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Wird die Verschlüsselung einmal aktiviert, so werden alle ab diesem Zeitpunkt hochgeladene Dateien verschlüsselt. Sie kann nur wieder deaktiviert werden, wenn das Verschlüsselungsmodul dies unterstützt und alle Voraussetzungen (wie das Setzen eines Wiederherstellungsschlüssels) im Vorhinein erfüllt wurden.",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Verschlüsselung an sich garantiert nicht die Sicherheit des Systems. Bitte schau in die ownCloud Dokumentation für weitere Informationen wie die Verschlüsselungs-App funktioniert und welche Anwendungsfälle unterstützt werden.",
     "Be aware that encryption always increases the file size." : "Sei dir bewusst, dass die Verschlüsselung immer die Dateigröße erhöht.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Es ist immer gut, regelmäßig Sicherungskopien von deinen Daten zu machen. Falls du die Verschlüsselung nutzt, solltest du auch eine Sicherung der Verschlüsselungsschlüssel zusammen mit deinen Daten machen .",
     "This is the final warning: Do you really want to enable encryption?" : "Dies ist die letzte Warnung: Verschlüsselung wirklich aktivieren?",
     "Enable encryption" : "Verschlüsselung aktivieren",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Kein Verschlüsselungs-Modul geladen, bitte aktiviere ein Verschlüsselungs-Modul im Anwendungs-Menü.",
@@ -178,11 +187,11 @@ OC.L10N.register(
     "Store credentials" : "Anmeldeinformationen speichern",
     "Test email settings" : "E-Mail-Einstellungen testen",
     "Send email" : "E-Mail senden",
-    "Log level" : "Loglevel",
     "Download logfile" : "Logdatei herunterladen",
     "More" : "Mehr",
     "Less" : "Weniger",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Die Logdatei ist größer als 100 MB. Es kann etwas Zeit beanspruchen, sie herunterzuladen!",
+    "What to log" : "Was für ein Protokoll",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite wird als Datenbank verwendet. Bei größeren Installationen wird empfohlen, auf ein anderes Datenbank-Backend zu wechseln.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Insbesondere bei der Nutzung des Desktop Clients zur Dateisynchronisierung wird vom Einsatz von SQLite abgeraten.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Um zu einer anderen Datenbank zu migrieren, benutze bitte die Kommandozeile: 'occ db:convert-type', oder in die <a target=\"_blank\" href=\"%s\">Dokumentation ↗</a> schauen.",
@@ -196,18 +205,26 @@ OC.L10N.register(
     "Developer documentation" : "Dokumentation für Entwickler",
     "Experimental applications ahead" : "Experimentelle Apps nachfolgend",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Experimentelle Apps sind nicht auf Sicherheitsprobleme hin überprüft, sind neu oder bekanntermaßen instabil und befinden sich in intensiver Entwicklung. Ihre Installation kann Datenverlust oder Sicherheitslücken hervorrufen.",
-    "by" : "von",
-    "licensed" : "Lizenziert",
+    "by %s" : "durch %s",
+    "%s-licensed" : "%s-lizensiert",
     "Documentation:" : "Dokumentation:",
     "User documentation" : "Dokumentation für Benutzer",
     "Admin documentation" : "Dokumentation für Administratoren",
     "Show description …" : "Beschreibung anzeigen…",
     "Hide description …" : "Beschreibung ausblenden…",
+    "This app has an update available." : "Es ist eine Aktualisierung verfügbar.",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Diese App hat keine minimale ownCloud Version zugeordnet. Dies wird ein Fehler in ownCloud 11 und später sein.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Diese App hat keine maximale ownCloud Version zugeordnet. Dies wird ein Fehler in ownCloud 11 und später sein.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Die App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
     "Enable only for specific groups" : "Nur für bestimmte Gruppen aktivieren",
     "Uninstall App" : "App deinstallieren",
     "Enable experimental apps" : "Experimentelle Apps aktivieren",
-    "No apps found for your version" : "Es wurden keine Apps für Deine Version gefunden",
+    "SSL Root Certificates" : "SSL Root Zertifikate",
+    "Common Name" : "Common Name",
+    "Valid until" : "Gültig bis",
+    "Issued By" : "Ausgestellt von:",
+    "Valid until %s" : "Gültig bis %s",
+    "Import root certificate" : "Root-Zertifikat importieren",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass Du jetzt ein %s-Konto hast.<br><br>Dein Benutzername: %s<br>Greife darauf zu: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Noch einen schönen Tag!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hallo,\n\nhier nur kurz die Mitteilung, dass Du jetzt ein %s-Konto hast.\n\nDein Benutzername: %s\nGreife darauf zu: %s\n\n",
@@ -216,40 +233,35 @@ OC.L10N.register(
     "Forum" : "Forum",
     "Issue tracker" : "Issue Tracker",
     "Commercial support" : "Kommerzieller Support",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Du benutzt <strong>%s</strong> von <strong>%s</strong>",
+    "Profile picture" : "Profilbild",
+    "Upload new" : "Neues hochladen",
+    "Select from Files" : "Wähle aus Dateien",
+    "Remove image" : "Bild entfernen",
+    "png or jpg, max. 20 MB" : "png oder jpg, max. 20MB",
+    "Picture provided by original account" : "Bild von Original- Konto zur Verfügung gestellt",
+    "Cancel" : "Abbrechen",
+    "Choose as profile picture" : "Wähle ein Profilbild",
+    "Full name" : "Vollständiger Name",
+    "No display name set" : "Kein Anzeigename angegeben",
+    "Email" : "E-Mail",
+    "Your email address" : "Deine E-Mail-Adresse",
+    "For password recovery and notifications" : "Für Passwort Wiederherstellung und Benachrichtigungen",
+    "No email address set" : "Keine E-Mail-Adresse angegeben",
+    "You are member of the following groups:" : "Du bist Mitglied folgender Gruppen:",
+    "Password" : "Passwort",
+    "Unable to change your password" : "Passwort konnte nicht geändert werden",
+    "Current password" : "Aktuelles Passwort",
+    "New password" : "Neues Passwort",
+    "Change password" : "Passwort ändern",
+    "Language" : "Sprache",
+    "Help translate" : "Hilf bei der Übersetzung",
     "Get the apps to sync your files" : "Lade die Apps zur Synchronisierung Deiner Daten herunter",
     "Desktop client" : "Desktop-Client",
     "Android app" : "Android-App",
     "iOS app" : "iOS-App",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Wenn Du das Projekt unterstützen möchtest,\n<a href=\"https://owncloud.org/contribute\"\ntarget=\"_blank\" rel=\"noreferrer\">beteilige Dich an der Entwicklung</a>\noder\n<a href=\"https://owncloud.org/promote\"\ntarget=\"_blank\" rel=\"noreferrer\">hilf mit, es bekannter zu machen</a>!",
     "Show First Run Wizard again" : "Den Einrichtungsassistenten erneut anzeigen",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Du verwendest <strong>%s</strong> der verfügbaren <strong>%s</strong>",
-    "Password" : "Passwort",
-    "Unable to change your password" : "Passwort konnte nicht geändert werden",
-    "Current password" : "Aktuelles Passwort",
-    "New password" : "Neues Passwort",
-    "Change password" : "Passwort ändern",
-    "Full name" : "Vollständiger Name",
-    "No display name set" : "Kein Anzeigename angegeben",
-    "Email" : "E-Mail",
-    "Your email address" : "Deine E-Mail-Adresse",
-    "Fill in an email address to enable password recovery and receive notifications" : "Gib eine E-Mail-Adresse an, um eine Wiederherstellung des Passworts zu ermöglichen und Benachrichtigungen zu empfangen",
-    "No email address set" : "Keine E-Mail-Adresse angegeben",
-    "You are member of the following groups:" : "Du bist Mitglied folgender Gruppen:",
-    "Profile picture" : "Profilbild",
-    "Upload new" : "Neues hochladen",
-    "Select new from Files" : "Neues aus den Dateien wählen",
-    "Remove image" : "Bild entfernen",
-    "Either png or jpg. Ideally square but you will be able to crop it. The file is not allowed to exceed the maximum size of 20 MB." : "Entweder png oder jpg. Im Idealfall quadratisch, aber du kannst das Bild beschneiden. Es ist nicht erlaubt die Maximalgröße von 20 MB zu überschreiten.",
-    "Your avatar is provided by your original account." : "Dein Avatar wird von Deinem ursprünglichen Konto bereitgestellt.",
-    "Cancel" : "Abbrechen",
-    "Choose as profile image" : "Als Profilbild wählen",
-    "Language" : "Sprache",
-    "Help translate" : "Hilf bei der Übersetzung",
-    "Common Name" : "Common Name",
-    "Valid until" : "Gültig bis",
-    "Issued By" : "Ausgestellt von:",
-    "Valid until %s" : "Gültig bis %s",
-    "Import root certificate" : "Root-Zertifikat importieren",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Entwickelt von der {communityopen}ownCloud-Community{linkclose}, der {githubopen}Quellcode{linkclose} ist unter den Bedingungen der {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} lizenziert.",
     "Show storage location" : "Speicherort anzeigen",
     "Show last log in" : "Letzte Anmeldung anzeigen",
