@@ -1,6 +1,8 @@
 OC.L10N.register(
     "settings",
     {
+    "APCu" : "APCu",
+    "Redis" : "Redis",
     "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
     "Sharing" : "Berbagi",
     "Server-side encryption" : "Enkripsi sisi-server",
@@ -10,12 +12,10 @@ OC.L10N.register(
     "Log" : "Log",
     "Tips & tricks" : "Tips & trik",
     "Updates" : "Pembaruan",
-    "Authentication error" : "Terjadi kesalahan saat otentikasi",
-    "Your full name has been changed." : "Nama lengkap Anda telah diubah",
-    "Unable to change full name" : "Tidak dapat mengubah nama lengkap",
     "Couldn't remove app." : "Tidak dapat menghapus aplikasi.",
     "Language changed" : "Bahasa telah diubah",
     "Invalid request" : "Permintaan tidak valid",
+    "Authentication error" : "Terjadi kesalahan saat otentikasi",
     "Admins can't remove themself from the admin group" : "Admin tidak dapat menghapus dirinya sendiri dari grup admin",
     "Unable to add user to group %s" : "Tidak dapat menambahkan pengguna ke grup %s",
     "Unable to remove user from group %s" : "Tidak dapat menghapus pengguna dari grup %s",
@@ -28,6 +28,9 @@ OC.L10N.register(
     "Unable to change password" : "Tidak dapat mengubah sandi",
     "Enabled" : "Diaktifkan",
     "Not enabled" : "Tidak diaktifkan",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "memasang dan memperbarui aplikasi via toko aplikasi atau Federated Cloud Sharing",
+    "Federated Cloud Sharing" : "Federated Cloud Sharing",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL menggunakan versi lawas %s (%s). Silakan perbarui sistem operasi Anda atau fitur-fitur seperti %s tidak akan dapat bekerja dengan benar.",
     "A problem occurred, please check your log files (Error: %s)" : "Terjadi masalah, mohon periksa berkas log Anda (Kesalahan: %s)",
     "Migration Completed" : "Migrasi Selesai",
     "Group already exists." : "Grup sudah ada.",
@@ -48,14 +51,21 @@ OC.L10N.register(
     "Invalid user" : "Pengguna salah",
     "Unable to change mail address" : "Tidak dapat mengubah alamat email",
     "Email saved" : "Email disimpan",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Apakah And yakin ingin menambahkan \"{domain}\" sebagai domain terpercaya?",
+    "Your full name has been changed." : "Nama lengkap Anda telah diubah",
+    "Unable to change full name" : "Tidak dapat mengubah nama lengkap",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Apakah Anda yakin ingin menambahkan \"{domain}\" sebagai domain terpercaya?",
     "Add trusted domain" : "Tambah domain terpercaya",
     "Migration in progress. Please wait until the migration is finished" : "Migrasi sedang dalam proses. Mohon tunggu sampai migrasi selesai.",
     "Migration started …" : "Migrasi dimulai ...",
     "Sending..." : "Mengirim",
+    "Official" : "Resmi",
+    "Approved" : "Disetujui",
+    "Experimental" : "Uji Coba",
     "All" : "Semua",
+    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini.",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplikasi resmi dikembangkan oleh komunitas ownCloud. Mereka menawarkan fitur pusat bagi ownCloud dan siap digunakan untuk penggunaan produksi.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Aplikasi tersetujui dikembangkan oleh pengembang terpercaya dan telah lulus pemeriksaan keamanan. Mereka secara aktif dipelihara direpositori kode terbuka dan pemelihara sudah memastikan mereka stabil untuk penggunaan normal.",
+    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Apl ini belum diperiksa masalah keamanannya dan masih baru atau biasanya tidak stabil. Instal dengan resiko Anda sendiri.",
     "Update to %s" : "Perbarui ke %s",
     "Please wait...." : "Mohon tunggu....",
     "Error while disabling app" : "Terjadi kesalahan saat menonaktifkan aplikasi",
@@ -68,18 +78,21 @@ OC.L10N.register(
     "Uninstalling ...." : "Mencopot ...",
     "Error while uninstalling app" : "Terjadi kesalahan saat mencopot aplikasi",
     "Uninstall" : "Copot",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikasi sudah diaktifkan tetapi perlu diperbarui. Anda akan dialihkan ke halaman pembaruan dalam 5 detik.",
+    "App update" : "Pembaruan Aplikasi",
+    "No apps found for \"{query}\"" : "Tidak ada aplikasi yang ditemukan untuk \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Terjadi kesalahan. Mohon unggah sertifikat PEM terenkode-ASCII.",
+    "Valid until {date}" : "Berlaku sampai {date}",
+    "Delete" : "Hapus",
+    "An error occurred: {message}" : "Sebuah kesalahan yang muncul: {message}",
     "Select a profile picture" : "Pilih foto profil",
     "Very weak password" : "Sandi sangat lemah",
     "Weak password" : "Sandi lemah",
     "So-so password" : "Sandi lumayan",
     "Good password" : "Sandi baik",
     "Strong password" : "Sandi kuat",
-    "Valid until {date}" : "Berlaku sampai {date}",
-    "Delete" : "Hapus",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Terjadi kesalahan. Mohon unggah sertifikat PEM terenkode-ASCII.",
     "Groups" : "Grup",
     "Unable to delete {objName}" : "Tidak dapat menghapus {objName}",
-    "Error creating group" : "Terjadi kesalahan saat membuat grup",
     "A valid group name must be provided" : "Harus memberikan nama grup yang benar.",
     "deleted {groupName}" : "menghapus {groupName}",
     "undo" : "urungkan",
@@ -89,17 +102,15 @@ OC.L10N.register(
     "add group" : "tambah grup",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Pengubahan kata sandi akan ditampilkan di data kehilangan, karena data pemulihan tidak tersedia bagi pengguna ini",
     "A valid username must be provided" : "Harus memberikan nama pengguna yang benar",
-    "Error creating user" : "Terjadi kesalahan saat membuat pengguna",
     "A valid password must be provided" : "Harus memberikan sandi yang benar",
     "A valid email must be provided" : "Email yang benar harus diberikan",
     "__language_name__" : "__language_name__",
-    "Sync clients" : "Klien sync",
     "Personal info" : "Info pribadi",
-    "SSL root certificates" : "Sertifikat root SSL",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Semuanya (Masalah fatal, galat, peringatan, info, debug)",
-    "Info, warnings, errors and fatal issues" : "Info, peringatan, galat dan masalah fatal",
-    "Warnings, errors and fatal issues" : "Peringatan, galat dan masalah fatal",
-    "Errors and fatal issues" : "Galat dan masalah fatal",
+    "Sync clients" : "Klien sync",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "Semuanya (Masalah fatal, kesalahan, peringatan, info, debug)",
+    "Info, warnings, errors and fatal issues" : "Info, peringatan, kesalahan dan masalah fatal",
+    "Warnings, errors and fatal issues" : "Peringatan, kesalahan dan masalah fatal",
+    "Errors and fatal issues" : "Kesalahan dan masalah fatal",
     "Fatal issues only" : "Hanya masalah fatal",
     "None" : "Tidak ada",
     "Login" : "Masuk",
@@ -108,18 +119,20 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "kelihatannya php tidak diatur dengan benar untuk variabel lingkungan sistem kueri. Pemeriksaan dengan getenv(\"PATH\") hanya mengembalikan respon kosong.",
-    "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Mohon periksa dokumentasi instalasi untuk catatan konfigurasi php dan konfigurasi php server Anda, terutama saat menggunakan ph-fpm.",
+    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Silakan periksa <a target=\"_blank\" href=\"%s\">dokumentasi instalasi ↗</a> untuk membaca catatan konfigurasi dan konfigurasi php pada server Anda, terutama ketika menggunakan php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfig Hanya-Baca telah diaktifkan. Ini akan mencegah setelan beberapa konfigurasi melalui antarmuka-web. Selanjutnya, berkas perlu dibuat dapat-dibaca secara manual untuk setiap pembaruan.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP tampaknya disetel menjadi strip inline doc blocks. Hal ini akan membuat beberapa aplikasi inti tidak dapat diakses.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Server Anda dijalankan di Microsoft Windows. Kami sangat menyarankan Linux untuk mendapatkan pengalaman pengguna yang optimal.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Module 'fileinfo' pada PHP tidak ada. Kami sangat menyarankan untuk mengaktifkan modul ini untuk mendapatkan hasil terbaik pada proses pendeteksian mime-type.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transaksi penguncian berkas dinonaktifkan, hal ini dapat menyebabkan masalah dengan kondisi race. Aktifkan 'filelocking.enabled' pada config.php untuk menghindari masalah ini. Baca <a target=\"_blank\" href=\"%s\">dokumentasi ↗</a> untuk informasi lebih lanjut.",
     "System locale can not be set to a one which supports UTF-8." : "Sistem lokal tidak dapat diatur untuk satu yang mendukung UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Ini artinya mungkin ada masalah dengan karakter tertentu pada nama berkas.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Kamu sangat menyarankan untuk menginstal paket-paket yang dibutuhkan pada sistem agar mendukung lokal berikut: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Jika instalasi Anda tidak di root domain dan menggunakan sistem cron, hal tersebut dapat menyebabkan masalah dengan pembuatan URL. Untuk mencegah masalah tersebut, mohon atur opsi \"overwrite.cli.url\" pada berkas config.php Anda ke jalur lokasi webroot instalasi Anda (Disarankan: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Tidak mungkin untuk mengeksekusi cronjob via CLI. Kesalahan teknis berikut muncul:",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Mohon periksa dua kali <a target=\"_blank\" href=\"%s\">panduan instalasi ↗</a>, dan periksa segala kesalahan atau peringatan pada <a href=\"#log-section\">log</a>.",
+    "All checks passed." : "Semua pemeriksaan lulus.",
     "Open documentation" : "Buka dokumentasi",
     "Allow apps to use the Share API" : "Izinkan aplikasi untuk menggunakan API Pembagian",
     "Allow users to share via link" : "Izinkan pengguna untuk membagikan via tautan",
@@ -135,6 +148,7 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Izinkan pengguna mengirim pemberitahuan email saat berbagi berkas kepada pengguna lainnya",
     "Exclude groups from sharing" : "Tidak termasuk grup untuk berbagi",
     "These groups will still be able to receive shares, but not to initiate them." : "Grup ini akan tetap dapat menerima berbagi, tatapi tidak dapat membagikan.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Izinkan penyelesai otomatis pada nama pengguna di jendela dialog berbagi. Jika ini dinonaktifkan, nama pengguna utuh perlu dimasukkan.",
     "Last cron job execution: %s." : "Eksekusi penjadwalan cron terakhir: %s.",
     "Last cron job execution: %s. Something seems wrong." : "Eksekusi penjadwalan cron terakhir: %s. Kelihatannya ada yang salah.",
     "Cron was not executed yet!" : "Cron masih belum dieksekusi!",
@@ -142,10 +156,16 @@ OC.L10N.register(
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php didaftarkan pada layanan webcron untuk memanggil cron.php setiap 15 menit melalui http.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Gunakan layanan cron sistem untuk memanggil berkas cron.php setiap 15 menit.",
     "Enable server-side encryption" : "Aktifkan enkripsi sisi-server",
-    "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?" : "Enkripsi adalah proses satu arah. Setelah enkripsi diaktifkan, semua berkas mulai saat ini akan di enkrispi pada server dan tidak mungkin untuk menonaktifkan enkrispi dikemudian hari. Ini merupakan peringatan terakhir: Apakah Anda yakin ingin mengaktifkan enkripsi?",
+    "Please read carefully before activating server-side encryption: " : "Mohon baca dengan teliti sebelum mengaktifkan enkripsi server-side:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Setelah enkripsi diaktifkan, semua berkas yang diunggah pada server mulai saat ini akan dienkripsi saat singgah pada server. Penonaktifan enkripsi hanya mungkin berhasil jika modul enkripsi yang aktif mendukung fungsi ini dan semua prasyarat (misalnya pengaturan kunci pemulihan) sudah terpenuhi.",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Enkripsi saja tidak menjamin keamanan sistem. Silakan lihat dokumentasi ownCloud untuk informasi lebih lanjut tentang bagaimana aplikasi enkripsi bekerja, dan kasus penggunaan yang didukung.",
+    "Be aware that encryption always increases the file size." : "Ingat bahwa enkripsi selalu menambah ukuran berkas.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Alangkah baiknya untuk membuat cadangan data secara rutin, dalam kasus enkripsi, pastikan untuk mencadangkan kunci enkripsi bersama dengan data Anda.",
+    "This is the final warning: Do you really want to enable encryption?" : "Ini adalah peringatan terakhir: Apakah Anda yakin ingin mengaktifkan enkripsi?",
     "Enable encryption" : "Aktifkan enkripsi",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Tidak ada modul enkripsi yang dimuat, mohon aktifkan modul enkripsi di menu aplikasi.",
     "Select default encryption module:" : "Pilih modul enkripsi baku:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Anda perlu mengganti kunci enkrispi Anda dari enkripsi lama (ownCloud <= 8.0) ke yang baru. Mohon aktifkan \"Modul enkripsi standar\" dan jalankan 'occ encryption:migrate'",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Anda perlu untuk mengubah kunci enkripsi dari enkripsi lama (ownCloud <= 8.0) ke yang baru.",
     "Start migration" : "Mulai migrasi",
     "This is used for sending out notifications." : "Ini digunakan untuk mengirim notifikasi keluar.",
@@ -156,14 +176,13 @@ OC.L10N.register(
     "Authentication method" : "Metode otentikasi",
     "Authentication required" : "Diperlukan otentikasi",
     "Server address" : "Alamat server",
-    "Port" : "port",
+    "Port" : "Port",
     "Credentials" : "Kredensial",
     "SMTP Username" : "Nama pengguna SMTP",
     "SMTP Password" : "Sandi SMTP",
     "Store credentials" : "Simpan kredensial",
     "Test email settings" : "Pengaturan email percobaan",
     "Send email" : "Kirim email",
-    "Log level" : "Level log",
     "Download logfile" : "Unduh berkas log",
     "More" : "Lainnya",
     "Less" : "Ciutkan",
@@ -181,61 +200,51 @@ OC.L10N.register(
     "Developer documentation" : "Dokumentasi pengembang",
     "Experimental applications ahead" : "Aplikasi percobaan terdepan",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Aplikasi percobaan belum diperiksa untuk masalah keamanan, baru atau dikenal tidak stabil dan dalam proses pengembangan. Menginstalnya dapat menyebabkan kehilangan data atau penerobosan keamanan.",
-    "by" : "oleh",
-    "licensed" : "dilisensikan",
     "Documentation:" : "Dokumentasi:",
-    "User Documentation" : "Dokumentasi Pengguna",
-    "Admin Documentation" : "Dokumentasi Admin",
+    "User documentation" : "Dokumentasi pengguna.",
+    "Admin documentation" : "Dokumentasi admin",
     "Show description …" : "Tampilkan deskripsi ...",
     "Hide description …" : "Sembunyikan deskripsi ...",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Apl ini tidak dapat diinstal karena ketergantungan berikut belum terpenuhi:",
     "Enable only for specific groups" : "Aktifkan hanya untuk grup tertentu",
     "Uninstall App" : "Copot aplikasi",
     "Enable experimental apps" : "Aktifkan aplikasi percobaan",
-    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini.",
+    "Common Name" : "Nama umum",
+    "Valid until" : "Berlaku sampai",
+    "Issued By" : "Diterbitkan oleh",
+    "Valid until %s" : "Berlaku sampai %s",
+    "Import root certificate" : "Impor sertifikat root",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hai,<br><br>sekedar memberi tahu bahwa Andaa sekarang memiliki akun %s.<br><br>Nama Pengguna Anda: %s<br>Akses di: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Horee!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hai,\n\nsekedar memberi tahu bahwa Andaa sekarang memiliki akun %s.\n\nNama Pengguna Anda: %s\nAkses di: %s\n",
-    "User documentation" : "Dokumentasi pengguna.",
     "Administrator documentation" : "Dokumentasi administrator",
     "Online documentation" : "Dokumentasi online",
     "Forum" : "Forum",
     "Issue tracker" : "Pelacak masalah",
     "Commercial support" : "Dukungan komersial",
+    "Profile picture" : "Foto profil",
+    "Upload new" : "Unggah baru",
+    "Remove image" : "Hapus gambar",
+    "Cancel" : "Batal",
+    "Full name" : "Nama lengkap",
+    "No display name set" : "Nama tampilan tidak diatur",
+    "Email" : "Email",
+    "Your email address" : "Alamat email Anda",
+    "No email address set" : "Alamat email tidak diatur",
+    "You are member of the following groups:" : "Anda adalah anggota dari grup berikut:",
+    "Password" : "Sandi",
+    "Unable to change your password" : "Gagal mengubah sandi Anda",
+    "Current password" : "Sandi saat ini",
+    "New password" : "Sandi baru",
+    "Change password" : "Ubah sandi",
+    "Language" : "Bahasa",
+    "Help translate" : "Bantu menerjemahkan",
     "Get the apps to sync your files" : "Dapatkan aplikasi untuk sinkronisasi berkas Anda",
     "Desktop client" : "Klien desktop",
     "Android app" : "Aplikasi Android",
     "iOS app" : "Aplikasi iOS",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Jika Anda ingin mendukung proyek ini\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">bergabunglah dalam pengembangan</a>\n\t\tatau\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">promosikan</a>!",
     "Show First Run Wizard again" : "Tampilkan Penuntun Konfigurasi Awal",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Anda telah menggunakan <strong>%s</strong> dari total <strong>%s</strong>",
-    "Password" : "Sandi",
-    "Unable to change your password" : "Gagal mengubah sandi Anda",
-    "Current password" : "Sandi saat ini",
-    "New password" : "Sandi baru",
-    "Change password" : "Ubah sandi",
-    "Full name" : "Nama lengkap",
-    "No display name set" : "Nama tampilan tidak diatur",
-    "Email" : "Email",
-    "Your email address" : "Alamat email Anda",
-    "Fill in an email address to enable password recovery and receive notifications" : "Isikan alamat email untuk mengaktifkan pemulihan sandi dan menerima notifikasi",
-    "No email address set" : "Alamat email tidak diatur",
-    "You are member of the following groups:" : "Anda adalah anggota dari grup berikut:",
-    "Profile picture" : "Foto profil",
-    "Upload new" : "Unggah baru",
-    "Select new from Files" : "Pilih baru dari Berkas",
-    "Remove image" : "Hapus gambar",
-    "Either png or jpg. Ideally square but you will be able to crop it." : "Boleh png atau jpg. Idealnya berbentuk persegi tetapi jika tidak, Anda bisa memotongnya nanti.",
-    "Your avatar is provided by your original account." : "Avatar disediakan oleh akun asli Anda.",
-    "Cancel" : "Batal",
-    "Choose as profile image" : "Pilih sebagai gambar profil",
-    "Language" : "Bahasa",
-    "Help translate" : "Bantu menerjemahkan",
-    "Common Name" : "Nama umum",
-    "Valid until" : "Berlaku sampai",
-    "Issued By" : "Diterbitkan oleh",
-    "Valid until %s" : "Berlaku sampai %s",
-    "Import root certificate" : "Impor sertifikat root",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Dikembangkan oleh {communityopen}komunitas ownCloud{linkclose}, {githubopen}kode sumber{linkclose} dilisensikan dibawah {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Tampilkan kolasi penyimpanan",
     "Show last log in" : "Tampilkan masuk terakhir",
@@ -247,7 +256,6 @@ OC.L10N.register(
     "Create" : "Buat",
     "Admin Recovery Password" : "Sandi pemulihan Admin",
     "Enter the recovery password in order to recover the users files during password change" : "Masukkan sandi pemulihan untuk memulihkan berkas pengguna saat penggantian sandi",
-    "Search Users" : "Cari Pengguna",
     "Add Group" : "Tambah Grup",
     "Group" : "Grup",
     "Everyone" : "Semua orang",
@@ -265,6 +273,6 @@ OC.L10N.register(
     "change full name" : "ubah nama lengkap",
     "set new password" : "setel sandi baru",
     "change email address" : "ubah alamat email",
-    "Default" : "Baku"
+    "Default" : "Default"
 },
 "nplurals=1; plural=0;");
