@@ -10,15 +10,12 @@ OC.L10N.register(
     "Cron" : "Cron",
     "Email server" : "Email server",
     "Log" : "Záznam",
-    "Server Status" : "Stav servera",
     "Tips & tricks" : "Tipy a triky",
     "Updates" : "Aktualizácie",
-    "Authentication error" : "Chyba autentifikácie",
-    "Your full name has been changed." : "Vaše meno a priezvisko bolo zmenené.",
-    "Unable to change full name" : "Nemožno zmeniť meno a priezvisko",
     "Couldn't remove app." : "Nemožno odstrániť aplikáciu.",
     "Language changed" : "Jazyk zmenený",
     "Invalid request" : "Neplatná požiadavka",
+    "Authentication error" : "Chyba autentifikácie",
     "Admins can't remove themself from the admin group" : "Administrátori nesmú odstrániť sami seba zo skupiny admin",
     "Unable to add user to group %s" : "Nie je možné pridať používateľa do skupiny %s",
     "Unable to remove user from group %s" : "Nie je možné odstrániť používateľa zo skupiny %s",
@@ -31,6 +28,7 @@ OC.L10N.register(
     "Unable to change password" : "Zmena hesla sa nepodarila",
     "Enabled" : "Povolené",
     "Not enabled" : "Zakázané",
+    "Federated Cloud Sharing" : "Združené cloudové zdieľanie",
     "A problem occurred, please check your log files (Error: %s)" : "Nastala chyba, skontrolujte prosím váš log súbor (Chyba: %s)",
     "Migration Completed" : "Migrácia ukončená",
     "Group already exists." : "Skupina už existuje.",
@@ -51,13 +49,18 @@ OC.L10N.register(
     "Invalid user" : "Neplatný používateľ",
     "Unable to change mail address" : "Nemožno zmeniť emailovú adresu",
     "Email saved" : "Email uložený",
+    "Your full name has been changed." : "Vaše meno a priezvisko bolo zmenené.",
+    "Unable to change full name" : "Nemožno zmeniť meno a priezvisko",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ste si istí, že chcete pridať \"{domain}\" medzi dôveryhodné domény?",
     "Add trusted domain" : "Pridať dôveryhodnú doménu",
     "Migration in progress. Please wait until the migration is finished" : "Prebieha migrácia. Počkajte prosím, kým sa skončí",
     "Migration started …" : "Migrácia spustená ...",
     "Sending..." : "Odosielam...",
+    "Official" : "Oficiálny",
     "Approved" : "Schválené",
+    "Experimental" : "Experimentálny",
     "All" : "Všetky",
+    "No apps found for your version" : "Aplikácie pre vašu verziu sa nenašli",
     "Update to %s" : "Aktualizovať na %s",
     "Please wait...." : "Čakajte prosím...",
     "Error while disabling app" : "Chyba pri zakázaní aplikácie",
@@ -70,17 +73,16 @@ OC.L10N.register(
     "Uninstalling ...." : "Prebieha odinštalovanie...",
     "Error while uninstalling app" : "Chyba pri odinštalovaní aplikácie",
     "Uninstall" : "Odinštalácia",
+    "Valid until {date}" : "Platný do {date}",
+    "Delete" : "Zmazať",
     "Select a profile picture" : "Vybrať avatara",
     "Very weak password" : "Veľmi slabé heslo",
     "Weak password" : "Slabé heslo",
     "So-so password" : "Priemerné heslo",
     "Good password" : "Dobré heslo",
     "Strong password" : "Silné heslo",
-    "Valid until {date}" : "Platný do {date}",
-    "Delete" : "Zmazať",
     "Groups" : "Skupiny",
     "Unable to delete {objName}" : "Nemožno vymazať {objName}",
-    "Error creating group" : "Chyba pri vytváraní skupiny",
     "A valid group name must be provided" : "Musíte zadať platný názov skupiny",
     "deleted {groupName}" : "vymazaná {groupName}",
     "undo" : "vrátiť",
@@ -90,13 +92,11 @@ OC.L10N.register(
     "add group" : "pridať skupinu",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Zmena hesla bude mať za následok stratu dát, pretože obnova dát nie je k dispozícii pre tohto používateľa",
     "A valid username must be provided" : "Musíte zadať platné používateľské meno",
-    "Error creating user" : "Chyba pri vytváraní používateľa",
     "A valid password must be provided" : "Musíte zadať platné heslo",
     "A valid email must be provided" : "Musíte zadať platnú emailovú adresu",
     "__language_name__" : "Slovensky",
-    "Sync clients" : "Klienti synchronizácie",
     "Personal info" : "Osobné informácie",
-    "SSL root certificates" : "Koreňové SSL certifikáty",
+    "Sync clients" : "Klienti synchronizácie",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Všetko (fatálne problémy, chyby, upozornenia, info, debug)",
     "Info, warnings, errors and fatal issues" : "Info, upozornenia, chyby a fatálne problémy",
     "Warnings, errors and fatal issues" : "Upozornenia, chyby a fatálne problémy",
@@ -117,6 +117,7 @@ OC.L10N.register(
     "This means that there might be problems with certain characters in file names." : "To znamená, že sa môžu vyskytnúť problémy s niektorými znakmi v názvoch súborov.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Dôrazne doporučujeme nainštalovať na váš systém požadované balíčky podporujúce jednu z nasledovných znakových sád: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Inštalácia mimo koreňový priečinok domény a používanie systémového príkazu cron môže spôsobiť problém s generovaním správnej URL. Pre zabránenie týmto chybám nastavte prosím správnu cestu v svojom config.php súbore pre hodnotu \"overwrite.cli.url\" (Doporučujeme: \"%s\")",
+    "Open documentation" : "Otvoriť dokumentáciu",
     "Allow apps to use the Share API" : "Povoliť aplikáciám používať API na zdieľanie",
     "Allow users to share via link" : "Povoliť používateľom zdieľanie pomocou odkazov",
     "Enforce password protection" : "Vynútiť ochranu heslom",
@@ -131,12 +132,15 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Povoliť používateľom zasielať emailom oznámenie o zdieľaní súborov ostatným používateľom",
     "Exclude groups from sharing" : "Vybrať skupiny zo zdieľania",
     "These groups will still be able to receive shares, but not to initiate them." : "Tieto skupiny budú môcť stále zdieľať, ale sami nemôžu zdieľať ostatným.",
+    "Last cron job execution: %s." : "Posledný cron prebehol: %s.",
+    "Last cron job execution: %s. Something seems wrong." : "Posledný cron prebehol: %s. Zdá sa, že niečo nie je vporiadku.",
     "Cron was not executed yet!" : "Cron sa ešte nespustil!",
     "Execute one task with each page loaded" : "Vykonať jednu úlohu s každým načítaní stránky",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php je zaregistrovaná v službe WebCron a zavolá cron.php každých 15 minút cez http.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Použiť systémovú službu cron na spúšťanie súboru cron.php každých 15 minút.",
     "Enable server-side encryption" : "Povoliť šifrovanie na serveri",
     "Enable encryption" : "Povoliť šifrovanie",
+    "Select default encryption module:" : "Vybrať predvolený šifrovací modul:",
     "Start migration" : "Začať migráciu",
     "This is used for sending out notifications." : "Používa sa na odosielanie upozornení.",
     "Send mode" : "Mód odosielania",
@@ -153,69 +157,67 @@ OC.L10N.register(
     "Store credentials" : "Ukladať prihlasovacie údaje",
     "Test email settings" : "Nastavenia testovacieho emailu",
     "Send email" : "Odoslať email",
-    "Log level" : "Úroveň záznamu",
     "Download logfile" : "Stiahnuť súbor logu",
     "More" : "Viac",
     "Less" : "Menej",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Súbor protokolu je väčší ako 100 MB. Jeho sťahovanie môže chvíľu trvať!",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Ako databáza je použitá SQLite. Pre veľké inštalácie odporúčame prejsť na inú databázu.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Najmä pri používaní aplikácie na synchronizáciu s desktopom nie je databáza SQLite doporučená.",
+    "How to do backups" : "Ako vytvárať zálohy",
     "Advanced monitoring" : "Pokročilé sledovanie",
+    "Performance tuning" : "Ladenie výkonu",
     "Improving the config.php" : "Zlepšenie config.php",
+    "Theming" : "Vzhľady tém",
+    "Hardening and security guidance" : "Sprievodca vylepšením bezpečnosti",
     "Version" : "Verzia",
     "Developer documentation" : "Dokumentácia vývojára",
-    "by" : "od",
-    "licensed" : "licencované",
+    "Experimental applications ahead" : "Experimentálna aplikácia v poradí",
+    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Experimentálne aplikácie nie sú preverované na bezpečnostné chyby, môžu byť nestabilné a veľmi sa meniť. Ich inštaláciou môžete spôsobiť stratu dát alebo bezpečnostné problémy.",
     "Documentation:" : "Dokumentácia:",
-    "User Documentation" : "Príručka používateľa",
-    "Admin Documentation" : "Príručka administrátora",
+    "User documentation" : "Príručka používateľa",
+    "Admin documentation" : "Príručka administrátora",
     "Show description …" : "Zobraziť popis …",
     "Hide description …" : "Skryť popis …",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Túto aplikáciu nemožno nainštalovať, pretože nie sú splnené nasledovné závislosti:",
     "Enable only for specific groups" : "Povoliť len pre vybrané skupiny",
     "Uninstall App" : "Odinštalovanie aplikácie",
+    "Enable experimental apps" : "Povoliť experimentálne aplikácie",
+    "Common Name" : "Bežný názov",
+    "Valid until" : "Platný do",
+    "Issued By" : "Vydal",
+    "Valid until %s" : "Platný do %s",
+    "Import root certificate" : "Importovať koreňový certifikát",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Dobrý deň,<br><br>toto je oznámenie o novo vytvorenom účte %s.<br><br>Vaše používateľské meno: %s<br>Prihlásiť sa môžete tu: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Pekný deň!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ahoj,\n\ntoto je oznámenie o novo vytvorenom účte %s.\n\nVaše používateľské meno: %s\nPrihlásiť sa môžete tu: %s\n\n",
-    "User documentation" : "Príručka používateľa",
     "Administrator documentation" : "Príručka administrátora",
     "Online documentation" : "Online príručka",
     "Forum" : "Fórum",
+    "Issue tracker" : "Zoznam chýb",
     "Commercial support" : "Komerčná podpora",
+    "Profile picture" : "Avatar",
+    "Upload new" : "Nahrať nový",
+    "Remove image" : "Zmazať obrázok",
+    "Cancel" : "Zrušiť",
+    "Full name" : "Meno a priezvisko",
+    "No display name set" : "Zobrazované meno nie je nastavené",
+    "Email" : "Email",
+    "Your email address" : "Vaša emailová adresa",
+    "No email address set" : "Emailová adresa nie je nastavená",
+    "You are member of the following groups:" : "Ste členom nasledovných skupín:",
+    "Password" : "Heslo",
+    "Unable to change your password" : "Nie je možné zmeniť vaše heslo",
+    "Current password" : "Aktuálne heslo",
+    "New password" : "Nové heslo",
+    "Change password" : "Zmeniť heslo",
+    "Language" : "Jazyk",
+    "Help translate" : "Pomôcť s prekladom",
     "Get the apps to sync your files" : "Získať aplikácie na synchronizáciu vašich súborov",
     "Desktop client" : "Desktopový klient",
     "Android app" : "Android aplikácia",
     "iOS app" : "iOS aplikácia",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Ak chcete projekt podporiť,\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">zapojte sa do vývoja</a>\n\t\talebo\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">ho propagujte</a>!",
     "Show First Run Wizard again" : "Znovu zobraziť sprievodcu prvým spustením",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Použili ste <strong>%s</strong> z <strong>%s</strong> dostupných ",
-    "Password" : "Heslo",
-    "Unable to change your password" : "Nie je možné zmeniť vaše heslo",
-    "Current password" : "Aktuálne heslo",
-    "New password" : "Nové heslo",
-    "Change password" : "Zmeniť heslo",
-    "Full name" : "Meno a priezvisko",
-    "No display name set" : "Zobrazované meno nie je nastavené",
-    "Email" : "Email",
-    "Your email address" : "Vaša emailová adresa",
-    "Fill in an email address to enable password recovery and receive notifications" : "Zadajte emailovú adresu pre umožnenie obnovy zabudnutého hesla a pre prijímanie upozornení a oznámení",
-    "No email address set" : "Emailová adresa nie je nastavená",
-    "You are member of the following groups:" : "Ste členom nasledovných skupín:",
-    "Profile picture" : "Avatar",
-    "Upload new" : "Nahrať nový",
-    "Select new from Files" : "Vyberte nový zo súborov",
-    "Remove image" : "Zmazať obrázok",
-    "Either png or jpg. Ideally square but you will be able to crop it." : "Formát súboru png alebo jpg. V ideálnom prípade štvorec, ale budete mať možnosť ho orezať.",
-    "Your avatar is provided by your original account." : "Váš avatar je použitý z pôvodného účtu.",
-    "Cancel" : "Zrušiť",
-    "Choose as profile image" : "Vybrať ako avatara",
-    "Language" : "Jazyk",
-    "Help translate" : "Pomôcť s prekladom",
-    "Common Name" : "Bežný názov",
-    "Valid until" : "Platný do",
-    "Issued By" : "Vydal",
-    "Valid until %s" : "Platný do %s",
-    "Import root certificate" : "Importovať koreňový certifikát",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Vyvinula {communityopen}komunita ownCloud{linkclose}. {githubopen}Zdrojový kód{linkclose} je dostupný za podmienok licencie {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Zobraziť umiestnenie úložiska",
     "Show last log in" : "Zobraziť posledné prihlásenie",
@@ -227,7 +229,6 @@ OC.L10N.register(
     "Create" : "Vytvoriť",
     "Admin Recovery Password" : "Obnovenie hesla administrátora",
     "Enter the recovery password in order to recover the users files during password change" : "Zadajte heslo pre obnovenie súborov používateľa pri zmene hesla",
-    "Search Users" : "Hľadať používateľov",
     "Add Group" : "Pridať skupinu",
     "Group" : "Skupina",
     "Everyone" : "Všetci",
