@@ -12,12 +12,10 @@ OC.L10N.register(
     "Log" : "Бележење",
     "Tips & tricks" : "Савети и трикови",
     "Updates" : "Ажурирања",
-    "Authentication error" : "Грешка при провери идентитета",
-    "Your full name has been changed." : "Ваше пуно име је промењено.",
-    "Unable to change full name" : "Не могу да променим пуно име",
     "Couldn't remove app." : "Не могу да уклоним апликацију.",
     "Language changed" : "Језик је промењен",
     "Invalid request" : "Неисправан захтев",
+    "Authentication error" : "Грешка при провери идентитета",
     "Admins can't remove themself from the admin group" : "Администратор не може себе да уклони из admin групе",
     "Unable to add user to group %s" : "Не могу да додам корисника у групу %s",
     "Unable to remove user from group %s" : "Не могу да уклоним корисника из групе %s",
@@ -51,6 +49,8 @@ OC.L10N.register(
     "Invalid user" : "Неисправан корисник",
     "Unable to change mail address" : "Не могу да изменим е-адресу",
     "Email saved" : "Е-порука сачувана",
+    "Your full name has been changed." : "Ваше пуно име је промењено.",
+    "Unable to change full name" : "Не могу да променим пуно име",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Да ли заиста желите да додате „{domain}“ као поуздан домен?",
     "Add trusted domain" : "Додај поуздан домен",
     "Migration in progress. Please wait until the migration is finished" : "Пресељење је у току. Сачекајте док се не заврши",
@@ -60,6 +60,7 @@ OC.L10N.register(
     "Approved" : "Одобрене",
     "Experimental" : "Експерименталне",
     "All" : "Све",
+    "No apps found for your version" : "Нема апликација за вашу верзију",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Званичнe апликације су развиjене од стране и унутар оунКлауд заједнице. Оне пружају главне функционалности и спремне су и стабилне за свакодневну употребу.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Одобрене апликације су развили проверени програмери и апликације су прошле основне безбедносне провере. Оне се активно одржавају у репозиторијуму за апликације отвореног кода и њихови одржаватељи сматрају да су стабилне за уобичајену употребу.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ова апликација није проверена по питању безбедности и нова је или зна да буде нестабилна. Инсталирате је на сопствену одговорност.",
@@ -75,18 +76,17 @@ OC.L10N.register(
     "Uninstalling ...." : "Деинсталирам ...",
     "Error while uninstalling app" : "Грешка при деинсталацији апликације",
     "Uninstall" : "Деинсталирај",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Дошло је до грешке. Отпремите АСКИ кодирани ПЕМ сертификат.",
+    "Valid until {date}" : "Важи до {date}",
+    "Delete" : "Обриши",
     "Select a profile picture" : "Изаберите слику профила",
     "Very weak password" : "Веома слаба лозинка",
     "Weak password" : "Слаба лозинка",
     "So-so password" : "Осредња лозинка",
     "Good password" : "Добра лозинка",
     "Strong password" : "Јака лозинка",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Дошло је до грешке. Отпремите АСКИ кодирани ПЕМ сертификат.",
-    "Valid until {date}" : "Важи до {date}",
-    "Delete" : "Обриши",
     "Groups" : "Групе",
     "Unable to delete {objName}" : "Не могу да обришем {objName}",
-    "Error creating group" : "Грешка при прављењу групе",
     "A valid group name must be provided" : "Мора бити наведено исправно име групе",
     "deleted {groupName}" : "обрисана {groupName}",
     "undo" : "опозови",
@@ -96,13 +96,11 @@ OC.L10N.register(
     "add group" : "додај групу",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Измена лозинке ће резултирати губитком података јер опорављање података није доступно за овог корисника",
     "A valid username must be provided" : "Морате унети исправно корисничко име",
-    "Error creating user" : "Грешка при прављењу корисника",
     "A valid password must be provided" : "Морате унети исправну лозинку",
     "A valid email must be provided" : "Мора бити наведена исправна е-адреса",
     "__language_name__" : "Српски",
-    "Sync clients" : "Синхронизовање клијената",
     "Personal info" : "Лични подаци",
-    "SSL root certificates" : "ССЛ корени сертификати",
+    "Sync clients" : "Синхронизовање клијената",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Све (фаталне проблеме, грешке, упозорења, информације, отклањање грешака)",
     "Info, warnings, errors and fatal issues" : "Информације, упозорења, грешке и фатални проблеми",
     "Warnings, errors and fatal issues" : "Упозорења, грешке и фатални проблеми",
@@ -119,7 +117,6 @@ OC.L10N.register(
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "ПХП је очигледно подешен да се скида уметнуте док блокова. То ће учинити неколико кључних апликација недоступним.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Ваш сервер ради под оперативним системом Microsoft Windows. Препоручујемо оперативни систем Linux за оптималaн кориснички доживљај.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "%1$s верзије ниже од %2$s је инсталиран. Због стабилности и перформанси препоручујемо да ажурирате на новију %1$s верзију.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Недостаје ПХП модул „fileinfo“. Препоручујемо вам да га укључите да бисте добили најбоље резултате с откривањем МИМЕ врста.",
     "System locale can not be set to a one which supports UTF-8." : "Системски локалитет се не може поставити на неки који подржава УТФ-8",
     "This means that there might be problems with certain characters in file names." : "То значи да може доћи до проблема са неким знаковима у називима фајлова.",
@@ -170,7 +167,6 @@ OC.L10N.register(
     "Store credentials" : "Сачувај акредитиве",
     "Test email settings" : "Тестирај поставке е-поште",
     "Send email" : "Пошаљи е-пошту",
-    "Log level" : "Ниво бележења",
     "Download logfile" : "Преузми записник",
     "More" : "Више",
     "Less" : "Мање",
@@ -188,8 +184,6 @@ OC.L10N.register(
     "Developer documentation" : "Програмерска документација",
     "Experimental applications ahead" : "Експериментална апликација",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Експерименталне апликације се непроверене што се тиче безбедности и могу бити нестабилне и недовршене. Инсталирање може довести до губитка података или нарушавања безбедности.",
-    "by" : "од",
-    "licensed" : "лиценцирано",
     "Documentation:" : "Документација:",
     "User documentation" : "Корисничка документација",
     "Admin documentation" : "Администраторска документација",
@@ -199,7 +193,11 @@ OC.L10N.register(
     "Enable only for specific groups" : "Укључи само за одређене групе",
     "Uninstall App" : "Деинсталирај апликацију",
     "Enable experimental apps" : "Укључи експерименталне апликације",
-    "No apps found for your version" : "Нема апликација за вашу верзију",
+    "Common Name" : "Уобичајено име",
+    "Valid until" : "Важи до",
+    "Issued By" : "Издавач",
+    "Valid until %s" : "Важи до %s",
+    "Import root certificate" : "Увоз кореног сертификата",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Поздрав,<br><br>само вас обавештавам да сад имате %s налог.<br><br>Ваше корисничко име: %s<br>Приступите му на: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Здраво!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Поздрав.\n\nСамо да знате да сада имате %s налог.\n\nВаше корисничко име: %s\nПриступите му на: %s\n",
@@ -208,39 +206,29 @@ OC.L10N.register(
     "Forum" : "Форум",
     "Issue tracker" : "Пратилац проблема",
     "Commercial support" : "Комерцијална подршка",
+    "Profile picture" : "Слика профила",
+    "Upload new" : "Отпреми нову",
+    "Remove image" : "Уклони слику",
+    "Cancel" : "Одустани",
+    "Full name" : "Пуно име",
+    "No display name set" : "Није постављено име за приказ",
+    "Email" : "Е-пошта",
+    "Your email address" : "Ваша адреса е-поште",
+    "No email address set" : "Није постављена е-адреса",
+    "You are member of the following groups:" : "Имате чланство у следећим групама:",
+    "Password" : "Лозинка",
+    "Unable to change your password" : "Не могу да изменим вашу лозинку",
+    "Current password" : "Тренутна лозинка",
+    "New password" : "Нова лозинка",
+    "Change password" : "Измени лозинку",
+    "Language" : "Језик",
+    "Help translate" : " Помозите у превођењу",
     "Get the apps to sync your files" : "Преузмите апликације ради синхронизовања ваших фајлова",
     "Desktop client" : "Клијент за рачунар",
     "Android app" : "Андроид апликација",
     "iOS app" : "иОС апликација",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Ако желите да подржите пројект\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">придружите се развоју</a>\n\t\tили\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">разгласите свима</a>!",
     "Show First Run Wizard again" : "Поново прикажи чаробњака за прво покретање",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Искористили сте <strong>%s</strong> од дозвољених <strong>%s</strong>",
-    "Password" : "Лозинка",
-    "Unable to change your password" : "Не могу да изменим вашу лозинку",
-    "Current password" : "Тренутна лозинка",
-    "New password" : "Нова лозинка",
-    "Change password" : "Измени лозинку",
-    "Full name" : "Пуно име",
-    "No display name set" : "Није постављено име за приказ",
-    "Email" : "Е-пошта",
-    "Your email address" : "Ваша адреса е-поште",
-    "Fill in an email address to enable password recovery and receive notifications" : "Попуните е-адресу да омогућите обнављање лозинке и добијате обавештења",
-    "No email address set" : "Није постављена е-адреса",
-    "You are member of the following groups:" : "Имате чланство у следећим групама:",
-    "Profile picture" : "Слика профила",
-    "Upload new" : "Отпреми нову",
-    "Select new from Files" : "Изабери нову из фајлова",
-    "Remove image" : "Уклони слику",
-    "Your avatar is provided by your original account." : "Ваш аватар је добијен са оригиналног налога.",
-    "Cancel" : "Одустани",
-    "Choose as profile image" : "Изаберите слику профила",
-    "Language" : "Језик",
-    "Help translate" : " Помозите у превођењу",
-    "Common Name" : "Уобичајено име",
-    "Valid until" : "Важи до",
-    "Issued By" : "Издавач",
-    "Valid until %s" : "Важи до %s",
-    "Import root certificate" : "Увоз кореног сертификата",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Развијено од стране {communityopen}оунКлауд заједнице{linkclose}, {githubopen}изворни код{linkclose} је лиценциран под {licenseopen}<abbr title=\"Аферо општа јавна лиценца\">АОЈЛ (AGPL)</abbr>{linkclose}.",
     "Show storage location" : "Прикажи локацију складишта",
     "Show last log in" : "Прикажи последњу пријаву",
