@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "APCu" : "APCu",
     "Redis" : "Redis",
-    "Security & setup warnings" : "安全 & 设置警告",
+    "Security & setup warnings" : "安全及设置警告",
     "Sharing" : "共享",
     "Server-side encryption" : "服务器端加密",
     "External Storage" : "外部存储",
@@ -12,12 +12,10 @@ OC.L10N.register(
     "Log" : "日志",
     "Tips & tricks" : "技巧提示",
     "Updates" : "更新",
-    "Authentication error" : "认证错误",
-    "Your full name has been changed." : "您的全名已修改。",
-    "Unable to change full name" : "无法修改全名",
     "Couldn't remove app." : "无法删除应用。",
     "Language changed" : "语言已修改",
     "Invalid request" : "无效请求",
+    "Authentication error" : "认证错误",
     "Admins can't remove themself from the admin group" : "管理员不能将自己移出管理组。",
     "Unable to add user to group %s" : "无法把用户增加到组 %s",
     "Unable to remove user from group %s" : "无法从组%s中移除用户",
@@ -53,6 +51,8 @@ OC.L10N.register(
     "Invalid user" : "用户无效",
     "Unable to change mail address" : "无法更改邮箱地址",
     "Email saved" : "电子邮件已保存",
+    "Your full name has been changed." : "您的全名已修改。",
+    "Unable to change full name" : "无法修改全名",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "你真的希望添加 \"{domain}\" 为信任域？",
     "Add trusted domain" : "添加信任域",
     "Migration in progress. Please wait until the migration is finished" : "迁移正在进行中。请等待，直到完成迁移",
@@ -62,6 +62,7 @@ OC.L10N.register(
     "Approved" : "已认可",
     "Experimental" : "实验",
     "All" : "全部",
+    "No apps found for your version" : "未找到适合当前版本的应用",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "官方应用是由 ownCloud 社区开发。他们提供 ownCloud 的功能核心并准备用于生产。",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "已认可的应用是由值得信赖的开发商开发，并已通过了一个粗略的安全检查。他们放在一个开放的代码库并且维护人员认为他们是稳定的差不多可以正常使用。",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "此应用未检查安全问题，它是新的或已知是不稳定的。安装风险自担。",
@@ -77,6 +78,12 @@ OC.L10N.register(
     "Uninstalling ...." : "卸载中....",
     "Error while uninstalling app" : "卸载应用时发生了一个错误",
     "Uninstall" : "卸载",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。5秒后将跳转到更新页面。",
+    "App update" : "应用更新",
+    "No apps found for \"{query}\"" : "未找到应用适合 \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "出现了一个错误。请上传 ASCII 编码的 PEM 证书。",
+    "Valid until {date}" : "有效期至 {date}",
+    "Delete" : "删除",
     "An error occurred: {message}" : "发生错误： {message}",
     "Select a profile picture" : "选择头像",
     "Very weak password" : "非常弱的密码",
@@ -84,12 +91,8 @@ OC.L10N.register(
     "So-so password" : "一般强度的密码",
     "Good password" : "较强的密码",
     "Strong password" : "强密码",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "出现了一个错误。请上传 ASCII 编码的 PEM 证书。",
-    "Valid until {date}" : "有效期至 {date}",
-    "Delete" : "删除",
     "Groups" : "组",
     "Unable to delete {objName}" : "无法删除 {objName}",
-    "Error creating group" : "创建组时出错",
     "A valid group name must be provided" : "请提供一个有效的组名称",
     "deleted {groupName}" : "已删除 {groupName}",
     "undo" : "撤销",
@@ -99,13 +102,11 @@ OC.L10N.register(
     "add group" : "增加组",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "更改密码会导致数据丢失，因为数据恢复不适用于此用户",
     "A valid username must be provided" : "必须提供合法的用户名",
-    "Error creating user" : "创建用户出错",
     "A valid password must be provided" : "必须提供合法的密码",
     "A valid email must be provided" : "必须提供合法的用户名",
     "__language_name__" : "简体中文",
-    "Sync clients" : "客户端",
     "Personal info" : "个人信息",
-    "SSL root certificates" : "SSL 根证书",
+    "Sync clients" : "客户端",
     "Everything (fatal issues, errors, warnings, info, debug)" : "所有（灾难性问题，错误，警告，信息，调试）",
     "Info, warnings, errors and fatal issues" : "信息，警告，错误和灾难性问题",
     "Warnings, errors and fatal issues" : "警告，错误和灾难性问题",
@@ -123,7 +124,6 @@ OC.L10N.register(
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除行内 <doc> 块，这将导致数个核心应用无法访问。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能是由缓存/加速器造成的，例如 Zend OPcache 或 eAccelerator。",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "你的服务器是运行于 Microsoft Windows 系统。我们强烈推荐使用 Linux 系统以获得最佳的用户体验。比如中文文件夹和文件名支持。",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "%1$s 下版本 %2$s 已安装。基于稳定和性能的原因，我们强烈建议更新至 %1$s 版本。",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP模块'文件信息'丢失. 我们强烈建议启用此模块以便mime类型检测取得最佳结果.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "事务文件锁定被禁用，这可能会导致竞争条件问题。在config.php 中启用“filelocking.enabled”可以避免这些问题。请参阅<a target=\"_blank\" href=\"%s\">文档↗</a>了解详情。",
     "System locale can not be set to a one which supports UTF-8." : "系统语系无法设置为支持 UTF-8 的语系。",
@@ -131,7 +131,6 @@ OC.L10N.register(
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "我们强烈建议安装在系统上所需的软件包支持以下区域设置之一： %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "如果你不是安装在网域根目录而且又使用系统定时计划任务，那么可以导致 URL 链接生成问题。为了避免这些问题，请在你的 Config.php 文件中设置 \\\"overwrite.cli.url\\\" 选项为 webroot 安装根目录 (建议: \\\"%s\\\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "由于下面的错误，无法通过 CLI 执行定时计划任务:",
-    "Transactional file locking is using the database as locking backend, for best performance it's advised to configure a memcache for locking. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "事务文件锁定正在使用的数据库作为锁定后端，为获得最佳的性能建议配置的 memcache 用来锁定。请参阅<a target=\"_blank\" href=\"%s\">文档↗</a>了解详情。",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "请点击检查 <a target=\\\"_blank\\\" href=\\\"%s\\\"> 安装向导 ↗</a>, 点击 <a href=\\\"#log-section\\\"> 日志 </a>查看详细错误和警告。",
     "All checks passed." : "所有检查已通过。",
     "Open documentation" : "打开文档",
@@ -149,6 +148,7 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "允许用户发送共享文件的邮件通知给其他用户",
     "Exclude groups from sharing" : "在分享中排除组",
     "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取分享，但无法向他人分享。",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "允许在共享对话框中的自动补全用户名。如果被禁用，需要输入用户全名。",
     "Last cron job execution: %s." : "上次定时任务执行于： %s.",
     "Last cron job execution: %s. Something seems wrong." : "上次定时任务执行于: %s. 似乎有些问题。",
     "Cron was not executed yet!" : "定时任务还未被执行！",
@@ -157,6 +157,10 @@ OC.L10N.register(
     "Use system's cron service to call the cron.php file every 15 minutes." : "使用系统 CRON 服务每 15 分钟执行一次 cron.php 文件。",
     "Enable server-side encryption" : "启用服务器端加密",
     "Please read carefully before activating server-side encryption: " : "在激活服务器端加密之前，请仔细阅读：",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦加密被启用，之后上传到服务器的所有文件都将服务器上加密。只有当启用状态的加密模块支持解密并且所有的先决条件(例如，设定恢复键)得到满足时才能解除加密。",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "加密本身并不能保证系统的安全性。请参阅ownCloud文档有关加密应用程序是如何工作和支持用例的详细信息等。",
+    "Be aware that encryption always increases the file size." : "请注意，加密会增加文件大小。",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定期备份数据有利于保证数据完整，并且确保备份您的加密数据和加密密钥。",
     "This is the final warning: Do you really want to enable encryption?" : "这是最后一次警告：你真的想启用加密？",
     "Enable encryption" : "启用加密",
     "No encryption module loaded, please enable an encryption module in the app menu." : "没有加载加密模块，请在 APP 应用菜单中启用加密模块。",
@@ -179,11 +183,11 @@ OC.L10N.register(
     "Store credentials" : "存储凭据",
     "Test email settings" : "测试电子邮件设置",
     "Send email" : "发送邮件",
-    "Log level" : "日志级别",
     "Download logfile" : "下载日志文件",
     "More" : "更多",
     "Less" : "更少",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "日志文件超过 100 MB。下载可能需要一些时间！",
+    "What to log" : "记录日志",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite 被用作数据库。对于较大数据量的安装和使用，我们建议您切换到不同的数据库后端。",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特别当使用桌面客户端来同步文件时，不鼓励使用 SQLite 。",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "要迁移到另一个数据库请使用命令行工具: 'occ db:convert-type', 或者查看 <a target=\\\"_blank\\\" href=\\\"%s\\\"> 相关文档 ↗</a>.",
@@ -197,18 +201,23 @@ OC.L10N.register(
     "Developer documentation" : "开发者文档",
     "Experimental applications ahead" : "未来的实验应用",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "实验应用程序没有在安全性的问题上作过多检查，新的或已知的不稳定 BUG 都在开发中。安装它们可能会导致数据丢失或安全漏洞。",
-    "by" : "被",
-    "licensed" : "许可",
     "Documentation:" : "文档：",
     "User documentation" : "用户文档",
     "Admin documentation" : "管理员文档",
     "Show description …" : "显示描述...",
     "Hide description …" : "隐藏描述...",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "这个程序没有指定最低的ownCloud版本。这是在ownCloud11之后版本的错误。",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "这个程序没有指定最高的ownCloud版本。这是在ownCloud11之后版本的错误。",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "此应用程序无法安装，因为以下依赖性不满足：",
     "Enable only for specific groups" : "仅对特定的组开放",
     "Uninstall App" : "卸载应用",
     "Enable experimental apps" : "启用实验性应用程序",
-    "No apps found for your version" : "未找到适合当前版本的应用",
+    "SSL Root Certificates" : "SSL 根证书",
+    "Common Name" : "通用名称",
+    "Valid until" : "有效期至",
+    "Issued By" : "授权由",
+    "Valid until %s" : "有效期至 %s",
+    "Import root certificate" : "导入根证书",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "亲，<br><br>现在我们为你开通了 %s 私有云帐户。<br><br>你的用户名： %s<br>访问网址： <a href=\\\"%s\\\">%s</a><br><br>",
     "Cheers!" : "干杯！",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "亲，\\n\\n 现在我们为你开通了 %s 私有去帐户。\\n\\n 你的用户名： %s\\n 访问网址： %s\\n 你的初始密码需要咨询系统管理员。或者你也可以在登录页面输入任意密码登录，\\n登录窗口将出现忘记密码链接，点击通过注册邮箱重设初始密码。\\n\\n",
@@ -217,41 +226,35 @@ OC.L10N.register(
     "Forum" : "论坛",
     "Issue tracker" : "问题跟踪",
     "Commercial support" : "商业支持",
+    "Profile picture" : "联系人图片",
+    "Upload new" : "上传新的",
+    "Select from Files" : "选择文件",
+    "Remove image" : "移除图片",
+    "png or jpg, max. 20 MB" : "png或jpg格式最大不超过20MB大小",
+    "Picture provided by original account" : "原始账户图片",
+    "Cancel" : "取消",
+    "Choose as profile picture" : "选择图片",
+    "Full name" : "全名",
+    "No display name set" : "不显示名称设置",
+    "Email" : "电子邮件",
+    "Your email address" : "您的电子邮件",
+    "For password recovery and notifications" : "用户恢复密码通知",
+    "No email address set" : "尚未设置 Email 地址",
+    "You are member of the following groups:" : "您是以下组的成员：",
+    "Password" : "密码",
+    "Unable to change your password" : "无法修改密码",
+    "Current password" : "当前密码",
+    "New password" : "新密码",
+    "Change password" : "修改密码",
+    "Language" : "语言",
+    "Help translate" : "帮助翻译",
     "Get the apps to sync your files" : "安装应用进行文件同步",
     "Desktop client" : "桌面客户端",
     "Android app" : "Android 应用",
     "iOS app" : "iOS 应用",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "想支持ownCloud项目？请\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">参加开发</a>\n\t\t或者\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">帮助推广</a>吧！",
     "Show First Run Wizard again" : "再次显示首次运行向导",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "你已使用 <strong>%s</strong>，有效空间 <strong>%s</strong>",
-    "Password" : "密码",
-    "Unable to change your password" : "无法修改密码",
-    "Current password" : "当前密码",
-    "New password" : "新密码",
-    "Change password" : "修改密码",
-    "Full name" : "全名",
-    "No display name set" : "不显示名称设置",
-    "Email" : "电子邮件",
-    "Your email address" : "您的电子邮件",
-    "Fill in an email address to enable password recovery and receive notifications" : "填入电子邮件地址从而启用密码恢复和接收通知",
-    "No email address set" : "尚未设置 Email 地址",
-    "You are member of the following groups:" : "您是以下组的成员：",
-    "Profile picture" : "联系人图片",
-    "Upload new" : "上传新的",
-    "Select new from Files" : "从文件中选择一个新的",
-    "Remove image" : "移除图片",
-    "Either png or jpg. Ideally square but you will be able to crop it. The file is not allowed to exceed the maximum size of 20 MB." : "png 或 jpg。正方形比较理想但你也可以之后对其进行裁剪。文件大小最大不允许超过 20MB。",
-    "Your avatar is provided by your original account." : "您的头像由您的原始账户所提供。",
-    "Cancel" : "取消",
-    "Choose as profile image" : "用作头像",
-    "Language" : "语言",
-    "Help translate" : "帮助翻译",
-    "Common Name" : "通用名称",
-    "Valid until" : "有效期至",
-    "Issued By" : "授权由",
-    "Valid until %s" : "有效期至 %s",
-    "Import root certificate" : "导入根证书",
-    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "由 {communityopen}ownCloud 社区{linkclose}开发，{githubopen}源代码{linkclose}在 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr> 许可证{linkclose}下发布。",
+    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "由 {communityopen}ownCloud 社区{linkclose}开发，{githubopen}源代码{linkclose}的发布需遵守 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr> 许可协议{linkclose}。",
     "Show storage location" : "显示存储位置",
     "Show last log in" : "显示最后登录",
     "Show user backend" : "显示用户后端",
